@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef ATTACHMENTVCARDFROMADDRESSBOOKJOBTEST_H
-#define ATTACHMENTVCARDFROMADDRESSBOOKJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -15,12 +14,10 @@ class AttachmentVcardFromAddressBookJobTest : public QObject
     Q_OBJECT
 public:
     explicit AttachmentVcardFromAddressBookJobTest(QObject *parent = nullptr);
-    ~AttachmentVcardFromAddressBookJobTest();
+    ~AttachmentVcardFromAddressBookJobTest() override;
 private Q_SLOTS:
     void testAttachmentVCardWithInvalidItem();
     void testAttachmentVCardWithValidItem();
     void testAttachmentVCardWithInvalidVCard();
     void testAttachmentVCardWithEmptyVCard();
 };
-
-#endif // ATTACHMENTVCARDFROMADDRESSBOOKJOBTEST_H
