@@ -25,12 +25,13 @@
 #include <MessageCore/StringUtil>
 
 #include <Akonadi/ItemFetchJob>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <QIcon>
 
 #include <QMenu>
 #include <QPointer>
 #include <QTreeView>
+#include <kwidgetsaddons_version.h>
 
 #include "messagecomposer_debug.h"
 #include <KActionCollection>
@@ -51,8 +52,8 @@
 #include "attachment/attachmentfrommimecontentjob.h"
 #include "attachment/attachmentfromurljob.h"
 #include "messagecore/attachmentupdatejob.h"
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
-#include <Akonadi/Contact/EmailAddressSelectionWidget>
+#include <Akonadi/EmailAddressSelectionDialog>
+#include <Akonadi/EmailAddressSelectionWidget>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
@@ -64,6 +65,7 @@
 #include <KJob>
 #include <KMime/Content>
 
+#include <QActionGroup>
 #include <QFileDialog>
 
 using namespace MessageComposer;
@@ -136,9 +138,7 @@ AttachmentControllerBase::AttachmentControllerBasePrivate::AttachmentControllerB
 {
 }
 
-AttachmentControllerBase::AttachmentControllerBasePrivate::~AttachmentControllerBasePrivate()
-{
-}
+AttachmentControllerBase::AttachmentControllerBasePrivate::~AttachmentControllerBasePrivate() = default;
 
 void AttachmentControllerBase::setSelectedParts(const AttachmentPart::List &selectedParts)
 {
@@ -166,7 +166,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::attachmentRemove
 void AttachmentControllerBase::AttachmentControllerBasePrivate::compressJobResult(KJob *job)
 {
     if (job->error()) {
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to compress attachment"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to compress attachment"));
         return;
     }
 
@@ -176,13 +176,21 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::compressJobResul
     AttachmentPart::Ptr compressedPart = ajob->compressedPart();
 
     if (ajob->isCompressedPartLarger()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int result = KMessageBox::questionTwoActions(wParent,
+#else
         const int result = KMessageBox::questionYesNo(wParent,
-                                                      i18n("The compressed attachment is larger than the original. "
-                                                           "Do you want to keep the original one?"),
-                                                      QString(/*caption*/),
-                                                      KGuiItem(i18nc("Do not compress", "Keep")),
-                                                      KGuiItem(i18n("Compress")));
+#endif
+                                                           i18n("The compressed attachment is larger than the original. "
+                                                                "Do you want to keep the original one?"),
+                                                           QString(/*caption*/),
+                                                           KGuiItem(i18nc("Do not compress", "Keep")),
+                                                           KGuiItem(i18n("Compress")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
         if (result == KMessageBox::Yes) {
+#endif
             // The user has chosen to keep the uncompressed file.
             return;
         }
@@ -200,7 +208,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::compressJobResul
 void AttachmentControllerBase::AttachmentControllerBasePrivate::loadJobResult(KJob *job)
 {
     if (job->error()) {
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach file"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to attach file"));
         return;
     }
 
@@ -273,7 +281,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::reloadAttachment
 void AttachmentControllerBase::AttachmentControllerBasePrivate::updateJobResult(KJob *job)
 {
     if (job->error()) {
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to reload attachment"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to reload attachment"));
         return;
     }
     auto ajob = qobject_cast<AttachmentUpdateJob *>(job);
@@ -376,7 +384,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::attachPublicKeyJ
     // is that we want to show the proper caption ("public key" instead of "file")...
 
     if (job->error()) {
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach public key"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to attach public key"));
         return;
     }
 
@@ -390,7 +398,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::attachVcardFromA
 {
     if (job->error()) {
         qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get vCard";
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach vCard"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to attach vCard"));
         return;
     }
 
@@ -403,7 +411,7 @@ void AttachmentControllerBase::AttachmentControllerBasePrivate::attachClipBoardE
 {
     if (job->error()) {
         qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get try to attach text from clipboard";
-        KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach text from clipboard"));
+        KMessageBox::error(wParent, job->errorString(), i18n("Failed to attach text from clipboard"));
         return;
     }
 
@@ -676,7 +684,7 @@ void AttachmentControllerBase::openWith(const KService::Ptr &offer)
 {
     QTemporaryFile *tempFile = dumpAttachmentToTempFile(d->selectedParts.constFirst());
     if (!tempFile) {
-        KMessageBox::sorry(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to open attachment"));
+        KMessageBox::error(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to open attachment"));
         return;
     }
     QUrl url = QUrl::fromLocalFile(tempFile->fileName());
@@ -684,7 +692,7 @@ void AttachmentControllerBase::openWith(const KService::Ptr &offer)
     // If offer is null, this will show the "open with" dialog
     auto job = new KIO::ApplicationLauncherJob(offer);
     job->setUrls({url});
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
     job->start();
     connect(job, &KJob::result, this, [tempFile, job]() {
         if (job->error()) {
@@ -700,16 +708,16 @@ void AttachmentControllerBase::openAttachment(const AttachmentPart::Ptr &part)
 {
     QTemporaryFile *tempFile = dumpAttachmentToTempFile(part);
     if (!tempFile) {
-        KMessageBox::sorry(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to open attachment"));
+        KMessageBox::error(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to open attachment"));
         return;
     }
     tempFile->setPermissions(QFile::ReadUser);
     auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(tempFile->fileName()), QString::fromLatin1(part->mimeType()));
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
     job->setDeleteTemporaryFile(true);
     connect(job, &KIO::OpenUrlJob::result, this, [this, tempFile](KJob *job) {
         if (job->error() == KIO::ERR_USER_CANCELED) {
-            KMessageBox::sorry(d->wParent, i18n("KMail was unable to open the attachment."), job->errorString());
+            KMessageBox::error(d->wParent, i18n("KMail was unable to open the attachment."), job->errorString());
             delete tempFile;
         } else {
             // The file was opened.  Delete it only when the composer is closed
@@ -749,7 +757,7 @@ void AttachmentControllerBase::editAttachment(AttachmentPart::Ptr part, MessageV
 {
     QTemporaryFile *tempFile = dumpAttachmentToTempFile(part);
     if (!tempFile) {
-        KMessageBox::sorry(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to edit attachment"));
+        KMessageBox::error(d->wParent, i18n("KMail was unable to write the attachment to a temporary file."), i18n("Unable to edit attachment"));
         return;
     }
 
@@ -844,12 +852,20 @@ void AttachmentControllerBase::attachmentProperties(const AttachmentPart::Ptr &p
 
 void AttachmentControllerBase::attachDirectory(const QUrl &url)
 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int rc = KMessageBox::warningTwoActions(d->wParent,
+#else
     const int rc = KMessageBox::warningYesNo(d->wParent,
-                                             i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                                             i18nc("@title:window", "Attach directory"),
-                                             KGuiItem(i18nc("@action:button", "Attach")),
-                                             KStandardGuiItem::cancel());
+#endif
+                                                  i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
+                                                  i18nc("@title:window", "Attach directory"),
+                                                  KGuiItem(i18nc("@action:button", "Attach")),
+                                                  KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (rc == KMessageBox::ButtonCode::PrimaryAction) {
+#else
     if (rc == KMessageBox::Yes) {
+#endif
         addAttachment(url);
     }
 }
@@ -902,12 +918,20 @@ void AttachmentControllerBase::showAddAttachmentFileDialog()
             QMimeDatabase mimeDb;
             const auto mimeType = mimeDb.mimeTypeForUrl(urlWithEncoding);
             if (mimeType.name() == QLatin1String("inode/directory")) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                const int rc = KMessageBox::warningTwoActions(d->wParent,
+#else
                 const int rc = KMessageBox::warningYesNo(d->wParent,
-                                                         i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                                                         i18nc("@title:window", "Attach directory"),
-                                                         KGuiItem(i18nc("@action:button", "Attach")),
-                                                         KStandardGuiItem::cancel());
+#endif
+                                                              i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
+                                                              i18nc("@title:window", "Attach directory"),
+                                                              KGuiItem(i18nc("@action:button", "Attach")),
+                                                              KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (rc == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (rc == KMessageBox::Yes) {
+#endif
                     addAttachment(urlWithEncoding);
                 }
             } else {
@@ -934,7 +958,7 @@ void AttachmentControllerBase::addAttachmentUrlSync(const QUrl &url)
         addAttachment(part);
     } else {
         if (ajob->error()) {
-            KMessageBox::sorry(d->wParent, ajob->errorString(), i18nc("@title:window", "Failed to attach file"));
+            KMessageBox::error(d->wParent, ajob->errorString(), i18nc("@title:window", "Failed to attach file"));
         }
     }
 }
