@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,11 @@
 #include <KPIMTextEdit/RichTextComposerControler>
 #include <KPIMTextEdit/RichTextComposerImages>
 #include <KPIMTextEdit/TextHTMLBuilder>
-#include <PimCommon/AutoCorrection>
+#include <PimCommonAutoCorrection/AutoCorrection>
 #include <part/textpart.h>
 
+#include <KMessageBox>
+
 #include <QRegularExpression>
 
 #define USE_TEXTHTML_BUILDER 1
@@ -32,7 +34,7 @@ public:
 
     void fixHtmlFontSize(QString &cleanHtml) const;
     Q_REQUIRED_RESULT QString toCleanHtml() const;
-    PimCommon::AutoCorrection *autoCorrection = nullptr;
+    PimCommonAutoCorrection::AutoCorrection *autoCorrection = nullptr;
     RichTextComposerNg *const richtextComposer;
     MessageComposer::RichTextComposerSignatures *richTextComposerSignatures = nullptr;
 };
@@ -50,12 +52,12 @@ MessageComposer::RichTextComposerSignatures *RichTextComposerNg::composerSignatu
     return d->richTextComposerSignatures;
 }
 
-PimCommon::AutoCorrection *RichTextComposerNg::autocorrection() const
+PimCommonAutoCorrection::AutoCorrection *RichTextComposerNg::autocorrection() const
 {
     return d->autoCorrection;
 }
 
-void RichTextComposerNg::setAutocorrection(PimCommon::AutoCorrection *autocorrect)
+void RichTextComposerNg::setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect)
 {
     d->autoCorrection = autocorrect;
 }
@@ -63,7 +65,9 @@ void RichTextComposerNg::setAutocorrection(PimCommon::AutoCorrection *autocorrec
 void RichTextComposerNg::setAutocorrectionLanguage(const QString &lang)
 {
     if (d->autoCorrection) {
-        d->autoCorrection->setLanguage(lang);
+        PimCommonAutoCorrection::AutoCorrectionSettings *settings = d->autoCorrection->autoCorrectionSettings();
+        settings->setLanguage(lang);
+        d->autoCorrection->setAutoCorrectionSettings(settings);
     }
 }
 
@@ -75,7 +79,7 @@ static bool isSpecial(const QTextCharFormat &charFormat)
 
 bool RichTextComposerNg::processModifyText(QKeyEvent *e)
 {
-    if (d->autoCorrection && d->autoCorrection->isEnabledAutoCorrection()) {
+    if (d->autoCorrection && d->autoCorrection->autoCorrectionSettings()->isEnabledAutoCorrection()) {
         if ((e->key() == Qt::Key_Space) || (e->key() == Qt::Key_Enter) || (e->key() == Qt::Key_Return)) {
             if (!isLineQuoted(textCursor().block().text()) && !textCursor().hasSelection()) {
                 const QTextCharFormat initialTextFormat = textCursor().charFormat();
@@ -346,10 +350,16 @@ void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &s
 {
     if (signature.isEnabledSignature()) {
         QString signatureStr;
+        bool ok = false;
+        QString errorMessage;
         if (addedText & KIdentityManagement::Signature::AddSeparator) {
-            signatureStr = signature.withSeparator();
+            signatureStr = signature.withSeparator(&ok, &errorMessage);
         } else {
-            signatureStr = signature.rawText();
+            signatureStr = signature.rawText(&ok, &errorMessage);
+        }
+
+        if (!ok && !errorMessage.isEmpty()) {
+            KMessageBox::error(nullptr, errorMessage);
         }
 
         insertSignatureHelper(signatureStr,
@@ -383,7 +393,7 @@ void RichTextComposerNg::forceAutoCorrection(bool selectedText)
     if (document()->isEmpty()) {
         return;
     }
-    if (d->autoCorrection && d->autoCorrection->isEnabledAutoCorrection()) {
+    if (d->autoCorrection && d->autoCorrection->autoCorrectionSettings()->isEnabledAutoCorrection()) {
         const bool richText = (textMode() == RichTextComposer::Rich);
         const int initialPosition = textCursor().position();
         QTextCursor cur = textCursor();
