@@ -8,20 +8,21 @@
 
 #include "composer.h"
 
-#include "job/attachmentjob.h"
-#include "part/globalpart.h"
-#include "part/infopart.h"
-#include "job/jobbase_p.h"
-#include "part/textpart.h"
-#include "job/maintextjob.h"
-#include "job/multipartjob.h"
-#include "job/signjob.h"
-#include "job/encryptjob.h"
-#include "job/signencryptjob.h"
-#include "job/skeletonmessagejob.h"
-#include "job/transparentjob.h"
 #include "imagescaling/imagescaling.h"
 #include "imagescaling/imagescalingutils.h"
+#include "job/attachmentjob.h"
+#include "job/autocryptheadersjob.h"
+#include "job/encryptjob.h"
+#include "job/jobbase_p.h"
+#include "job/maintextjob.h"
+#include "job/multipartjob.h"
+#include "job/signencryptjob.h"
+#include "job/signjob.h"
+#include "job/skeletonmessagejob.h"
+#include "job/transparentjob.h"
+#include "part/globalpart.h"
+#include "part/infopart.h"
+#include "part/textpart.h"
 #include "settings/messagecomposersettings.h"
 
 #include "messagecomposer_debug.h"
@@ -33,13 +34,14 @@ using MessageCore::AttachmentPart;
 class MessageComposer::ComposerPrivate : public JobBasePrivate
 {
 public:
-    ComposerPrivate(Composer *qq)
+    explicit ComposerPrivate(Composer *qq)
         : JobBasePrivate(qq)
     {
     }
-    ~ComposerPrivate()
+
+    ~ComposerPrivate() override
     {
-        //delete skeletonMessage;
+        delete skeletonMessage;
     }
 
     void init();
@@ -47,13 +49,19 @@ public:
     void composeStep1();
     void composeStep2();
     Q_REQUIRED_RESULT QList<ContentJobBase *> createEncryptJobs(ContentJobBase *contentJob, bool sign);
-    void contentJobFinished(KJob *job);   // slot
-    void composeWithLateAttachments(KMime::Message *headers, KMime::Content *content, const AttachmentPart::List &parts, const std::vector<GpgME::Key> &keys, const QStringList &recipients);
-    void attachmentsFinished(KJob *job);   // slot
+    void contentJobFinished(KJob *job); // slot
+    void composeWithLateAttachments(KMime::Message *headers,
+                                    KMime::Content *content,
+                                    const AttachmentPart::List &parts,
+                                    const std::vector<GpgME::Key> &keys,
+                                    const QStringList &recipients);
+    void attachmentsFinished(KJob *job); // slot
 
     void composeFinalStep(KMime::Content *headers, KMime::Content *content);
 
-    QVector<QPair<QStringList, std::vector<GpgME::Key> > > encData;
+    QString gnupgHome;
+    QVector<QPair<QStringList, std::vector<GpgME::Key>>> encData;
+    GpgME::Key senderEncryptionKey;
     std::vector<GpgME::Key> signers;
     AttachmentPart::List attachmentParts;
     // attachments with different sign/encrypt settings from
@@ -77,6 +85,7 @@ public:
     bool encrypt = false;
     bool noCrypto = false;
     bool autoSaving = false;
+    bool autocryptEnabled = false;
     Q_DECLARE_PUBLIC(Composer)
 };
 
@@ -103,7 +112,7 @@ void ComposerPrivate::composeStep1()
     Q_Q(Composer);
 
     // Create skeleton message (containing headers only; no content).
-    SkeletonMessageJob *skeletonJob = new SkeletonMessageJob(infoPart, globalPart, q);
+    auto skeletonJob = new SkeletonMessageJob(infoPart, globalPart, q);
     QObject::connect(skeletonJob, &SkeletonMessageJob::finished, q, [this, skeletonJob](KJob *job) {
         if (job->error()) {
             return; // KCompositeJob takes care of the error.
@@ -126,13 +135,13 @@ void ComposerPrivate::composeStep2()
     Q_Q(Composer);
 
     ContentJobBase *mainJob = nullptr;
-    MainTextJob *mainTextJob = new MainTextJob(textPart, q);
+    auto mainTextJob = new MainTextJob(textPart, q);
 
-    if ((sign || encrypt) && format & Kleo::InlineOpenPGPFormat) {    // needs custom handling --- one SignEncryptJob by itself
+    if ((sign || encrypt) && format & Kleo::InlineOpenPGPFormat) { // needs custom handling --- one SignEncryptJob by itself
         qCDebug(MESSAGECOMPOSER_LOG) << "sending to sign/enc inline job!";
 
         if (encrypt) {
-            //TODO: fix Inline PGP with encrypted attachments
+            // TODO: fix Inline PGP with encrypted attachments
 
             const QList<ContentJobBase *> jobs = createEncryptJobs(mainTextJob, sign);
             for (ContentJobBase *subJob : jobs) {
@@ -140,20 +149,20 @@ void ComposerPrivate::composeStep2()
                     // We have no attachments.  Use the content given by the MainTextJob.
                     mainJob = subJob;
                 } else {
-                    MultipartJob *multipartJob = new MultipartJob(q);
+                    auto multipartJob = new MultipartJob(q);
                     multipartJob->setMultipartSubtype("mixed");
                     multipartJob->appendSubjob(subJob);
-                    for (const AttachmentPart::Ptr &part : qAsConst(attachmentParts)) {
+                    for (const AttachmentPart::Ptr &part : std::as_const(attachmentParts)) {
                         multipartJob->appendSubjob(new AttachmentJob(part));
                     }
                     mainJob = multipartJob;
                 }
 
-                QObject::connect(mainJob, SIGNAL(finished(KJob*)), q, SLOT(contentJobFinished(KJob*)));
+                QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
                 q->addSubjob(mainJob);
             }
         } else {
-            SignJob *subJob = new SignJob(q);
+            auto subJob = new SignJob(q);
             subJob->setSigningKeys(signers);
             subJob->setCryptoMessageFormat(format);
             subJob->appendSubjob(mainTextJob);
@@ -162,15 +171,15 @@ void ComposerPrivate::composeStep2()
                 // We have no attachments.  Use the content given by the MainTextJob.
                 mainJob = subJob;
             } else {
-                MultipartJob *multipartJob = new MultipartJob(q);
+                auto multipartJob = new MultipartJob(q);
                 multipartJob->setMultipartSubtype("mixed");
                 multipartJob->appendSubjob(subJob);
-                for (const AttachmentPart::Ptr &part : qAsConst(attachmentParts)) {
+                for (const AttachmentPart::Ptr &part : std::as_const(attachmentParts)) {
                     multipartJob->appendSubjob(new AttachmentJob(part));
                 }
                 mainJob = multipartJob;
             }
-            QObject::connect(mainJob, SIGNAL(finished(KJob*)), q, SLOT(contentJobFinished(KJob*)));
+            QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
             q->addSubjob(mainJob);
         }
 
@@ -191,41 +200,59 @@ void ComposerPrivate::composeStep2()
         while (iter.hasNext()) {
             AttachmentPart::Ptr part = iter.next();
             qCDebug(MESSAGECOMPOSER_LOG) << "Checking attachment crypto policy... signed: " << part->isSigned() << " isEncrypted : " << part->isEncrypted();
-            if (!noCrypto && !autoSaving && (sign != part->isSigned() || encrypt != part->isEncrypted())) {    // different policy
+            if (!noCrypto && !autoSaving && (sign != part->isSigned() || encrypt != part->isEncrypted())) { // different policy
                 qCDebug(MESSAGECOMPOSER_LOG) << "got attachment with different crypto policy!";
                 lateAttachmentParts.append(part);
                 iter.remove();
             }
         }
-        MultipartJob *multipartJob = new MultipartJob(q);
+        auto multipartJob = new MultipartJob(q);
         multipartJob->setMultipartSubtype("mixed");
         multipartJob->appendSubjob(mainTextJob);
-        for (const AttachmentPart::Ptr &part : qAsConst(attachmentParts)) {
+        for (const AttachmentPart::Ptr &part : std::as_const(attachmentParts)) {
             multipartJob->appendSubjob(new AttachmentJob(part));
         }
         mainJob = multipartJob;
     }
 
+    if (autocryptEnabled) {
+        auto autocryptJob = new AutocryptHeadersJob();
+        autocryptJob->setSkeletonMessage(skeletonMessage);
+        autocryptJob->setGnupgHome(gnupgHome);
+        autocryptJob->appendSubjob(mainJob);
+        autocryptJob->setSenderKey(senderEncryptionKey);
+        if (encrypt && format & Kleo::OpenPGPMIMEFormat) {
+            qDebug() << "Add gossip: " << encData[0].first.size() << encData[0].second.size();
+            if (encData[0].first.size() > 1 && encData[0].second.size() > 2) {
+                autocryptJob->setGossipKeys(encData[0].second);
+            }
+        }
+        mainJob = autocryptJob;
+    }
+
     if (sign) {
-        SignJob *sJob = new SignJob(q);
+        auto sJob = new SignJob(q);
         sJob->setCryptoMessageFormat(format);
         sJob->setSigningKeys(signers);
         sJob->appendSubjob(mainJob);
-        if (!encrypt) {
-            sJob->setSkeletonMessage(skeletonMessage);
-        }
+        sJob->setSkeletonMessage(skeletonMessage);
         mainJob = sJob;
     }
 
     if (encrypt) {
         const auto lstJob = createEncryptJobs(mainJob, false);
-        for (ContentJobBase *eJob : lstJob) {
-            QObject::connect(eJob, SIGNAL(finished(KJob*)), q, SLOT(contentJobFinished(KJob*)));
-            q->addSubjob(eJob);
-            mainJob = eJob;         //start only last EncryptJob
+        for (ContentJobBase *job : lstJob) {
+            auto eJob = dynamic_cast<EncryptJob *>(job);
+            if (eJob && sign) {
+                // When doing Encrypt and Sign move headers only in the signed part
+                eJob->setProtectedHeaders(false);
+            }
+            QObject::connect(job, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
+            q->addSubjob(job);
+            mainJob = job; // start only last EncryptJob
         }
     } else {
-        QObject::connect(mainJob, SIGNAL(finished(KJob*)), q, SLOT(contentJobFinished(KJob*)));
+        QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
         q->addSubjob(mainJob);
     }
 
@@ -245,7 +272,7 @@ QList<ContentJobBase *> ComposerPrivate::createEncryptJobs(ContentJobBase *conte
     qCDebug(MESSAGECOMPOSER_LOG) << "format:" << format;
     qCDebug(MESSAGECOMPOSER_LOG) << "enc data:" << encData.size();
 
-    if (encData.isEmpty()) {  // no key data! bail!
+    if (encData.isEmpty()) { // no key data! bail!
         q->setErrorText(i18n("No key data for recipients found."));
         q->setError(Composer::IncompleteError);
         q->emitResult();
@@ -255,11 +282,11 @@ QList<ContentJobBase *> ComposerPrivate::createEncryptJobs(ContentJobBase *conte
     const int encDataSize = encData.size();
     jobs.reserve(encDataSize);
     for (int i = 0; i < encDataSize; ++i) {
-        QPair<QStringList, std::vector<GpgME::Key> > recipients = encData[ i ];
+        QPair<QStringList, std::vector<GpgME::Key>> recipients = encData[i];
         qCDebug(MESSAGECOMPOSER_LOG) << "got first list of recipients:" << recipients.first;
         ContentJobBase *subJob = nullptr;
         if (sign) {
-            SignEncryptJob *seJob = new SignEncryptJob(q);
+            auto seJob = new SignEncryptJob(q);
 
             seJob->setCryptoMessageFormat(format);
             seJob->setSigningKeys(signers);
@@ -269,11 +296,12 @@ QList<ContentJobBase *> ComposerPrivate::createEncryptJobs(ContentJobBase *conte
 
             subJob = seJob;
         } else {
-            EncryptJob *eJob = new EncryptJob(q);
+            auto eJob = new EncryptJob(q);
             eJob->setCryptoMessageFormat(format);
             eJob->setEncryptionKeys(recipients.second);
             eJob->setRecipients(recipients.first);
             eJob->setSkeletonMessage(skeletonMessage);
+            eJob->setGnupgHome(gnupgHome);
             subJob = eJob;
         }
         qCDebug(MESSAGECOMPOSER_LOG) << "subJob" << subJob;
@@ -297,13 +325,13 @@ void ComposerPrivate::contentJobFinished(KJob *job)
     QStringList recipients;
 
     Q_ASSERT(dynamic_cast<ContentJobBase *>(job) == static_cast<ContentJobBase *>(job));
-    ContentJobBase *contentJob = static_cast<ContentJobBase *>(job);
+    auto contentJob = static_cast<ContentJobBase *>(job);
 
     // create the final headers and body,
     // taking into account secondary recipients for encryption
-    if (encData.size() > 1) {  // crypto job with secondary recipients..
-        Q_ASSERT(dynamic_cast<MessageComposer::AbstractEncryptJob *>(job));    // we need to get the recipients for this job
-        MessageComposer::AbstractEncryptJob *eJob = dynamic_cast<MessageComposer::AbstractEncryptJob *>(job);
+    if (encData.size() > 1) { // crypto job with secondary recipients..
+        Q_ASSERT(dynamic_cast<MessageComposer::AbstractEncryptJob *>(job)); // we need to get the recipients for this job
+        auto eJob = dynamic_cast<MessageComposer::AbstractEncryptJob *>(job);
 
         keys = eJob->encryptionKeys();
         recipients = eJob->recipients();
@@ -317,7 +345,7 @@ void ComposerPrivate::contentJobFinished(KJob *job)
         headers->setHeader(skeletonMessage->date());
         headers->setHeader(skeletonMessage->messageID());
 
-        KMime::Headers::Generic *realTo = new KMime::Headers::Generic("X-KMail-EncBccRecipients");
+        auto realTo = new KMime::Headers::Generic("X-KMail-EncBccRecipients");
         realTo->fromUnicodeString(eJob->recipients().join(QLatin1Char('%')), "utf-8");
 
         qCDebug(MESSAGECOMPOSER_LOG) << "got one of multiple messages sending to:" << realTo->asUnicodeString();
@@ -326,9 +354,10 @@ void ComposerPrivate::contentJobFinished(KJob *job)
         headers->assemble();
     } else { // just use the saved headers from before
         if (!encData.isEmpty()) {
-            qCDebug(MESSAGECOMPOSER_LOG) << "setting enc data:" << encData[ 0 ].first << "with num keys:" << encData[ 0 ].second.size();
-            keys = encData[ 0 ].second;
-            recipients = encData[ 0 ].first;
+            const auto firstElement = encData.at(0);
+            qCDebug(MESSAGECOMPOSER_LOG) << "setting enc data:" << firstElement.first << "with num keys:" << firstElement.second.size();
+            keys = firstElement.second;
+            recipients = firstElement.first;
         }
 
         headers = skeletonMessage;
@@ -342,15 +371,19 @@ void ComposerPrivate::contentJobFinished(KJob *job)
     }
 }
 
-void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers, KMime::Content *content, const AttachmentPart::List &parts, const std::vector<GpgME::Key> &keys, const QStringList &recipients)
+void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers,
+                                                 KMime::Content *content,
+                                                 const AttachmentPart::List &parts,
+                                                 const std::vector<GpgME::Key> &keys,
+                                                 const QStringList &recipients)
 {
     Q_Q(Composer);
 
-    MultipartJob *multiJob = new MultipartJob(q);
+    auto multiJob = new MultipartJob(q);
     multiJob->setMultipartSubtype("mixed");
 
     // wrap the content into a job for the multijob to handle it
-    MessageComposer::TransparentJob *tJob = new MessageComposer::TransparentJob(q);
+    auto tJob = new MessageComposer::TransparentJob(q);
     tJob->setContent(content);
     multiJob->appendSubjob(tJob);
     multiJob->setExtraContent(headers);
@@ -358,13 +391,13 @@ void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers, KMime:
     qCDebug(MESSAGECOMPOSER_LOG) << "attachment encr key size:" << keys.size() << " recipients: " << recipients;
 
     // operate correctly on each attachment that has a different crypto policy than body.
-    for (const AttachmentPart::Ptr &attachment : qAsConst(parts)) {
-        AttachmentJob *attachJob = new AttachmentJob(attachment, q);
+    for (const AttachmentPart::Ptr &attachment : std::as_const(parts)) {
+        auto attachJob = new AttachmentJob(attachment, q);
 
         qCDebug(MESSAGECOMPOSER_LOG) << "got a late attachment";
         if (attachment->isSigned() && format) {
             qCDebug(MESSAGECOMPOSER_LOG) << "adding signjob for late attachment";
-            SignJob *sJob = new SignJob(q);
+            auto sJob = new SignJob(q);
             sJob->setContent(nullptr);
             sJob->setCryptoMessageFormat(format);
             sJob->setSigningKeys(signers);
@@ -372,7 +405,7 @@ void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers, KMime:
             sJob->appendSubjob(attachJob);
             if (attachment->isEncrypted()) {
                 qCDebug(MESSAGECOMPOSER_LOG) << "adding sign + encrypt job for late attachment";
-                EncryptJob *eJob = new EncryptJob(q);
+                auto eJob = new EncryptJob(q);
                 eJob->setCryptoMessageFormat(format);
                 eJob->setEncryptionKeys(keys);
                 eJob->setRecipients(recipients);
@@ -384,9 +417,9 @@ void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers, KMime:
                 qCDebug(MESSAGECOMPOSER_LOG) << "Just signing late attachment";
                 multiJob->appendSubjob(sJob);
             }
-        } else if (attachment->isEncrypted() && format) {  // only encryption
+        } else if (attachment->isEncrypted() && format) { // only encryption
             qCDebug(MESSAGECOMPOSER_LOG) << "just encrypting late attachment";
-            EncryptJob *eJob = new EncryptJob(q);
+            auto eJob = new EncryptJob(q);
             eJob->setCryptoMessageFormat(format);
             eJob->setEncryptionKeys(keys);
             eJob->setRecipients(recipients);
@@ -395,12 +428,12 @@ void ComposerPrivate::composeWithLateAttachments(KMime::Message *headers, KMime:
             multiJob->appendSubjob(eJob);
         } else {
             qCDebug(MESSAGECOMPOSER_LOG) << "attaching plain non-crypto attachment";
-            AttachmentJob *attachJob = new AttachmentJob(attachment, q);
-            multiJob->appendSubjob(attachJob);
+            auto attachSecondJob = new AttachmentJob(attachment, q);
+            multiJob->appendSubjob(attachSecondJob);
         }
     }
 
-    QObject::connect(multiJob, SIGNAL(finished(KJob*)), q, SLOT(attachmentsFinished(KJob*)));
+    QObject::connect(multiJob, SIGNAL(finished(KJob *)), q, SLOT(attachmentsFinished(KJob *)));
 
     q->addSubjob(multiJob);
     multiJob->start();
@@ -414,7 +447,7 @@ void ComposerPrivate::attachmentsFinished(KJob *job)
     qCDebug(MESSAGECOMPOSER_LOG) << "composing final message with late attachments";
 
     Q_ASSERT(dynamic_cast<ContentJobBase *>(job));
-    ContentJobBase *contentJob = static_cast<ContentJobBase *>(job);
+    auto contentJob = static_cast<ContentJobBase *>(job);
 
     KMime::Content *content = contentJob->content();
     KMime::Content *headers = contentJob->extraContent();
@@ -427,6 +460,9 @@ void ComposerPrivate::composeFinalStep(KMime::Content *headers, KMime::Content *
     content->assemble();
 
     const QByteArray allData = headers->head() + content->encodedContent();
+
+    delete content;
+
     KMime::Message::Ptr resultMessage(new KMime::Message);
     resultMessage->setContent(allData);
     resultMessage->parse(); // Not strictly necessary.
@@ -440,17 +476,14 @@ Composer::Composer(QObject *parent)
     d->init();
 }
 
-Composer::~Composer()
-{
-}
+Composer::~Composer() = default;
 
 QVector<KMime::Message::Ptr> Composer::resultMessages() const
 {
     Q_D(const Composer);
     Q_ASSERT(d->finished);
     Q_ASSERT(!error());
-    const QVector<KMime::Message::Ptr> results = d->resultMessages;
-    return results;
+    return d->resultMessages;
 }
 
 GlobalPart *Composer::globalPart() const
@@ -534,14 +567,14 @@ void Composer::setMessageCryptoFormat(Kleo::CryptoMessageFormat format)
     d->format = format;
 }
 
-void Composer::setSigningKeys(std::vector<GpgME::Key> &signers)
+void Composer::setSigningKeys(const std::vector<GpgME::Key> &signers)
 {
     Q_D(Composer);
 
     d->signers = signers;
 }
 
-void Composer::setEncryptionKeys(const QVector<QPair<QStringList, std::vector<GpgME::Key> > > &encData)
+void Composer::setEncryptionKeys(const QVector<QPair<QStringList, std::vector<GpgME::Key>>> &encData)
 {
     Q_D(Composer);
 
@@ -555,6 +588,34 @@ void Composer::setNoCrypto(bool noCrypto)
     d->noCrypto = noCrypto;
 }
 
+void Composer::setAutocryptEnabled(bool autocryptEnabled)
+{
+    Q_D(Composer);
+
+    d->autocryptEnabled = autocryptEnabled;
+}
+
+void Composer::setSenderEncryptionKey(const GpgME::Key &senderKey)
+{
+    Q_D(Composer);
+
+    d->senderEncryptionKey = senderKey;
+}
+
+void Composer::setGnupgHome(const QString &path)
+{
+    Q_D(Composer);
+
+    d->gnupgHome = path;
+}
+
+QString Composer::gnupgHome() const
+{
+    Q_D(const Composer);
+
+    return d->gnupgHome;
+}
+
 bool Composer::finished() const
 {
     Q_D(const Composer);
