@@ -1,26 +1,27 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_MESSAGEFACTORYFORWARDJOB_H
-#define MESSAGECOMPOSER_MESSAGEFACTORYFORWARDJOB_H
+#pragma once
 
-#include <QObject>
+#include <Akonadi/Collection>
 #include <KMime/Message>
-#include <AkonadiCore/Collection>
-namespace KIdentityManagement {
+#include <QObject>
+namespace KIdentityManagement
+{
 class IdentityManager;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class MessageFactoryForwardJob : public QObject
 {
     Q_OBJECT
 public:
     explicit MessageFactoryForwardJob(QObject *parent = nullptr);
-    ~MessageFactoryForwardJob();
+    ~MessageFactoryForwardJob() override;
     void start();
     void setMsg(const KMime::Message::Ptr &msg);
 
@@ -48,5 +49,3 @@ private:
     KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 };
 }
-
-#endif
