@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@
 
 #include <Akonadi/Collection>
 #include <Akonadi/Item>
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <QVector>
 
 namespace KIdentityManagement
@@ -32,10 +32,14 @@ enum ReplyStrategy {
     ReplyAuthor, //< Reply to the author of the message (possibly NOT the mailing list, if any)
     ReplyList, //< Reply to the mailing list (and not the author of the message)
     ReplyAll, //< Reply to author and all the recipients in CC
-    ReplyNone //< Don't set reply addresses: they will be set manually
+    ReplyNone, //< Don't set reply addresses: they will be set manually
 };
 
-enum MDNAdvice { MDNIgnore, MDNSendDenied, MDNSend };
+enum MDNAdvice {
+    MDNIgnore,
+    MDNSendDenied,
+    MDNSend,
+};
 /**
  * Contains various factory methods for creating new messages such as replies, MDNs, forwards, etc.
  */
@@ -266,4 +270,3 @@ private:
 
 Q_DECLARE_METATYPE(MessageComposer::ReplyStrategy)
 Q_DECLARE_METATYPE(MessageComposer::MessageFactoryNG::MessageReply)
-
