@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "messagefactoryreplyjob.h"
 #include "settings/messagecomposersettings.h"
 #include <TemplateParser/TemplateParserJob>
-#include <KIdentityManagement/IdentityManager>
 
 using namespace MessageComposer;
 
@@ -16,13 +15,12 @@ MessageFactoryReplyJob::MessageFactoryReplyJob(QObject *parent)
 {
 }
 
-MessageFactoryReplyJob::~MessageFactoryReplyJob()
-{
-}
+MessageFactoryReplyJob::~MessageFactoryReplyJob() = default;
 
 void MessageFactoryReplyJob::start()
 {
-    TemplateParser::TemplateParserJob *parser = new TemplateParser::TemplateParserJob(mMsg, (mReplyAll ? TemplateParser::TemplateParserJob::ReplyAll : TemplateParser::TemplateParserJob::Reply), this);
+    auto parser =
+        new TemplateParser::TemplateParserJob(mMsg, (mReplyAll ? TemplateParser::TemplateParserJob::ReplyAll : TemplateParser::TemplateParserJob::Reply), this);
     connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &MessageFactoryReplyJob::slotReplyDone);
     connect(parser, &TemplateParser::TemplateParserJob::parsingFailed, this, &MessageFactoryReplyJob::slotReplyDone);
     parser->setIdentityManager(mIdentityManager);
