@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imagescalingselectformat.h"
 
+#include <KLocalizedString>
 #include <QLineEdit>
 #include <QPushButton>
-#include <KLocalizedString>
 
-#include <QListWidget>
-#include <QHBoxLayout>
-#include <QPointer>
 #include <QDialogButtonBox>
+#include <QHBoxLayout>
+#include <QListWidget>
+#include <QPointer>
 #include <QVBoxLayout>
 
 using namespace MessageComposer;
@@ -22,8 +22,8 @@ ImageScalingSelectFormatDialog::ImageScalingSelectFormatDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Select Image Format"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -36,13 +36,11 @@ ImageScalingSelectFormatDialog::ImageScalingSelectFormatDialog(QWidget *parent)
     initialize();
 }
 
-ImageScalingSelectFormatDialog::~ImageScalingSelectFormatDialog()
-{
-}
+ImageScalingSelectFormatDialog::~ImageScalingSelectFormatDialog() = default;
 
 void ImageScalingSelectFormatDialog::addImageFormat(const QString &format, const QString &mimetype)
 {
-    QListWidgetItem *item = new QListWidgetItem(format);
+    auto item = new QListWidgetItem(format);
     item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
     item->setData(ImageScalingSelectFormatDialog::ImageRole, mimetype);
     item->setCheckState(Qt::Unchecked);
@@ -87,8 +85,8 @@ void ImageScalingSelectFormatDialog::setFormat(const QString &format)
 ImageScalingSelectFormat::ImageScalingSelectFormat(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QHBoxLayout(this);
+    lay->setContentsMargins({});
     mFormat = new QLineEdit;
     connect(mFormat, &QLineEdit::textChanged, this, &ImageScalingSelectFormat::textChanged);
     mFormat->setReadOnly(true);
@@ -98,9 +96,7 @@ ImageScalingSelectFormat::ImageScalingSelectFormat(QWidget *parent)
     lay->addWidget(mSelectFormat);
 }
 
-ImageScalingSelectFormat::~ImageScalingSelectFormat()
-{
-}
+ImageScalingSelectFormat::~ImageScalingSelectFormat() = default;
 
 void ImageScalingSelectFormat::slotSelectFormat()
 {
