@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAGESCALINGSELECTFORMAT_H
-#define IMAGESCALINGSELECTFORMAT_H
+#pragma once
 
 #include <QDialog>
 
@@ -13,21 +12,20 @@ class QLineEdit;
 class QPushButton;
 class QListWidget;
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ImageScalingSelectFormatDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ImageScalingSelectFormatDialog(QWidget *parent);
-    ~ImageScalingSelectFormatDialog();
+    ~ImageScalingSelectFormatDialog() override;
 
     void setFormat(const QString &format);
     QString format() const;
 
 private:
-    enum {
-        ImageRole = Qt::UserRole + 1
-    };
+    enum { ImageRole = Qt::UserRole + 1 };
     void initialize();
     void addImageFormat(const QString &format, const QString &mimetype);
     QListWidget *mListWidget = nullptr;
@@ -38,7 +36,7 @@ class ImageScalingSelectFormat : public QWidget
     Q_OBJECT
 public:
     explicit ImageScalingSelectFormat(QWidget *parent);
-    ~ImageScalingSelectFormat();
+    ~ImageScalingSelectFormat() override;
 
     void setFormat(const QString &format);
     Q_REQUIRED_RESULT QString format() const;
@@ -54,5 +52,3 @@ private:
     QPushButton *mSelectFormat = nullptr;
 };
 }
-
-#endif // IMAGESCALINGSELECTFORMAT_H
