@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imagescalingwidget.h"
-#include "ui_imagescalingwidget.h"
 #include "settings/messagecomposersettings.h"
-#include <Libkdepim/LineEditCatchReturnKey>
+#include "ui_imagescalingwidget.h"
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <Libkdepim/LineEditCatchReturnKey>
 
 #include <QButtonGroup>
 #include <QComboBox>
 #include <QImageWriter>
-#include <QWhatsThis>
 #include <QVector>
+#include <QWhatsThis>
 
 using namespace MessageComposer;
 class MessageComposer::ImageScalingWidgetPrivate
@@ -31,7 +31,7 @@ public:
         delete ui;
     }
 
-    Ui::ImageScalingWidget *ui = nullptr;
+    Ui::ImageScalingWidget *const ui;
     QButtonGroup *mSourceFilenameFilterGroup = nullptr;
     QButtonGroup *mRecipientFilterGroup = nullptr;
     bool mWasChanged = false;
@@ -58,12 +58,12 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
     connect(d->ui->AskBeforeResizing, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->EnlargeImageToMinimum, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->ReduceImageToMaximum, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
-    connect(d->ui->customMaximumWidth, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
-    connect(d->ui->customMaximumHeight, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
-    connect(d->ui->customMinimumWidth, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
-    connect(d->ui->customMinimumHeight, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(d->ui->customMaximumWidth, &QSpinBox::valueChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->customMaximumHeight, &QSpinBox::valueChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->customMinimumWidth, &QSpinBox::valueChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->customMinimumHeight, &QSpinBox::valueChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->skipImageSizeLower, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
-    connect(d->ui->imageSize, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(d->ui->imageSize, &QSpinBox::valueChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->pattern, &QLineEdit::textChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->CBMaximumWidth, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
     connect(d->ui->CBMaximumHeight, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
@@ -83,53 +83,54 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
 
     d->ui->pattern->setEnabled(false);
     d->mSourceFilenameFilterGroup = new QButtonGroup(d->ui->filterSourceGroupBox);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect(d->mSourceFilenameFilterGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotSourceFilterClicked);
-#else
-    connect(d->mSourceFilenameFilterGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotSourceFilterAbstractButtonClicked);
-#endif
+    connect(d->mSourceFilenameFilterGroup,
+            qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked),
+            this,
+            &ImageScalingWidget::slotSourceFilterAbstractButtonClicked);
     d->mSourceFilenameFilterGroup->addButton(d->ui->notFilterFilename, MessageComposer::MessageComposerSettings::EnumFilterSourceType::NoFilter);
-    d->mSourceFilenameFilterGroup->addButton(d->ui->includeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::IncludeFilesWithPattern);
-    d->mSourceFilenameFilterGroup->addButton(d->ui->excludeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::ExcludeFilesWithPattern);
+    d->mSourceFilenameFilterGroup->addButton(d->ui->includeFilesWithPattern,
+                                             MessageComposer::MessageComposerSettings::EnumFilterSourceType::IncludeFilesWithPattern);
+    d->mSourceFilenameFilterGroup->addButton(d->ui->excludeFilesWithPattern,
+                                             MessageComposer::MessageComposerSettings::EnumFilterSourceType::ExcludeFilesWithPattern);
 
     d->mRecipientFilterGroup = new QButtonGroup(d->ui->tab_4);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect(d->mRecipientFilterGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotRecipientFilterClicked);
-#else
-    connect(d->mRecipientFilterGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotRecipientFilterAbstractClicked);
-#endif
+    connect(d->mRecipientFilterGroup,
+            qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked),
+            this,
+            &ImageScalingWidget::slotRecipientFilterAbstractClicked);
     d->ui->doNotResizePattern->setEnabled(false);
     d->ui->resizeEmailsPattern->setEnabled(false);
     d->mRecipientFilterGroup->addButton(d->ui->doNotFilterRecipients, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::NoFilter);
-    d->mRecipientFilterGroup->addButton(d->ui->resizeEachEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern);
-    d->mRecipientFilterGroup->addButton(d->ui->resizeOneEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern);
-    d->mRecipientFilterGroup->addButton(d->ui->doNotResizeEachEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern);
-    d->mRecipientFilterGroup->addButton(d->ui->doNotResizeOneEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern);
+    d->mRecipientFilterGroup->addButton(d->ui->resizeEachEmails,
+                                        MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern);
+    d->mRecipientFilterGroup->addButton(d->ui->resizeOneEmails,
+                                        MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern);
+    d->mRecipientFilterGroup->addButton(d->ui->doNotResizeEachEmails,
+                                        MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern);
+    d->mRecipientFilterGroup->addButton(d->ui->doNotResizeOneEmails,
+                                        MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern);
 
     d->ui->help->setText(i18n("<a href=\"whatsthis\">How does this work?</a>"));
     connect(d->ui->help, &QLabel::linkActivated, this, &ImageScalingWidget::slotHelpLinkClicked);
     d->ui->help->setContextMenuPolicy(Qt::NoContextMenu);
 }
 
-ImageScalingWidget::~ImageScalingWidget()
-{
-    delete d;
-}
+ImageScalingWidget::~ImageScalingWidget() = default;
 
 void ImageScalingWidget::slotHelpLinkClicked(const QString &)
 {
-    const QString help
-        = i18n("<qt>"
-               "<p>Here you can define image filename. "
-               "You can use:</p>"
-               "<ul>"
-               "<li>%t set current time</li>"
-               "<li>%d set current date</li>"
-               "<li>%n original filename</li>"
-               "<li>%e original extension</li>"
-               "<li>%x new extension</li>"
-               "</ul>"
-               "</qt>");
+    const QString help = i18n(
+        "<qt>"
+        "<p>Here you can define image filename. "
+        "You can use:</p>"
+        "<ul>"
+        "<li>%t set current time</li>"
+        "<li>%d set current date</li>"
+        "<li>%n original filename</li>"
+        "<li>%e original extension</li>"
+        "<li>%x new extension</li>"
+        "</ul>"
+        "</qt>");
 
     QWhatsThis::showText(QCursor::pos(), help);
 }
@@ -167,7 +168,7 @@ void ImageScalingWidget::slotRecipientFilterAbstractClicked(QAbstractButton *but
 
 void ImageScalingWidget::slotComboboxChanged(int index)
 {
-    QComboBox *combo = qobject_cast< QComboBox * >(sender());
+    auto combo = qobject_cast<QComboBox *>(sender());
     if (combo) {
         const bool isCustom = combo->itemData(index) == -1;
         if (combo == d->ui->CBMaximumWidth) {
@@ -185,9 +186,9 @@ void ImageScalingWidget::slotComboboxChanged(int index)
 
 void ImageScalingWidget::initComboBox(QComboBox *combo)
 {
-    const QVector<int> size = { 240, 320, 512, 640, 800, 1024, 1600, 2048 };
+    const QVector<int> size = {240, 320, 512, 640, 800, 1024, 1600, 2048};
     for (int val : size) {
-        combo->addItem(QString::number(val), val);
+        combo->addItem(QStringLiteral("%1 px").arg(QString::number(val)), val);
     }
     combo->addItem(i18n("Custom"), -1);
 }
@@ -200,7 +201,7 @@ void ImageScalingWidget::initWriteImageFormat()
         d->ui->WriteToImageFormat->addItem(QString::fromLatin1(format));
     }
     */
-    //known by several mailer.
+    // known by several mailer.
     d->ui->WriteToImageFormat->addItem(QStringLiteral("JPG"));
     d->ui->WriteToImageFormat->addItem(QStringLiteral("PNG"));
 }
