@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ ImageScalingTestWidget::ImageScalingTestWidget(QWidget *parent)
     lay->addWidget(new MessageComposer::ImageScalingWidget(this));
 }
 
-ImageScalingTestWidget::~ImageScalingTestWidget()
-{
-}
+ImageScalingTestWidget::~ImageScalingTestWidget() = default;
 
 int main(int argc, char **argv)
 {
