@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "attachmentvcardfromaddressbookjob.h"
+#include <Akonadi/ContactGroupExpandJob>
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 #include <KContacts/VCardConverter>
 #include <KLocalizedString>
-#include <akonadi/contact/contactgroupexpandjob.h>
 
 using namespace MessageComposer;
 
