@@ -7,12 +7,12 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef DISTRIBUTIONLISTEXPANDJOB_H
-#define DISTRIBUTIONLISTEXPANDJOB_H
+#pragma once
 
 #include <KJob>
 #include <QStringList>
-namespace MessageComposer {
+namespace MessageComposer
+{
 /**
  * @short A job to expand a distribution list to its member email addresses.
  */
@@ -54,9 +54,8 @@ private Q_SLOTS:
     void slotExpansionDone(KJob *);
 
 private:
-    QString mListName;
+    const QString mListName;
     QStringList mEmailAddresses;
     bool mIsEmpty = false;
 };
 }
-#endif
