@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ using namespace MessageComposer;
 class MessageComposer::PluginEditorPrivate
 {
 public:
-    PluginEditorPrivate()
-    {
-    }
+    PluginEditorPrivate() = default;
 
     int order = 0;
 };
