@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,7 +30,12 @@ class MESSAGECOMPOSER_EXPORT PluginEditorInterface : public PimCommon::AbstractG
 {
     Q_OBJECT
 public:
-    enum ApplyOnFieldType { Composer = 1, EmailFields = 2, SubjectField = 4, All = Composer | EmailFields | SubjectField };
+    enum ApplyOnFieldType {
+        Composer = 1,
+        EmailFields = 2,
+        SubjectField = 4,
+        All = Composer | EmailFields | SubjectField,
+    };
     Q_FLAG(ApplyOnFieldType)
     Q_DECLARE_FLAGS(ApplyOnFieldTypes, ApplyOnFieldType)
 
@@ -65,4 +70,3 @@ private:
     std::unique_ptr<PluginEditorInterfacePrivate> const d;
 };
 }
-
