@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ using namespace MessageComposer;
 class MessageComposer::PluginEditorBasePrivate
 {
 public:
-    PluginEditorBasePrivate()
-    {
-    }
+    PluginEditorBasePrivate() = default;
 
     bool mIsEnabled = false;
 };
