@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ using namespace MessageComposer;
 class MessageComposer::PluginEditorCheckBeforeSendInterfacePrivate
 {
 public:
-    PluginEditorCheckBeforeSendInterfacePrivate()
-    {
-    }
+    PluginEditorCheckBeforeSendInterfacePrivate() = default;
 
     MessageComposer::PluginEditorCheckBeforeSendParams parameters;
     QWidget *mParentWidget = nullptr;
@@ -25,10 +23,7 @@ PluginEditorCheckBeforeSendInterface::PluginEditorCheckBeforeSendInterface(QObje
 {
 }
 
-PluginEditorCheckBeforeSendInterface::~PluginEditorCheckBeforeSendInterface()
-{
-    delete d;
-}
+PluginEditorCheckBeforeSendInterface::~PluginEditorCheckBeforeSendInterface() = default;
 
 void PluginEditorCheckBeforeSendInterface::setParentWidget(QWidget *parent)
 {
@@ -52,5 +47,5 @@ MessageComposer::PluginEditorCheckBeforeSendParams PluginEditorCheckBeforeSendIn
 
 void PluginEditorCheckBeforeSendInterface::reloadConfig()
 {
-    //Reimplement it
+    // Reimplement it
 }
