@@ -1,29 +1,16 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORCHECKBEFORESENDPARAMS_H
-#define PLUGINEDITORCHECKBEFORESENDPARAMS_H
+#pragma once
 
 #include "messagecomposer_export.h"
 #include <QString>
-
-namespace MessageComposer {
+#include <memory>
+namespace MessageComposer
+{
 class PluginEditorCheckBeforeSendParamsPrivate;
 /**
  * @brief The PluginEditorCheckBeforeSendParams class
@@ -66,10 +53,10 @@ public:
     Q_REQUIRED_RESULT int transportId() const;
     void setTransportId(int id);
 
-    PluginEditorCheckBeforeSendParams &operator =(const PluginEditorCheckBeforeSendParams &other);
-    Q_REQUIRED_RESULT bool operator ==(const PluginEditorCheckBeforeSendParams &other) const;
+    PluginEditorCheckBeforeSendParams &operator=(const PluginEditorCheckBeforeSendParams &other);
+    Q_REQUIRED_RESULT bool operator==(const PluginEditorCheckBeforeSendParams &other) const;
+
 private:
-    PluginEditorCheckBeforeSendParamsPrivate *const d;
+    std::unique_ptr<PluginEditorCheckBeforeSendParamsPrivate> const d;
 };
 }
-#endif // PLUGINEDITORCHECKBEFORESENDPARAMS_H
