@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORCONVERTERBEFORECONVERTINGDATA_H
-#define PLUGINEDITORCONVERTERBEFORECONVERTINGDATA_H
+#pragma once
 
 #include "messagecomposer_export.h"
 #include <KMime/Message>
-namespace MessageComposer {
+namespace MessageComposer
+{
 /**
  * @brief The PluginEditorConverterBeforeConvertingData class
  * @author Laurent Montel <montel@kde.org>
@@ -30,5 +30,3 @@ private:
     bool mNewMessage = true;
 };
 }
-
-#endif // PLUGINEDITORCONVERTERBEFORECONVERTINGDATA_H
