@@ -15,10 +15,9 @@
 #include "recipientspicker.h"
 
 #include <KLocalizedString>
-#include <QPushButton>
-
-#include <QBoxLayout>
 #include <QLabel>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace MessageComposer;
 
@@ -26,7 +25,7 @@ RecipientsEditorSideWidget::RecipientsEditorSideWidget(RecipientsEditor *view, Q
     : QWidget(parent)
     , mEditor(view)
 {
-    QBoxLayout *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
     topLayout->setContentsMargins({});
     topLayout->addStretch(1);
@@ -52,9 +51,7 @@ RecipientsEditorSideWidget::RecipientsEditorSideWidget(RecipientsEditor *view, Q
     updateTotalToolTip();
 }
 
-RecipientsEditorSideWidget::~RecipientsEditorSideWidget()
-{
-}
+RecipientsEditorSideWidget::~RecipientsEditorSideWidget() = default;
 
 RecipientsPicker *RecipientsEditorSideWidget::picker() const
 {
