@@ -1,24 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_SENDLATERDIALOG_H
-#define MESSAGECOMPOSER_SENDLATERDIALOG_H
+#pragma once
 
-#include <QDialog>
 #include <QDateTime>
+#include <QDialog>
 
 #include "messagecomposer_export.h"
 
 class QCheckBox;
 class QPushButton;
-namespace Ui {
+namespace Ui
+{
 class SendLaterWidget;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class SendLaterInfo;
 
 /** Send later dialog. */
@@ -30,11 +31,11 @@ public:
         Unknown = 0,
         SendDeliveryAtTime = 1,
         Canceled = 2,
-        PutInOutbox = 3
+        PutInOutbox = 3,
     };
 
     explicit SendLaterDialog(SendLaterInfo *info, QWidget *parent = nullptr);
-    ~SendLaterDialog();
+    ~SendLaterDialog() override;
 
     SendLaterInfo *info();
 
@@ -52,9 +53,8 @@ private:
     QDateTime mSendDateTime;
     SendLaterAction mAction = Unknown;
     QCheckBox *mDelay = nullptr;
-    Ui::SendLaterWidget *mSendLaterWidget = nullptr;
+    Ui::SendLaterWidget *const mSendLaterWidget;
     SendLaterInfo *mInfo = nullptr;
     QPushButton *mOkButton = nullptr;
 };
 }
-#endif // SENDLATERDIALOG_H
