@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,12 @@ class MESSAGECOMPOSER_EXPORT SendLaterInfo
 public:
     explicit SendLaterInfo() = default;
 
-    enum RecurrenceUnit { Days = 0, Weeks, Months, Years };
+    enum RecurrenceUnit {
+        Days = 0,
+        Weeks,
+        Months,
+        Years,
+    };
 
     Q_REQUIRED_RESULT bool isValid() const;
 
@@ -66,4 +71,3 @@ private:
 }
 
 MESSAGECOMPOSER_EXPORT QDebug operator<<(QDebug debug, const MessageComposer::SendLaterInfo &info);
-
