@@ -1,21 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_SENDLATERTIMEDATEWIDGET_H
-#define MESSAGECOMPOSER_SENDLATERTIMEDATEWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include <QDateTime>
-
-#include <memory>
+#include <QWidget>
 
 class KTimeComboBox;
 class KDateComboBox;
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 /** Send later date/time widget. */
 class SendLaterTimeDateWidget : public QWidget
 {
@@ -33,9 +31,7 @@ Q_SIGNALS:
 
 private:
     void slotDateTimeChanged();
-    std::unique_ptr<KTimeComboBox> mTimeComboBox;
-    std::unique_ptr<KDateComboBox> mDateComboBox;
+    KTimeComboBox *const mTimeComboBox;
+    KDateComboBox *const mDateComboBox;
 };
 }
-
-#endif // MESSAGECOMPOSER_SENDLATERTIMEDATEWIDGET_H
