@@ -7,9 +7,9 @@
 #include "attachmentcompressjobtest.h"
 #include "qtest_messagecore.h"
 
-#include <QBuffer>
 #include "messagecore_debug.h"
 #include <KZip>
+#include <QBuffer>
 #include <QTest>
 
 #include <MessageCore/AttachmentCompressJob>
@@ -40,12 +40,12 @@ void AttachmentCompressJobTest::testCompress()
     QVERIFY(!origPart->isCompressed());
 
     // Compress the part and verify it.
-    auto *cjob = new AttachmentCompressJob(origPart, this);
+    auto cjob = new AttachmentCompressJob(origPart, this);
     VERIFYEXEC(cjob);
     QCOMPARE(cjob->originalPart(), origPart);
     AttachmentPart::Ptr zipPart = cjob->compressedPart();
-    //qCDebug(MESSAGECORE_LOG) << data;
-    //qCDebug(MESSAGECORE_LOG) << zipPart->data();
+    // qCDebug(MESSAGECORE_LOG) << data;
+    // qCDebug(MESSAGECORE_LOG) << zipPart->data();
     QVERIFY(zipPart->isAutoEncoding());
     QVERIFY(zipPart->isCompressed());
     QCOMPARE(zipPart->name(), QString(name + QString::fromLatin1(".zip")));
@@ -85,7 +85,7 @@ void AttachmentCompressJobTest::testCompressedSizeLarger()
     QVERIFY(!origPart->isCompressed());
 
     // Compress the part and verify that it is aware of its folly.
-    auto *cjob = new AttachmentCompressJob(origPart, this);
+    auto cjob = new AttachmentCompressJob(origPart, this);
     VERIFYEXEC(cjob);
     QVERIFY(cjob->isCompressedPartLarger());
 }
