@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ATTACHMENTFROMURLJOBTEST_H
-#define ATTACHMENTFROMURLJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -19,5 +18,3 @@ private Q_SLOTS:
     void testAttachmentTooBig();
     void testAttachmentCharset();
 };
-
-#endif
