@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -17,9 +17,7 @@ AttachmentUpdateJobTest::AttachmentUpdateJobTest(QObject *parent)
     qputenv("KDE_FORK_SLAVES", "yes"); // To avoid a runtime dependency on klauncher
 }
 
-AttachmentUpdateJobTest::~AttachmentUpdateJobTest()
-{
-}
+AttachmentUpdateJobTest::~AttachmentUpdateJobTest() = default;
 
 void AttachmentUpdateJobTest::shouldHaveDefaultValue()
 {
