@@ -1,37 +1,24 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "mailinglisttest.h"
-#include "misc/mailinglist.h"
-#include <QTest>
-#include <KConfigGroup>
 #include "messagecore_debug.h"
+#include "misc/mailinglist.h"
+#include <KConfigGroup>
 #include <KSharedConfig>
+#include <QTest>
 
-//TODO add test for static MailingList detect(  const KMime::Message::Ptr &message ); and static QString name( ... );
+// TODO add test for static MailingList detect(  const KMime::Message::Ptr &message ); and static QString name( ... );
 
 MailingListTest::MailingListTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-MailingListTest::~MailingListTest()
-{
-}
+MailingListTest::~MailingListTest() = default;
 
 void MailingListTest::shouldHaveDefaultValue()
 {
@@ -61,11 +48,11 @@ void MailingListTest::shouldRestoreFromSettings()
     lst << QUrl(QStringLiteral("mailto://www.kde4.org")) << QUrl(QStringLiteral("http://www.koffice4.org"));
     ml.setHelpUrls(lst);
     /* Note: mArchivedAtUrl deliberately not saved here as it refers to a single
-    * instance of a message rather than an element of a general mailing list.
-    * http://reviewboard.kde.org/r/1768/#review2783
-    */
-    //normal that we don't save it.
-    //ml.setArchivedAtUrls(lst);
+     * instance of a message rather than an element of a general mailing list.
+     * http://reviewboard.kde.org/r/1768/#review2783
+     */
+    // normal that we don't save it.
+    // ml.setArchivedAtUrls(lst);
     lst << QUrl(QStringLiteral("mailto://www.kde5.org")) << QUrl(QStringLiteral("http://www.koffice5.org"));
     ml.setArchiveUrls(lst);
     lst << QUrl(QStringLiteral("mailto://www.kde6.org")) << QUrl(QStringLiteral("http://www.koffice6.org"));
