@@ -8,8 +8,8 @@
 
 #include "nodehelper.h"
 
-#include <kmime/kmime_content.h>
-#include <kmime/kmime_message.h>
+#include <KMime/Content>
+#include <KMime/KMimeMessage>
 
 KMime::Content *MessageCore::NodeHelper::nextSibling(const KMime::Content *node)
 {
@@ -22,7 +22,7 @@ KMime::Content *MessageCore::NodeHelper::nextSibling(const KMime::Content *node)
     if (parent) {
         const auto contents = parent->contents();
         const int index = contents.indexOf(const_cast<KMime::Content *>(node)) + 1;
-        if (index < contents.size()) { //next on the same level
+        if (index < contents.size()) { // next on the same level
             next = contents.at(index);
         }
     }
@@ -42,8 +42,7 @@ KMime::Content *MessageCore::NodeHelper::next(KMime::Content *node, bool allowCh
         return sibling;
     }
 
-    for (KMime::Content *parent = node->parent(); parent;
-         parent = parent->parent()) {
+    for (KMime::Content *parent = node->parent(); parent; parent = parent->parent()) {
         if (KMime::Content *sibling = nextSibling(parent)) {
             return sibling;
         }
