@@ -40,9 +40,8 @@
 #include <QComboBox>
 #include <QMenu>
 
-
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <chrono>
 #include <core/widgets/filternamedialog.h>
 
@@ -254,7 +253,7 @@ QVector<Akonadi::MessageStatus> Widget::currentFilterStatus() const
     if (d->mFilter) {
         return d->mFilter->status();
     }
-    return QVector<Akonadi::MessageStatus>();
+    return {};
 }
 
 QString Widget::currentFilterSearchString() const
@@ -262,7 +261,7 @@ QString Widget::currentFilterSearchString() const
     if (d->mFilter) {
         return d->mFilter->searchString();
     }
-    return QString();
+    return {};
 }
 
 QString Widget::currentFilterTagId() const
@@ -271,7 +270,7 @@ QString Widget::currentFilterTagId() const
         return d->mFilter->tagId();
     }
 
-    return QString();
+    return {};
 }
 
 void Widget::WidgetPrivate::setDefaultAggregationForStorageModel(const StorageModel *storageModel)
@@ -823,7 +822,6 @@ void Widget::setFilter(Filter *filter)
 {
     resetFilter();
     d->mFilter = filter;
-    // TODO
     d->mView->model()->setFilter(d->mFilter);
 }
 
