@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
  SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -63,9 +63,7 @@ QuickSearchLine::QuickSearchLine(QWidget *parent)
     changeQuicksearchVisibility(MessageListSettings::self()->showQuickSearch());
 }
 
-QuickSearchLine::~QuickSearchLine()
-{
-}
+QuickSearchLine::~QuickSearchLine() = default;
 
 void QuickSearchLine::slotSearchEditTextEdited(const QString &text)
 {
