@@ -1,21 +1,24 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SEARCHLINESTATUS_H
-#define SEARCHLINESTATUS_H
+#pragma once
 
-#include <QLineEdit>
-#include <Akonadi/KMime/MessageStatus>
 #include "messagelist_private_export.h"
 #include "quicksearchline.h"
+#include <Akonadi/MessageStatus>
 #include <QIcon>
+#include <QLineEdit>
 class QStringListModel;
 class QAction;
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
+class FilterSavedMenu;
+class Filter;
 class MESSAGELIST_TESTS_EXPORT SearchLineStatus : public QLineEdit
 {
     Q_OBJECT
@@ -29,6 +32,8 @@ public:
     void setContainsOutboundMessages(bool containsOutboundMessages);
     Q_REQUIRED_RESULT bool containsOutboundMessages() const;
     Q_REQUIRED_RESULT QuickSearchLine::SearchOptions searchOptions() const;
+    void setSearchOptions(QuickSearchLine::SearchOptions opts);
+    void setFilterMessageStatus(const QVector<Akonadi::MessageStatus> &newLstStatus);
     void addCompletionItem(const QString &str);
     void slotClearHistory();
     void clearFilterButtonClicked();
@@ -37,16 +42,17 @@ Q_SIGNALS:
     void searchOptionChanged();
     void clearButtonClicked();
     void forceLostFocus();
+    void saveFilter();
+    void activateFilter(MessageList::Core::Filter *f);
 
 protected:
     void contextMenuEvent(QContextMenuEvent *e) override;
     void keyPressEvent(QKeyEvent *e) override;
 
-private Q_SLOTS:
+private:
     void slotToggledLockAction();
     void showMenu();
     void slotFilterActionClicked(QAction *act);
-private:
     void clearFilterAction();
     void createFilterAction(const QIcon &icon, const QString &text, int value);
     void createMenuSearch();
@@ -58,6 +64,9 @@ private:
     void clearFilterByAction();
     void changeSearchAgainstFromOrToText();
     void slotClear();
+    void showSavedFiltersMenu();
+    void slotConfigureFilters();
+    void slotActivateFilter(const QString &identifier);
 
     bool mLocked = false;
     bool mHasFilter = false;
@@ -65,20 +74,20 @@ private:
     QIcon mWithFilter;
     QAction *mLockAction = nullptr;
     QAction *mFiltersAction = nullptr;
+    QAction *mSaveFilterAction = nullptr;
     QMenu *mFilterMenu = nullptr;
-    QCompleter *mCompleter = nullptr;
+    QCompleter *const mCompleter;
     QList<QAction *> mFilterListActions;
     QAction *mSearchEveryWhereAction = nullptr;
     QAction *mSearchAgainstBodyAction = nullptr;
     QAction *mSearchAgainstSubjectAction = nullptr;
     QAction *mSearchAgainstFromOrToAction = nullptr;
     QAction *mSearchAgainstBccAction = nullptr;
-    QStringListModel *mCompleterListModel = nullptr;
+    QStringListModel *const mCompleterListModel;
+    FilterSavedMenu *mFilterSavedMenu = nullptr;
     QStringList mListCompetion;
     QString mColorName;
     bool mContainsOutboundMessages = false;
 };
 }
 }
-
-#endif // SEARCHLINESTATUS_H
