@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,9 +19,7 @@ TabLockedWarning::TabLockedWarning(QWidget *parent)
     connect(this, &TabLockedWarning::linkActivated, this, &TabLockedWarning::slotLinkActivated);
 }
 
-TabLockedWarning::~TabLockedWarning()
-{
-}
+TabLockedWarning::~TabLockedWarning() = default;
 
 void TabLockedWarning::slotLinkActivated(const QString &contents)
 {
