@@ -25,14 +25,14 @@
 #include <QTabBar>
 #include <QToolButton>
 
-#include "core/manager.h"
 #include "core/model.h"
 #include "core/widgets/quicksearchline.h"
 #include "messagelistsettings.h"
 #include "messagelistutil_p.h"
 #include "storagemodel.h"
 #include "widget.h"
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/MessageStatus>
 
 namespace MessageList
 {
@@ -60,7 +60,7 @@ public:
     void changeQuicksearchVisibility(bool);
     void addActivateTabAction(int i);
     void slotTabCloseRequested(int index);
-    QItemSelection mapSelectionFromSource(const QItemSelection &selection) const;
+    Q_REQUIRED_RESULT QItemSelection mapSelectionFromSource(const QItemSelection &selection) const;
     void updateTabControls();
 
     Pane *const q;
@@ -82,6 +82,7 @@ public:
     QAction *mActivatePreviousTabAction = nullptr;
     QAction *mMoveTabLeftAction = nullptr;
     QAction *mMoveTabRightAction = nullptr;
+    QString mQuickSearchPlaceHolderMessage;
     bool mPreferEmptyTab = false;
     int mMaxTabCreated = 0;
 };
@@ -99,7 +100,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     d->mSelectionModel = selectionModel;
 
     // Build the proxy stack
-    const QAbstractProxyModel *proxyModel = qobject_cast<const QAbstractProxyModel *>(d->mSelectionModel->model());
+    const auto *proxyModel = qobject_cast<const QAbstractProxyModel *>(d->mSelectionModel->model());
 
     while (proxyModel) {
         if (proxyModel == d->mModel) {
@@ -107,7 +108,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
         }
 
         d->mProxyStack << proxyModel;
-        const QAbstractProxyModel *nextProxyModel = qobject_cast<const QAbstractProxyModel *>(proxyModel->sourceModel());
+        const auto nextProxyModel = qobject_cast<const QAbstractProxyModel *>(proxyModel->sourceModel());
 
         if (!nextProxyModel) {
             // It's the final model in the chain, so it is necessarily the sourceModel.
@@ -162,7 +163,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
         d->updateTabControls();
     });
 
-    connect(this, &QTabWidget::tabBarDoubleClicked, this, &Pane::createNewTab);
+    // connect(this, &QTabWidget::tabBarDoubleClicked, this, &Pane::createNewTab);
 
     tabBar()->installEventFilter(this);
 }
@@ -479,10 +480,12 @@ void Pane::focusQuickSearch(const QString &selectedText)
 
 void Pane::setQuickSearchClickMessage(const QString &msg)
 {
-    auto w = static_cast<Widget *>(currentWidget());
-
-    if (w) {
-        w->setQuickSearchClickMessage(msg);
+    d->mQuickSearchPlaceHolderMessage = msg;
+    for (int i = 0; i < count(); ++i) {
+        auto w = qobject_cast<Widget *>(widget(i));
+        if (w) {
+            w->setQuickSearchClickMessage(d->mQuickSearchPlaceHolderMessage);
+        }
     }
 }
 
@@ -540,7 +543,11 @@ void Pane::PanePrivate::setCurrentFolder(const QModelIndex &etmIndex)
 
 void Pane::PanePrivate::activateTab()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     q->tabBar()->setCurrentIndex(q->sender()->objectName().rightRef(2).toInt() - 1);
+#else
+    q->tabBar()->setCurrentIndex(QStringView(q->sender()->objectName()).right(2).toInt() - 1);
+#endif
 }
 
 void Pane::PanePrivate::moveTabRight()
@@ -792,7 +799,9 @@ QItemSelectionModel *Pane::createNewTab()
     w->setXmlGuiClient(d->mXmlGuiClient);
 
     addTab(w, i18nc("@title:tab Empty messagelist", "Empty"));
-
+    if (!d->mQuickSearchPlaceHolderMessage.isEmpty()) {
+        w->setQuickSearchClickMessage(d->mQuickSearchPlaceHolderMessage);
+    }
     if (d->mXmlGuiClient && count() < 10) {
         if (d->mMaxTabCreated < count()) {
             d->mMaxTabCreated = count();
@@ -888,7 +897,7 @@ Akonadi::Item Pane::currentItem() const
     auto w = static_cast<Widget *>(currentWidget());
 
     if (!w) {
-        return Akonadi::Item();
+        return {};
     }
 
     return w->currentItem();
@@ -899,7 +908,7 @@ KMime::Message::Ptr Pane::currentMessage() const
     auto w = static_cast<Widget *>(currentWidget());
 
     if (!w) {
-        return KMime::Message::Ptr();
+        return {};
     }
 
     return w->currentMessage();
@@ -909,7 +918,7 @@ QVector<KMime::Message::Ptr> Pane::selectionAsMessageList(bool includeCollapsedC
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return QVector<KMime::Message::Ptr>();
+        return {};
     }
     return w->selectionAsMessageList(includeCollapsedChildren);
 }
@@ -918,7 +927,7 @@ Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildr
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return Akonadi::Item::List();
+        return {};
     }
     return w->selectionAsMessageItemList(includeCollapsedChildren);
 }
@@ -927,7 +936,7 @@ QVector<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedC
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return QVector<Akonadi::Item::Id>();
+        return {};
     }
     return w->selectionAsListMessageId(includeCollapsedChildren);
 }
@@ -936,7 +945,7 @@ QVector<qlonglong> Pane::selectionAsMessageItemListId(bool includeCollapsedChild
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return QVector<qlonglong>();
+        return {};
     }
     return w->selectionAsMessageItemListId(includeCollapsedChildren);
 }
@@ -945,7 +954,7 @@ Akonadi::Item::List Pane::currentThreadAsMessageList() const
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return Akonadi::Item::List();
+        return {};
     }
     return w->currentThreadAsMessageList();
 }
@@ -956,7 +965,7 @@ Akonadi::Item::List Pane::itemListFromPersistentSet(MessageList::Core::MessageIt
     if (w) {
         return w->itemListFromPersistentSet(ref);
     }
-    return Akonadi::Item::List();
+    return {};
 }
 
 void Pane::deletePersistentSet(MessageList::Core::MessageItemSetReference ref)
@@ -979,7 +988,7 @@ QVector<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 {
     auto w = static_cast<Widget *>(currentWidget());
     if (!w) {
-        return QVector<Akonadi::MessageStatus>();
+        return {};
     }
     return w->currentFilterStatus();
 }
@@ -999,7 +1008,7 @@ QString Pane::currentFilterSearchString() const
     if (w) {
         return w->currentFilterSearchString();
     }
-    return QString();
+    return {};
 }
 
 bool Pane::isThreaded() const
@@ -1124,16 +1133,18 @@ void Pane::writeConfig(bool restoreSession)
 
     if (restoreSession) {
         conf.writeEntry(QStringLiteral("currentIndex"), currentIndex());
-        conf.writeEntry(QStringLiteral("tabNumber"), count());
 
+        int elementTab = 0;
         for (int i = 0; i < count(); ++i) {
             auto w = qobject_cast<Widget *>(widget(i));
-            if (w) {
-                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
+            if (w && w->currentCollection().isValid()) {
+                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(elementTab));
                 grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
                 grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+                elementTab++;
             }
         }
+        conf.writeEntry(QStringLiteral("tabNumber"), elementTab);
     }
     conf.sync();
 }
@@ -1148,32 +1159,17 @@ void Pane::readConfig(bool restoreSession)
         } else {
             for (int i = 0; i < numberOfTab; ++i) {
                 createNewTab();
-                restoreHeaderSettings(i);
-                if (restoreSession) {
-#if 0 // TODO fix me
-                    Akonadi::Collection::Id id = grp.readEntry(QStringLiteral("collectionId"), -1);
-                    ETMViewStateSaver *saver = new ETMViewStateSaver;
-                    saver->setSelectionModel(selectionModel);
-
-                    if (id != -1) {
-                        ETMViewStateSaver *saver = new ETMViewStateSaver;
-                        saver->setSelectionModel(selectionModel);
-                        saver->restoreState(grp);
-                        saver->selectCollections(Akonadi::Collection::List() << Akonadi::Collection(id));
-                        saver->restoreCurrentItem(QString::fromLatin1("c%1").arg(id));
-                    }
-#endif
-                }
+                restoreHeaderSettings(i, restoreSession);
             }
             setCurrentIndex(conf.readEntry(QStringLiteral("currentIndex"), 0));
         }
     } else {
         createNewTab();
-        restoreHeaderSettings(0);
+        restoreHeaderSettings(0, false);
     }
 }
 
-void Pane::restoreHeaderSettings(int index)
+void Pane::restoreHeaderSettings(int index, bool restoreSession)
 {
     KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(index));
     if (grp.exists()) {
@@ -1181,6 +1177,16 @@ void Pane::restoreHeaderSettings(int index)
         if (w) {
             w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
         }
+        if (restoreSession) {
+            const Akonadi::Collection::Id id = grp.readEntry(QStringLiteral("collectionId"), -1);
+            if (id != -1) {
+                Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+                saver->setSelectionModel(d->mSelectionModel);
+                saver->selectCollections(Akonadi::Collection::List() << Akonadi::Collection(id));
+                saver->restoreCurrentItem(QString::fromLatin1("c%1").arg(id));
+                saver->restoreState(grp);
+            }
+        }
     }
 }
 
