@@ -12,10 +12,10 @@
 #include <messagelist/enums.h>
 #include <messagelist/view.h>
 
+#include "messagelist_export.h"
 #include <Akonadi/Collection>
 #include <Akonadi/Item>
 #include <KMime/KMimeMessage>
-#include <messagelist_export.h>
 
 class KXMLGUIClient;
 class QAbstractItemModel;
@@ -434,7 +434,7 @@ Q_SIGNALS:
     void forceLostFocus();
 
 private:
-    void restoreHeaderSettings(int index);
+    void restoreHeaderSettings(int index, bool restoreSession);
     void readConfig(bool restoreSession);
 
     bool eventFilter(QObject *obj, QEvent *event) override;
@@ -443,4 +443,3 @@ private:
     std::unique_ptr<PanePrivate> const d;
 };
 } // namespace MessageList
-
