@@ -1,47 +1,37 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_P_H
-#define MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_P_H
+#pragma once
 
 #include "utils/configurethemesdialog.h"
 class QListWidgetItem;
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class Theme;
 }
-namespace Utils {
+namespace Utils
+{
 class ThemeEditor;
 class ThemeListWidget;
 class ThemeListWidgetItem;
 
-class Q_DECL_HIDDEN ConfigureThemesDialog::Private
+class Q_DECL_HIDDEN ConfigureThemesDialog::ConfigureThemesDialogPrivate
 {
 public:
-    Private(ConfigureThemesDialog *owner)
+    ConfigureThemesDialogPrivate(ConfigureThemesDialog *owner)
         : q(owner)
     {
     }
 
     void fillThemeList();
-    QString uniqueNameForTheme(const QString &baseName, Core::Theme *skipTheme = nullptr);
+    Q_REQUIRED_RESULT QString uniqueNameForTheme(const QString &baseName, Core::Theme *skipTheme = nullptr);
     ThemeListWidgetItem *findThemeItemByName(const QString &name, Core::Theme *skipTheme = nullptr);
     ThemeListWidgetItem *findThemeItemByTheme(Core::Theme *set);
     ThemeListWidgetItem *findThemeItemById(const QString &themeId);
@@ -68,5 +58,3 @@ public:
 };
 } // namespace Utils
 } // namespace MessageList
-
-#endif //!__MESSAGELIST_UTILS_CONFIGURESKINSDIALOG_P_H
