@@ -8,12 +8,11 @@
 
 #include "utils/themeeditor.h"
 #include "core/groupheaderitem.h"
-#include "core/manager.h"
 #include "core/messageitem.h"
 #include "core/modelinvariantrowmapper.h"
 #include "utils/comboboxutils.h"
 
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 
 #include <KTextEdit>
 
@@ -42,7 +41,7 @@
 
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
-#include <time.h> // for time_t
+#include <ctime> // for time_t
 
 using namespace MessageList::Utils;
 using namespace MessageList::Core;
@@ -124,9 +123,7 @@ ThemeContentItemSourceLabel::ThemeContentItemSourceLabel(QWidget *parent, Theme:
     setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 }
 
-ThemeContentItemSourceLabel::~ThemeContentItemSourceLabel()
-{
-}
+ThemeContentItemSourceLabel::~ThemeContentItemSourceLabel() = default;
 
 MessageList::Core::Theme::ContentItem::Type ThemeContentItemSourceLabel::type() const
 {
@@ -267,13 +264,11 @@ void ThemePreviewWidget::changeEvent(QEvent *event)
     QTreeWidget::changeEvent(event);
 }
 
-ThemePreviewWidget::~ThemePreviewWidget()
-{
-}
+ThemePreviewWidget::~ThemePreviewWidget() = default;
 
 QSize ThemePreviewWidget::sizeHint() const
 {
-    return QSize(350, 180);
+    return {350, 180};
 }
 
 void ThemePreviewWidget::setReadOnly(bool readOnly)
@@ -1464,9 +1459,7 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     fillViewHeaderPolicyCombo();
 }
 
-ThemeEditor::~ThemeEditor()
-{
-}
+ThemeEditor::~ThemeEditor() = default;
 
 void ThemeEditor::editTheme(Theme *set)
 {
