@@ -6,16 +6,15 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_UTILS_THEMEEDITOR_H
-#define MESSAGELIST_UTILS_THEMEEDITOR_H
+#pragma once
 
-#include "utils/optionseteditor.h"
-#include "core/themedelegate.h"
 #include "core/theme.h"
+#include "core/themedelegate.h"
+#include "utils/optionseteditor.h"
 
-#include <QTreeWidget>
 #include <QLabel>
 #include <QRect>
+#include <QTreeWidget>
 
 #include <QDialog>
 
@@ -25,8 +24,10 @@ class QComboBox;
 class KPluralHandlingSpinBox;
 class QLineEdit;
 
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class Item;
 class GroupHeaderItem;
 class MessageItem;
@@ -34,7 +35,8 @@ class FakeItem;
 class ModelInvariantRowMapper;
 } // namespace Core
 
-namespace Utils {
+namespace Utils
+{
 class ThemeColumnPropertiesDialog : public QDialog
 {
     Q_OBJECT
@@ -42,7 +44,7 @@ public:
     explicit ThemeColumnPropertiesDialog(QWidget *parent, Core::Theme::Column *column, const QString &title);
 
 protected:
-    Core::Theme::Column *mColumn = nullptr;
+    Core::Theme::Column *const mColumn;
     QLineEdit *mNameEdit = nullptr;
     QCheckBox *mVisibleByDefaultCheck = nullptr;
     QCheckBox *mIsSenderOrReceiverCheck = nullptr;
@@ -57,12 +59,12 @@ class ThemePreviewDelegate : public Core::ThemeDelegate
     Q_OBJECT
 public:
     explicit ThemePreviewDelegate(QAbstractItemView *parent);
-    ~ThemePreviewDelegate();
+    ~ThemePreviewDelegate() override;
 
 private:
     Core::GroupHeaderItem *mSampleGroupHeaderItem = nullptr;
     Core::FakeItem *mSampleMessageItem = nullptr;
-    Core::ModelInvariantRowMapper *mRowMapper = nullptr;  // needed for the MessageItem above to be valid
+    Core::ModelInvariantRowMapper *mRowMapper = nullptr; // needed for the MessageItem above to be valid
 public:
     Core::Item *itemFromIndex(const QModelIndex &index) const override;
 };
@@ -72,31 +74,31 @@ class ThemePreviewWidget : public QTreeWidget
     Q_OBJECT
 public:
     explicit ThemePreviewWidget(QWidget *parent);
-    ~ThemePreviewWidget();
+    ~ThemePreviewWidget() override;
     void setReadOnly(bool readOnly);
 
 private:
     // DnD insert position stuff
 
     /**
-    * The row we'll be inserting the dragged item into
-    */
+     * The row we'll be inserting the dragged item into
+     */
     enum RowInsertPosition {
-        AboveRow,         ///< We'll insert above the currently hit row in mDelegate
-        InsideRow,        ///< We'll insert inside the currently hit row in mDelegate
-        BelowRow          ///< We'll insert below the currently hit row in mDelegate
+        AboveRow, ///< We'll insert above the currently hit row in mDelegate
+        InsideRow, ///< We'll insert inside the currently hit row in mDelegate
+        BelowRow ///< We'll insert below the currently hit row in mDelegate
     };
 
     /**
-    * The position in row that we'll be inserting the dragged item
-    */
+     * The position in row that we'll be inserting the dragged item
+     */
     enum ItemInsertPosition {
-        OnLeftOfItem,     ///< We'll insert on the left of the selected item
-        OnRightOfItem,    ///< We'll insert on the right of the selected item
-        AsLastLeftItem,   ///< We'll insert as last left item of the row (rightmost left item)
-        AsLastRightItem,  ///< We'll insert as last right item of the row (leftmost right item)
-        AsFirstLeftItem,  ///< We'll insert as first left item of the row (leftmost)
-        AsFirstRightItem  ///< We'll insert as first right item of the row (rightmost)
+        OnLeftOfItem, ///< We'll insert on the left of the selected item
+        OnRightOfItem, ///< We'll insert on the right of the selected item
+        AsLastLeftItem, ///< We'll insert as last left item of the row (rightmost left item)
+        AsLastRightItem, ///< We'll insert as last right item of the row (leftmost right item)
+        AsFirstLeftItem, ///< We'll insert as first left item of the row (leftmost)
+        AsFirstRightItem ///< We'll insert as first right item of the row (rightmost)
     };
 
 private:
@@ -106,13 +108,14 @@ private:
     Core::Theme::ContentItem *mSelectedThemeContentItem = nullptr;
     Core::Theme::Column *mSelectedThemeColumn = nullptr;
     QPoint mMouseDownPoint;
-    Core::Theme *mTheme;
+    Core::Theme *mTheme = nullptr;
     RowInsertPosition mRowInsertPosition;
     ItemInsertPosition mItemInsertPosition;
     QPoint mDropIndicatorPoint1;
     QPoint mDropIndicatorPoint2;
     bool mFirstShow;
     bool mReadOnly;
+
 public:
     QSize sizeHint() const override;
     void setTheme(Core::Theme *theme);
@@ -132,11 +135,11 @@ private:
     void internalHandleDragEnterEvent(QDragEnterEvent *e);
 
     /**
-    * Computes the drop insert position for the dragged item at position pos.
-    * Returns true if the dragged item can be inserted somewhere and
-    * false otherwise. Sets mRowInsertPosition, mItemInsertPosition,
-    * mDropIndicatorPoint1 ,mDropIndicatorPoint2.
-    */
+     * Computes the drop insert position for the dragged item at position pos.
+     * Returns true if the dragged item can be inserted somewhere and
+     * false otherwise. Sets mRowInsertPosition, mItemInsertPosition,
+     * mDropIndicatorPoint1 ,mDropIndicatorPoint2.
+     */
     bool computeContentItemInsertPosition(const QPoint &pos, Core::Theme::ContentItem::Type type);
 
     void applyThemeColumnWidths();
@@ -161,7 +164,7 @@ class ThemeContentItemSourceLabel : public QLabel
     Q_OBJECT
 public:
     ThemeContentItemSourceLabel(QWidget *parent, Core::Theme::ContentItem::Type type);
-    ~ThemeContentItemSourceLabel();
+    ~ThemeContentItemSourceLabel() override;
 
 public:
     Core::Theme::ContentItem::Type type() const;
@@ -181,14 +184,14 @@ class ThemeEditor : public OptionSetEditor
     Q_OBJECT
 public:
     explicit ThemeEditor(QWidget *parent);
-    ~ThemeEditor();
+    ~ThemeEditor() override;
 
 public:
     /**
-    * Sets the option set to be edited.
-    * Saves and forgets any previously option set that was being edited.
-    * The set parameter may be 0: in this case the editor is simply disabled.
-    */
+     * Sets the option set to be edited.
+     * Saves and forgets any previously option set that was being edited.
+     * The set parameter may be 0: in this case the editor is simply disabled.
+     */
     void editTheme(Core::Theme *set);
 
     Core::Theme *editedTheme() const;
@@ -207,7 +210,7 @@ protected Q_SLOTS:
 private:
     void setReadOnly(bool readOnly);
 
-    Core::Theme *mCurrentTheme = nullptr;  // shallow, may be null!
+    Core::Theme *mCurrentTheme = nullptr; // shallow, may be null!
 
     // Appearance tab
     ThemePreviewWidget *mPreviewWidget = nullptr;
@@ -218,5 +221,3 @@ private:
 };
 } // namespace Utils
 } // namespace MessageList
-
-#endif //!__MESSAGELIST_UTILS_SKINEDITOR_H
