@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,7 +7,9 @@
 #include "mailsourceviewtextbrowserwidgettest.h"
 #include "../src/findbar/findbarsourceview.h"
 #include "../src/widgets/mailsourceviewtextbrowserwidget.h"
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeechWidget>
+#endif
 #include <QTest>
 
 MailSourceViewTextBrowserWidgetTest::MailSourceViewTextBrowserWidgetTest(QObject *parent)
@@ -15,9 +17,7 @@ MailSourceViewTextBrowserWidgetTest::MailSourceViewTextBrowserWidgetTest(QObject
 {
 }
 
-MailSourceViewTextBrowserWidgetTest::~MailSourceViewTextBrowserWidgetTest()
-{
-}
+MailSourceViewTextBrowserWidgetTest::~MailSourceViewTextBrowserWidgetTest() = default;
 
 void MailSourceViewTextBrowserWidgetTest::shouldHaveDefaultValue()
 {
@@ -30,9 +30,11 @@ void MailSourceViewTextBrowserWidgetTest::shouldHaveDefaultValue()
     QVERIFY(findbar);
     QVERIFY(findbar->isHidden());
 
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     auto texttospeechwidget = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
     QVERIFY(texttospeechwidget);
     QVERIFY(texttospeechwidget->isHidden());
+#endif
 }
 
 QTEST_MAIN(MailSourceViewTextBrowserWidgetTest)
