@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,9 +8,9 @@
 #include "messageviewer/viewer.h"
 
 #include <KActionCollection>
-#include <QStandardPaths>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <QStandardPaths>
 #include <QTest>
 
 ViewerGrantleeThemeSupportTest::ViewerGrantleeThemeSupportTest(QObject *parent)
@@ -18,9 +18,7 @@ ViewerGrantleeThemeSupportTest::ViewerGrantleeThemeSupportTest(QObject *parent)
 {
 }
 
-ViewerGrantleeThemeSupportTest::~ViewerGrantleeThemeSupportTest()
-{
-}
+ViewerGrantleeThemeSupportTest::~ViewerGrantleeThemeSupportTest() = default;
 
 void ViewerGrantleeThemeSupportTest::initTestCase()
 {
@@ -34,8 +32,7 @@ void ViewerGrantleeThemeSupportTest::initTestCase()
 
 void ViewerGrantleeThemeSupportTest::shouldUpdateThemeMenu()
 {
-    MessageViewer::Viewer *viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(
-                                                                  this));
+    auto viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(this));
     viewer->show();
     QVERIFY(QTest::qWaitForWindowExposed(viewer));
 
