@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -10,9 +10,7 @@
 #include <QTest>
 #include <qtestmouse.h>
 
-ViewerTest::ViewerTest()
-{
-}
+ViewerTest::ViewerTest() = default;
 
 void ViewerTest::shouldHaveDefaultValuesOnCreation()
 {
