@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    Code based on ARHParser.jsm from dkim_verifier (Copyright (c) Philippe Lieser)
    (This software is licensed under the terms of the MIT License.)
@@ -21,5 +21,5 @@ void DKIMAuthenticationStatusInfoConverterTest::shouldHaveDefaultValues()
 {
     MessageViewer::DKIMAuthenticationStatusInfoConverter status;
     QVERIFY(status.convert().isEmpty());
-    QCOMPARE(status.statusInfo(), {});
+    QCOMPARE(status.statusInfo(), MessageViewer::DKIMAuthenticationStatusInfo());
 }
