@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMGENERATERULEJOBTEST_H
-#define DKIMGENERATERULEJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,7 @@ class DKIMGenerateRuleJobTest : public QObject
     Q_OBJECT
 public:
     explicit DKIMGenerateRuleJobTest(QObject *parent = nullptr);
-    ~DKIMGenerateRuleJobTest() = default;
+    ~DKIMGenerateRuleJobTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
-
-#endif // DKIMGENERATERULEJOBTEST_H
