@@ -1,14 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimcheckpolicyjob.h"
 #include "dkim-verify/dkimmanagerrules.h"
-#include "settings/messageviewersettings.h"
-#include "messageviewer_dkimcheckerdebug.h"
 #include "dkim-verify/dmarcmanager.h"
+#include "messageviewer_dkimcheckerdebug.h"
 
 using namespace MessageViewer;
 DKIMCheckPolicyJob::DKIMCheckPolicyJob(QObject *parent)
@@ -16,9 +15,7 @@ DKIMCheckPolicyJob::DKIMCheckPolicyJob(QObject *parent)
 {
 }
 
-DKIMCheckPolicyJob::~DKIMCheckPolicyJob()
-{
-}
+DKIMCheckPolicyJob::~DKIMCheckPolicyJob() = default;
 
 bool DKIMCheckPolicyJob::canStart() const
 {
@@ -39,7 +36,7 @@ bool DKIMCheckPolicyJob::start()
             deleteLater();
             return true;
         }
-        auto *job = new DMARCPolicyJob(this);
+        auto job = new DMARCPolicyJob(this);
         job->setEmailAddress(mEmailAddress);
         connect(job, &DMARCPolicyJob::result, this, &DKIMCheckPolicyJob::dmarcPolicyResult);
         if (!job->start()) {
@@ -65,7 +62,7 @@ void DKIMCheckPolicyJob::compareWithDefaultRules()
     for (const DKIMRule &rule : rules) {
         if (rule.enabled()) {
             if (rule.from() == mEmailAddress || rule.from() == QLatin1Char('*')) {
-                //Check SDID
+                // Check SDID
                 const QStringList signedDomainIdentifier = rule.signedDomainIdentifier();
                 for (const QString &ssid : signedDomainIdentifier) {
                     if (mCheckResult.sdid == ssid) {
@@ -78,10 +75,10 @@ void DKIMCheckPolicyJob::compareWithDefaultRules()
                             mCheckResult.status = DKIMCheckSignatureJob::DKIMStatus::NeedToBeSigned;
                             break;
                         case DKIMRule::RuleType::CanBeSigned:
-                            //Show a warning ?
+                            // Show a warning ?
                             break;
                         case DKIMRule::RuleType::IgnoreEmailNotSigned:
-                            //Nothing !
+                            // Nothing !
                             break;
                         }
                         break;
@@ -99,8 +96,9 @@ void DKIMCheckPolicyJob::dmarcPolicyResult(const MessageViewer::DMARCPolicyJob::
     if (value.isValid()) {
         if (mCheckResult.status == DKIMCheckSignatureJob::DKIMStatus::EmailNotSigned) {
             mCheckResult.status = DKIMCheckSignatureJob::DKIMStatus::NeedToBeSigned;
-            //qDebug() << " void DKIMCheckPolicyJob::dmarcPolicyResult(const MessageViewer::DMARCPolicyJob::DMARCResult &value)"<<value.mDomain << "value " << value.mSource;
-            //TODO verify it.
+            // qDebug() << " void DKIMCheckPolicyJob::dmarcPolicyResult(const MessageViewer::DMARCPolicyJob::DMARCResult &value)"<<value.mDomain << "value " <<
+            // value.mSource;
+            // TODO verify it.
             mCheckResult.sdid = value.mSource;
         }
     } else {
