@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,9 +27,7 @@ DKIMCheckSignatureJob::DKIMCheckSignatureJob(QObject *parent)
 {
 }
 
-DKIMCheckSignatureJob::~DKIMCheckSignatureJob()
-{
-}
+DKIMCheckSignatureJob::~DKIMCheckSignatureJob() = default;
 
 MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMCheckSignatureJob::createCheckResult() const
 {
@@ -168,9 +166,7 @@ void DKIMCheckSignatureJob::start()
     }
 
     // compare body hash
-    qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG)
-        << "resultHash " << resultHash << "mDkimInfo.bodyHash()"
-        << mDkimInfo.bodyHash();
+    qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "resultHash " << resultHash << "mDkimInfo.bodyHash()" << mDkimInfo.bodyHash();
     if (resultHash != mDkimInfo.bodyHash().toLatin1()) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << " Corrupted body hash";
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::CorruptedBodyHash;
@@ -425,8 +421,9 @@ void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString
         deleteLater();
         return;
     }
-    if (mDkimKeyRecord.keyType() != QLatin1String("rsa")) {
-        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "mDkimKeyRecord key type is unknown " << mDkimKeyRecord.keyType() << " str " << str;
+    const QString keyType{mDkimKeyRecord.keyType()};
+    if ((keyType != QLatin1String("rsa")) && (keyType != QLatin1String("ed25519"))) {
+        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "mDkimKeyRecord key type is unknown " << keyType << " str " << str;
         mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
         Q_EMIT result(createCheckResult());
         deleteLater();
@@ -449,6 +446,8 @@ void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString
             return;
         }
     }
+    // TODO add support for ed25119
+
     // check that the testing flag is not set
     if (mDkimKeyRecord.flags().contains(QLatin1String("y"))) {
         if (!mPolicy.verifySignatureWhenOnlyTest()) {
@@ -474,7 +473,29 @@ void DKIMCheckSignatureJob::parseDKIMKeyRecord(const QString &str, const QString
         Q_EMIT storeKey(str, domain, selector);
     }
 
-    verifyRSASignature();
+    verifySignature();
+}
+
+void DKIMCheckSignatureJob::verifySignature()
+{
+    const QString keyType{mDkimKeyRecord.keyType()};
+    if (keyType == QLatin1String("rsa")) {
+        verifyRSASignature();
+    } else if (keyType == QLatin1String("ed25519")) {
+        verifyEd25519Signature();
+    } else {
+        qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << " It's a bug " << keyType;
+    }
+}
+
+void DKIMCheckSignatureJob::verifyEd25519Signature()
+{
+    // TODO implement it.
+    qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "it's a Ed25519 signed email";
+    mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::PublicKeyConversionError;
+    mStatus = MessageViewer::DKIMCheckSignatureJob::DKIMStatus::Invalid;
+    Q_EMIT result(createCheckResult());
+    deleteLater();
 }
 
 void DKIMCheckSignatureJob::verifyRSASignature()
@@ -491,7 +512,7 @@ void DKIMCheckSignatureJob::verifyRSASignature()
         deleteLater();
         return;
     } else {
-      qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
+        qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
     }
     QCA::RSAPublicKey rsaPublicKey = publicKey.toRSA();
     // qDebug() << "publicKey.modulus" << rsaPublicKey.n().toString();
