@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ DKIMGenerateRuleJob::DKIMGenerateRuleJob(QObject *parent)
 {
 }
 
-DKIMGenerateRuleJob::~DKIMGenerateRuleJob()
-{
-}
+DKIMGenerateRuleJob::~DKIMGenerateRuleJob() = default;
 
 bool DKIMGenerateRuleJob::canStart() const
 {
@@ -43,7 +41,7 @@ void DKIMGenerateRuleJob::verifyAndGenerateRule()
     DKIMRule rule;
     rule.setEnabled(true);
     rule.setFrom(mResult.fromEmail);
-    //TODO add Domain when we create a rule from base domain.
+    // TODO add Domain when we create a rule from base domain.
     rule.setSignedDomainIdentifier(QStringList() << mResult.sdid);
     rule.setRuleType(DKIMRule::RuleType::MustBeSigned);
     deleteLater();
