@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,12 +9,11 @@
 
 using namespace MessageViewer;
 
-DKIMKeyRecord::DKIMKeyRecord()
-{
-}
+DKIMKeyRecord::DKIMKeyRecord() = default;
 
 bool DKIMKeyRecord::parseKey(const QString &key)
 {
+    qDebug() << " key " << key;
     QString newKey = key;
     if (newKey.isEmpty()) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Error: trying to parse empty key";
