@@ -1,14 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef DKIMMANAGERULESDIALOG_H
-#define DKIMMANAGERULESDIALOG_H
+#pragma once
 
-#include <QDialog>
 #include "messageviewer_export.h"
-namespace MessageViewer {
+#include <QDialog>
+
+class QPushButton;
+namespace MessageViewer
+{
 class DKIMManageRulesWidget;
 /**
  * @brief The DKIMManageRulesDialog class
@@ -19,7 +21,7 @@ class MESSAGEVIEWER_EXPORT DKIMManageRulesDialog : public QDialog
     Q_OBJECT
 public:
     explicit DKIMManageRulesDialog(QWidget *parent = nullptr);
-    ~DKIMManageRulesDialog();
+    ~DKIMManageRulesDialog() override;
 
 private:
     void slotAccepted();
@@ -27,8 +29,7 @@ private:
     void writeConfig();
     void slotImport();
     void slotExport();
-    DKIMManageRulesWidget *mRulesWidget = nullptr;
+    DKIMManageRulesWidget *const mRulesWidget;
+    QPushButton *const mExportButton;
 };
 }
-
-#endif // DKIMMANAGERULESDIALOG_H
