@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,6 +17,7 @@
 #include <QPointer>
 #include <QTreeWidget>
 #include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 using namespace MessageViewer;
 DKIMManageRulesWidgetItem::DKIMManageRulesWidgetItem(QTreeWidget *parent)
     : QTreeWidgetItem(parent)
@@ -25,9 +26,7 @@ DKIMManageRulesWidgetItem::DKIMManageRulesWidgetItem(QTreeWidget *parent)
     treeWidget()->setItemWidget(this, ColumnType::RuleType, mRuleTypeCombobox);
 }
 
-DKIMManageRulesWidgetItem::~DKIMManageRulesWidgetItem()
-{
-}
+DKIMManageRulesWidgetItem::~DKIMManageRulesWidgetItem() = default;
 
 MessageViewer::DKIMRule DKIMManageRulesWidgetItem::rule() const
 {
@@ -90,11 +89,9 @@ DKIMManageRulesWidget::DKIMManageRulesWidget(QWidget *parent)
     });
 }
 
-DKIMManageRulesWidget::~DKIMManageRulesWidget()
-{
-}
+DKIMManageRulesWidget::~DKIMManageRulesWidget() = default;
 
-void DKIMManageRulesWidget::loadSettings()
+void DKIMManageRulesWidget::updateRules()
 {
     const QVector<MessageViewer::DKIMRule> rules = MessageViewer::DKIMManagerRules::self()->rules();
 
@@ -102,10 +99,16 @@ void DKIMManageRulesWidget::loadSettings()
         auto item = new DKIMManageRulesWidgetItem(mTreeWidget);
         item->setRule(rule);
     }
+    emitUpdateExportButton();
+}
+
+void DKIMManageRulesWidget::loadSettings()
+{
     mTreeWidget->setSortingEnabled(true);
     mTreeWidget->header()->setSortIndicatorShown(true);
     mTreeWidget->header()->setSectionsClickable(true);
     mTreeWidget->sortByColumn(0, Qt::AscendingOrder);
+    updateRules();
 }
 
 QVector<MessageViewer::DKIMRule> DKIMManageRulesWidget::rules() const
@@ -144,6 +147,7 @@ void DKIMManageRulesWidget::addRule()
         if (rule.isValid()) {
             auto item = new DKIMManageRulesWidgetItem(mTreeWidget);
             item->setRule(rule);
+            emitUpdateExportButton();
         } else {
             qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Rule is not valid";
         }
@@ -160,11 +164,17 @@ void DKIMManageRulesWidget::duplicateRule(DKIMManageRulesWidgetItem *rulesItem)
         if (rule.isValid()) {
             auto item = new DKIMManageRulesWidgetItem(mTreeWidget);
             item->setRule(rule);
+            emitUpdateExportButton();
         }
     }
     delete dlg;
 }
 
+void DKIMManageRulesWidget::emitUpdateExportButton()
+{
+    Q_EMIT updateExportButton(mTreeWidget->topLevelItemCount() > 0);
+}
+
 void DKIMManageRulesWidget::modifyRule(DKIMManageRulesWidgetItem *rulesItem)
 {
     QPointer<DKIMRuleDialog> dlg = new DKIMRuleDialog(this);
@@ -196,26 +206,44 @@ void DKIMManageRulesWidget::slotCustomContextMenuRequested(const QPoint &pos)
         });
         menu.addSeparator();
         menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove Rule"), this, [this, item]() {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            const int answer = KMessageBox::warningTwoActions(this,
+#else
             const int answer = KMessageBox::warningYesNo(this,
-                                                         i18n("Do you want to delete this rule?"),
-                                                         i18n("Delete Rule"),
-                                                         KStandardGuiItem::del(),
-                                                         KStandardGuiItem::cancel());
+#endif
+                                                              i18n("Do you want to delete this rule?"),
+                                                              i18n("Delete Rule"),
+                                                              KStandardGuiItem::del(),
+                                                              KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (answer == KMessageBox::Yes) {
+#endif
                 delete item;
+                emitUpdateExportButton();
             }
         });
     }
     if (mTreeWidget->topLevelItemCount() > 0) {
         menu.addSeparator();
         menu.addAction(i18n("Delete All"), this, [this]() {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            const int answer = KMessageBox::warningTwoActions(this,
+#else
             const int answer = KMessageBox::warningYesNo(this,
-                                                         i18n("Do you want to delete all the rules?"),
-                                                         i18n("Delete Rules"),
-                                                         KStandardGuiItem::del(),
-                                                         KStandardGuiItem::cancel());
+#endif
+                                                              i18n("Do you want to delete all the rules?"),
+                                                              i18n("Delete Rules"),
+                                                              KStandardGuiItem::del(),
+                                                              KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (answer == KMessageBox::Yes) {
+#endif
                 mTreeWidget->clear();
+                emitUpdateExportButton();
             }
         });
     }
