@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,7 @@
 #include "dkimrule.h"
 
 using namespace MessageViewer;
-DKIMRule::DKIMRule()
-{
-}
+DKIMRule::DKIMRule() = default;
 
 QString DKIMRule::domain() const
 {
@@ -78,13 +76,8 @@ void DKIMRule::setListId(const QString &listId)
 
 bool DKIMRule::operator==(const DKIMRule &other) const
 {
-    if (other.domain() == mDomain
-        && other.signedDomainIdentifier() == mSignedDomainIdentifier
-        && other.from() == mFrom
-        && other.listId() == mListId
-        && other.ruleType() == mRuleType
-        && other.enabled() == mEnabled
-        && other.priority() == mPriority) {
+    if (other.domain() == mDomain && other.signedDomainIdentifier() == mSignedDomainIdentifier && other.from() == mFrom && other.listId() == mListId
+        && other.ruleType() == mRuleType && other.enabled() == mEnabled && other.priority() == mPriority) {
         return true;
     }
     return false;
@@ -105,14 +98,14 @@ void DKIMRule::setPriority(int priority)
     mPriority = priority;
 }
 
-QDebug operator <<(QDebug d, const DKIMRule &t)
+QDebug operator<<(QDebug d, const DKIMRule &t)
 {
-    d << "mDomain: " << t.domain();
-    d << "mSignedDomainIdentifier: " << t.signedDomainIdentifier();
-    d << "mFrom: " << t.from();
-    d << "mEnabled: " << t.enabled();
-    d << "mRuleType " << t.ruleType();
-    d << "mListId " << t.listId();
-    d << "mPriority " << t.priority();
+    d << " mDomain: " << t.domain();
+    d << " mSignedDomainIdentifier: " << t.signedDomainIdentifier();
+    d << " mFrom: " << t.from();
+    d << " mEnabled: " << t.enabled();
+    d << " mRuleType " << t.ruleType();
+    d << " mListId " << t.listId();
+    d << " mPriority " << t.priority();
     return d;
 }
