@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -60,9 +60,7 @@ DKIMRuleWidget::DKIMRuleWidget(QWidget *parent)
     layout->addRow(i18n("Priority:"), mPriority);
 }
 
-DKIMRuleWidget::~DKIMRuleWidget()
-{
-}
+DKIMRuleWidget::~DKIMRuleWidget() = default;
 
 void DKIMRuleWidget::updateOkButton()
 {
