@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimviewermenu.h"
-#include <QMenu>
 #include <KLocalizedString>
+#include <QMenu>
 
 using namespace MessageViewer;
 DKIMViewerMenu::DKIMViewerMenu(QObject *parent)
     : QObject(parent)
+    , mMenu(new QMenu(i18n("DKIM")))
 {
     initialize();
 }
@@ -32,13 +33,13 @@ void DKIMViewerMenu::setEnableUpdateDkimKeyMenu(bool enabled)
 
 void DKIMViewerMenu::initialize()
 {
-    mMenu = new QMenu(i18n("DKIM"));
     QAction *checkSignature = mMenu->addAction(i18n("Recheck DKIM Signature"));
     connect(checkSignature, &QAction::triggered, this, &DKIMViewerMenu::recheckSignature);
 
     mUpdateDKIMKey = mMenu->addAction(i18n("Update DKIM key"));
     connect(mUpdateDKIMKey, &QAction::triggered, this, &DKIMViewerMenu::updateDkimKey);
 
+    mMenu->addSeparator();
     QAction *manageDKIMRuleDKIMKey = mMenu->addAction(i18n("Rules..."));
     connect(manageDKIMRuleDKIMKey, &QAction::triggered, this, &DKIMViewerMenu::showDkimRules);
 }
