@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,15 +10,13 @@
 #include <QDnsLookup>
 
 using namespace MessageViewer;
-//see https://tools.ietf.org/html/rfc7489
+// see https://tools.ietf.org/html/rfc7489
 DMARCRecordJob::DMARCRecordJob(QObject *parent)
     : QObject(parent)
 {
 }
 
-DMARCRecordJob::~DMARCRecordJob()
-{
-}
+DMARCRecordJob::~DMARCRecordJob() = default;
 
 bool DMARCRecordJob::start()
 {
@@ -28,8 +26,7 @@ bool DMARCRecordJob::start()
         return false;
     }
     mDnsLookup = new QDnsLookup(this);
-    connect(mDnsLookup, &QDnsLookup::finished,
-            this, &DMARCRecordJob::resolvDnsDone);
+    connect(mDnsLookup, &QDnsLookup::finished, this, &DMARCRecordJob::resolvDnsDone);
 
     mDnsLookup->setType(QDnsLookup::TXT);
     mDnsLookup->setName(resolvDnsValue());
