@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -20,11 +20,7 @@ public:
     ~FindBarSourceView() override;
 
 private:
-    explicit FindBarSourceView(QWidget *parent)
-        : mView(nullptr)
-    {
-        Q_UNUSED(parent)
-    }
+    FindBarSourceView(QWidget *parent) = delete;
 
     void clearSelections() override;
     void searchText(bool backward, bool isAutoSearch) override;
@@ -35,4 +31,3 @@ private:
     QPlainTextEdit *const mView;
 };
 }
-
