@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
-#ifndef GRANTLEEHEADERFORMATTERTEST_H
-#define GRANTLEEHEADERFORMATTERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -19,5 +18,3 @@ private Q_SLOTS:
     void testBlock_data();
     void testBlock();
 };
-
-#endif
