@@ -1,56 +1,52 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "grantleeheaderformatter.h"
+#include "config-messageviewer.h"
 #include "headerstyle_util.h"
-#include "grantleetheme/grantleetheme.h"
 #include "settings/messageviewersettings.h"
 #include "utils/iconnamecache.h"
-#include "config-messageviewer.h"
 
 #include <MessageCore/StringUtil>
 #include <MimeTreeParser/NodeHelper>
 
-#include <kmime/kmime_message.h>
-#include <kmime/kmime_dateformatter.h>
+#include <KMime/DateFormatter>
+#include <KMime/KMimeMessage>
 
-#include <KLocalizedString>
-#include <KIconLoader>
 #include <KColorScheme>
-
+#include <KIconLoader>
+#include <KLocalizedString>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/engine.h>
 #include <grantlee/metatype.h>
-#include <grantlee/templateloader.h>
+#else
+#include <KTextTemplate/engine.h>
+#include <KTextTemplate/metatype.h>
+#endif
 
 using namespace MessageCore;
 
 using namespace MessageViewer;
 
 Q_DECLARE_METATYPE(const KMime::Headers::Generics::AddressList *)
+Q_DECLARE_METATYPE(QSharedPointer<KMime::Headers::Generics::AddressList>)
 Q_DECLARE_METATYPE(const KMime::Headers::Generics::MailboxList *)
 Q_DECLARE_METATYPE(QSharedPointer<KMime::Headers::Generics::MailboxList>)
 Q_DECLARE_METATYPE(QDateTime)
 
 // Read-only introspection of KMime::Headers::Generics::AddressList object.
-namespace Grantlee {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+namespace Grantlee
+#else
+namespace KTextTemplate
+#endif
+{
 template<>
-inline QVariant TypeAccessor<const KMime::Headers::Generics::AddressList *>::lookUp(const KMime::Headers::Generics::AddressList *const object, const QString &property)
+inline QVariant TypeAccessor<const KMime::Headers::Generics::AddressList *>::lookUp(const KMime::Headers::Generics::AddressList *const object,
+                                                                                    const QString &property)
 {
     if (property == QLatin1String("nameOnly")) {
         return StringUtil::emailAddrAsAnchor(object, StringUtil::DisplayNameOnly);
@@ -62,44 +58,22 @@ inline QVariant TypeAccessor<const KMime::Headers::Generics::AddressList *>::loo
         return object->asUnicodeString();
     } else if (property.startsWith(QLatin1String("expandable"))) {
         const auto &name = property.mid(10);
-        const QString val = MessageCore::StringUtil::emailAddrAsAnchor(
-            object, MessageCore::StringUtil::DisplayFullAddress,
-            QString(), MessageCore::StringUtil::ShowLink,
-            MessageCore::StringUtil::ExpandableAddresses,
-            QStringLiteral("Full") + name + QStringLiteral("AddressList"));
+        const QString val = MessageCore::StringUtil::emailAddrAsAnchor(object,
+                                                                       MessageCore::StringUtil::DisplayFullAddress,
+                                                                       QString(),
+                                                                       MessageCore::StringUtil::ShowLink,
+                                                                       MessageCore::StringUtil::ExpandableAddresses,
+                                                                       QStringLiteral("Full") + name + QStringLiteral("AddressList"));
         return val;
     }
-    return QVariant();
+    return {};
 }
 }
-
-// Read-only introspection of KMime::Headers::Generics::MailboxList object.
-namespace Grantlee {
-template<>
-inline QVariant TypeAccessor<const KMime::Headers::Generics::MailboxList *>::lookUp(const KMime::Headers::Generics::MailboxList *const object, const QString &property)
-{
-    if (property == QLatin1String("nameOnly")) {
-        return StringUtil::emailAddrAsAnchor(object, StringUtil::DisplayNameOnly);
-    } else if (property == QLatin1String("isSet")) {
-        return !object->asUnicodeString().isEmpty();
-    } else if (property == QLatin1String("fullAddress")) {
-        return StringUtil::emailAddrAsAnchor(object, StringUtil::DisplayFullAddress);
-    } else if (property == QLatin1String("str")) {
-        return object->asUnicodeString();
-    } else if (property.startsWith(QLatin1String("expandable"))) {
-        const auto &name = property.mid(10);
-        const QString val = MessageCore::StringUtil::emailAddrAsAnchor(
-            object, MessageCore::StringUtil::DisplayFullAddress,
-            QString(), MessageCore::StringUtil::ShowLink,
-            MessageCore::StringUtil::ExpandableAddresses,
-            QStringLiteral("Full") + name + QStringLiteral("AddressList"));
-        return val;
-    }
-    return QVariant();
-}
-}
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 GRANTLEE_BEGIN_LOOKUP(QSharedPointer<KMime::Headers::Generics::MailboxList>)
+#else
+KTEXTTEMPLATE_BEGIN_LOOKUP(QSharedPointer<KMime::Headers::Generics::MailboxList>)
+#endif
 if (property == QLatin1String("nameOnly")) {
     return StringUtil::emailAddrAsAnchor(object.data(), StringUtil::DisplayNameOnly);
 } else if (property == QLatin1String("isSet")) {
@@ -110,16 +84,86 @@ if (property == QLatin1String("nameOnly")) {
     return object->asUnicodeString();
 } else if (property.startsWith(QLatin1String("expandable"))) {
     const auto &name = property.mid(10);
-    const QString val = MessageCore::StringUtil::emailAddrAsAnchor(
-        object.data(), MessageCore::StringUtil::DisplayFullAddress,
-        QString(), MessageCore::StringUtil::ShowLink,
-        MessageCore::StringUtil::ExpandableAddresses,
-        QStringLiteral("Full") + name + QStringLiteral("AddressList"));
+    const QString val = MessageCore::StringUtil::emailAddrAsAnchor(object.data(),
+                                                                   MessageCore::StringUtil::DisplayFullAddress,
+                                                                   QString(),
+                                                                   MessageCore::StringUtil::ShowLink,
+                                                                   MessageCore::StringUtil::ExpandableAddresses,
+                                                                   QStringLiteral("Full") + name + QStringLiteral("AddressList"));
     return val;
 }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 GRANTLEE_END_LOOKUP
+#else
+KTEXTTEMPLATE_END_LOOKUP
+#endif
 
-namespace Grantlee {
+// Read-only introspection of KMime::Headers::Generics::MailboxList object.
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+namespace Grantlee
+#else
+namespace KTextTemplate
+#endif
+{
+template<>
+inline QVariant TypeAccessor<const KMime::Headers::Generics::MailboxList *>::lookUp(const KMime::Headers::Generics::MailboxList *const object,
+                                                                                    const QString &property)
+{
+    if (property == QLatin1String("nameOnly")) {
+        return StringUtil::emailAddrAsAnchor(object, StringUtil::DisplayNameOnly);
+    } else if (property == QLatin1String("isSet")) {
+        return !object->asUnicodeString().isEmpty();
+    } else if (property == QLatin1String("fullAddress")) {
+        return StringUtil::emailAddrAsAnchor(object, StringUtil::DisplayFullAddress);
+    } else if (property == QLatin1String("str")) {
+        return object->asUnicodeString();
+    } else if (property.startsWith(QLatin1String("expandable"))) {
+        const auto &name = property.mid(10);
+        const QString val = MessageCore::StringUtil::emailAddrAsAnchor(object,
+                                                                       MessageCore::StringUtil::DisplayFullAddress,
+                                                                       QString(),
+                                                                       MessageCore::StringUtil::ShowLink,
+                                                                       MessageCore::StringUtil::ExpandableAddresses,
+                                                                       QStringLiteral("Full") + name + QStringLiteral("AddressList"));
+        return val;
+    }
+    return {};
+}
+}
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+GRANTLEE_BEGIN_LOOKUP(QSharedPointer<KMime::Headers::Generics::AddressList>)
+#else
+KTEXTTEMPLATE_BEGIN_LOOKUP(QSharedPointer<KMime::Headers::Generics::AddressList>)
+#endif
+if (property == QLatin1String("nameOnly")) {
+    return StringUtil::emailAddrAsAnchor(object.data(), StringUtil::DisplayNameOnly);
+} else if (property == QLatin1String("isSet")) {
+    return !object->asUnicodeString().isEmpty();
+} else if (property == QLatin1String("fullAddress")) {
+    return StringUtil::emailAddrAsAnchor(object.data(), StringUtil::DisplayFullAddress);
+} else if (property == QLatin1String("str")) {
+    return object->asUnicodeString();
+} else if (property.startsWith(QLatin1String("expandable"))) {
+    const auto &name = property.mid(10);
+    const QString val = MessageCore::StringUtil::emailAddrAsAnchor(object.data(),
+                                                                   MessageCore::StringUtil::DisplayFullAddress,
+                                                                   QString(),
+                                                                   MessageCore::StringUtil::ShowLink,
+                                                                   MessageCore::StringUtil::ExpandableAddresses,
+                                                                   QStringLiteral("Full") + name + QStringLiteral("AddressList"));
+    return val;
+}
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+GRANTLEE_END_LOOKUP
+#else
+KTEXTTEMPLATE_END_LOOKUP
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+namespace Grantlee
+#else
+namespace KTextTemplate
+#endif
+{
 template<>
 inline QVariant TypeAccessor<QDateTime &>::lookUp(const QDateTime &object, const QString &property)
 {
@@ -137,7 +181,7 @@ inline QVariant TypeAccessor<QDateTime &>::lookUp(const QDateTime &object, const
     } else if (property == QLatin1String("localelong")) {
         dateFormat = MessageViewer::HeaderStyleUtil::LongDate;
     } else {
-        return QVariant();
+        return {};
     }
 
     return HeaderStyleUtil::strToHtml(HeaderStyleUtil::dateString(object, dateFormat));
@@ -147,11 +191,9 @@ inline QVariant TypeAccessor<QDateTime &>::lookUp(const QDateTime &object, const
 class Q_DECL_HIDDEN HeaderFormatter
 {
 public:
-    virtual ~HeaderFormatter()
-    {
-    }
+    virtual ~HeaderFormatter() = default;
 
-    virtual QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper) = 0;
+    virtual QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper, bool showEmoticons) = 0;
     virtual QString i18nName() = 0;
 };
 
@@ -168,12 +210,13 @@ public:
         if (header == "list-id") {
             return i18n("List-Id:");
         } else {
-            return QString();
+            return {};
         }
     }
 
-    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper) override
+    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper, bool showEmoticons) override
     {
+        Q_UNUSED(showEmoticons);
         return nodeHelper->mailHeaderAsBase(header.constData(), message)->asUnicodeString();
     }
 
@@ -189,14 +232,13 @@ public:
         return i18n("Subject:");
     }
 
-    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper) override
+    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper, bool showEmoticons) override
     {
         KTextToHTML::Options flags = KTextToHTML::PreserveSpaces;
-        // TODO: somehow, we need to get settings from format method.
-        //if (showEmoticons) {
-        //    flags |= KTextToHTML::ReplaceSmileys;
-        //}
-        auto subjectStr = nodeHelper->mailHeaderAsBase("subject", message)->asUnicodeString();
+        if (showEmoticons) {
+            flags |= KTextToHTML::ReplaceSmileys;
+        }
+        const auto subjectStr = nodeHelper->mailHeaderAsBase("subject", message)->asUnicodeString();
 
         return HeaderStyleUtil::strToHtml(subjectStr, flags);
     }
@@ -210,8 +252,9 @@ public:
         return i18n("Date:");
     }
 
-    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper) override
+    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper, bool showEmoticons) override
     {
+        Q_UNUSED(showEmoticons);
         const auto value = nodeHelper->dateHeader(message);
         return value;
     }
@@ -231,8 +274,6 @@ public:
             return i18n("To:");
         } else if (header == "reply-To") {
             return i18n("Reply To:");
-        } else if (header == "replyFrom") {
-            return i18n("Reply From:");
         } else if (header == "cc") {
             return i18n("CC:");
         } else if (header == "bcc") {
@@ -246,39 +287,63 @@ public:
         } else if (header == "resent-To") {
             return i18n("resent to:");
         } else {
-            return QString();
+            return {};
         }
     }
 
-    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper) override
+    QVariant format(KMime::Message *message, MimeTreeParser::NodeHelper *nodeHelper, bool showEmoticons) override
     {
+        Q_UNUSED(showEmoticons);
         const auto value = nodeHelper->mailHeaderAsAddressList(header.constData(), message);
-        return QVariant::fromValue(static_cast<const KMime::Headers::Generics::AddressList *>(value));
+        return QVariant::fromValue(value);
     }
 
 protected:
     QByteArray header;
 };
 
-class Q_DECL_HIDDEN MessageViewer::GrantleeHeaderFormatter::Private
+class MessageViewer::GrantleeHeaderFormatter::GrantleeHeaderFormatterPrivate
 {
 public:
-    Private()
+    GrantleeHeaderFormatterPrivate()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        : engine(new Grantlee::Engine)
+#else
+        : engine(new KTextTemplate::Engine)
+#endif
     {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         Grantlee::registerMetaType<const KMime::Headers::Generics::AddressList *>();
         Grantlee::registerMetaType<const KMime::Headers::Generics::MailboxList *>();
-        Grantlee::registerMetaType<QSharedPointer<KMime::Headers::Generics::MailboxList> >();
+        Grantlee::registerMetaType<QSharedPointer<KMime::Headers::Generics::MailboxList>>();
+        Grantlee::registerMetaType<QSharedPointer<KMime::Headers::Generics::AddressList>>();
         Grantlee::registerMetaType<QDateTime>();
+#else
+        KTextTemplate::registerMetaType<const KMime::Headers::Generics::AddressList *>();
+        KTextTemplate::registerMetaType<const KMime::Headers::Generics::MailboxList *>();
+        KTextTemplate::registerMetaType<QSharedPointer<KMime::Headers::Generics::MailboxList>>();
+        KTextTemplate::registerMetaType<QSharedPointer<KMime::Headers::Generics::AddressList>>();
+        KTextTemplate::registerMetaType<QDateTime>();
+#endif
         iconSize = KIconLoader::global()->currentSize(KIconLoader::Toolbar);
-        engine = new Grantlee::Engine;
-        templateLoader = QSharedPointer<Grantlee::FileSystemTemplateLoader>(
-            new Grantlee::FileSystemTemplateLoader);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        templateLoader = QSharedPointer<Grantlee::FileSystemTemplateLoader>(new Grantlee::FileSystemTemplateLoader);
+#else
+        templateLoader = QSharedPointer<KTextTemplate::FileSystemTemplateLoader>(new KTextTemplate::FileSystemTemplateLoader);
+#endif
         engine->addTemplateLoader(templateLoader);
 
         QVector<QByteArray> addressHeaders;
-        addressHeaders << "to" << "reply-To" << "reply-From" << "cc" << "bcc" << "from" << "sender" << "resent-From" << "resent-To";
+        addressHeaders << "to"
+                       << "reply-To"
+                       << "cc"
+                       << "bcc"
+                       << "from"
+                       << "sender"
+                       << "resent-From"
+                       << "resent-To";
 
-        for (const auto &header: addressHeaders) {
+        for (const auto &header : std::as_const(addressHeaders)) {
             registerHeaderFormatter(header, QSharedPointer<HeaderFormatter>(new AddressHeaderFormatter(header)));
         }
 
@@ -286,7 +351,7 @@ public:
         registerHeaderFormatter("date", QSharedPointer<HeaderFormatter>(new DateFormatter()));
     }
 
-    ~Private()
+    ~GrantleeHeaderFormatterPrivate()
     {
         delete engine;
     }
@@ -295,26 +360,28 @@ public:
     {
         headerFormatter[header] = formatter;
     }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QSharedPointer<Grantlee::FileSystemTemplateLoader> templateLoader;
-    QMap<QByteArray, QSharedPointer<HeaderFormatter> > headerFormatter;
-    Grantlee::Engine *engine = nullptr;
+    Grantlee::Engine *const engine;
+#else
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> templateLoader;
+    KTextTemplate::Engine *const engine;
+#endif
+    QMap<QByteArray, QSharedPointer<HeaderFormatter>> headerFormatter;
     MessageViewer::HeaderStyleUtil headerStyleUtil;
+    QColor activeColor;
+
     int iconSize;
 };
 
 GrantleeHeaderFormatter::GrantleeHeaderFormatter()
-    : d(new GrantleeHeaderFormatter::Private)
+    : d(new GrantleeHeaderFormatter::GrantleeHeaderFormatterPrivate)
 {
 }
 
-GrantleeHeaderFormatter::~GrantleeHeaderFormatter()
-{
-    delete d;
-}
+GrantleeHeaderFormatter::~GrantleeHeaderFormatter() = default;
 
-QString GrantleeHeaderFormatter::toHtml(
-    const GrantleeHeaderFormatter::GrantleeHeaderFormatterSettings &settings) const
+QString GrantleeHeaderFormatter::toHtml(const GrantleeHeaderFormatter::GrantleeHeaderFormatterSettings &settings) const
 {
     QString errorMessage;
     if (!settings.theme.isValid()) {
@@ -322,28 +389,60 @@ QString GrantleeHeaderFormatter::toHtml(
         return errorMessage;
     }
     d->templateLoader->setTemplateDirs(QStringList() << settings.theme.absolutePath());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template headerTemplate = d->engine->loadByName(settings.theme.themeFilename());
+#else
+    KTextTemplate::Template headerTemplate = d->engine->loadByName(settings.theme.themeFilename());
+#endif
     if (headerTemplate->error()) {
         errorMessage = headerTemplate->errorString();
         return errorMessage;
     }
-    return format(
-        settings.theme.absolutePath(), headerTemplate,
-        settings.theme.displayExtraVariables(), settings.isPrinting, settings.style, settings.message,
-        settings.showEmoticons);
+    return format(settings.theme.absolutePath(),
+                  headerTemplate,
+                  settings.theme.displayExtraVariables(),
+                  settings.isPrinting,
+                  settings.style,
+                  settings.message,
+                  settings.showEmoticons);
 }
 
-QString GrantleeHeaderFormatter::toHtml(const QStringList &displayExtraHeaders, const QString &absolutPath, const QString &filename, const MessageViewer::HeaderStyle *style, KMime::Message *message, bool isPrinting) const
+QString GrantleeHeaderFormatter::toHtml(const QStringList &displayExtraHeaders,
+                                        const QString &absolutPath,
+                                        const QString &filename,
+                                        const MessageViewer::HeaderStyle *style,
+                                        KMime::Message *message,
+                                        bool isPrinting) const
 {
     d->templateLoader->setTemplateDirs(QStringList() << absolutPath);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template headerTemplate = d->engine->loadByName(filename);
+#else
+    KTextTemplate::Template headerTemplate = d->engine->loadByName(filename);
+#endif
     if (headerTemplate->error()) {
         return headerTemplate->errorString();
     }
     return format(absolutPath, headerTemplate, displayExtraHeaders, isPrinting, style, message);
 }
 
-QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grantlee::Template &headerTemplate, const QStringList &displayExtraHeaders, bool isPrinting, const MessageViewer::HeaderStyle *style, KMime::Message *message, bool showEmoticons) const
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+QString GrantleeHeaderFormatter::format(const QString &absolutePath,
+                                        const Grantlee::Template &headerTemplate,
+                                        const QStringList &displayExtraHeaders,
+                                        bool isPrinting,
+                                        const MessageViewer::HeaderStyle *style,
+                                        KMime::Message *message,
+                                        bool showEmoticons) const
+#else
+QString GrantleeHeaderFormatter::format(const QString &absolutePath,
+                                        const KTextTemplate::Template &headerTemplate,
+                                        const QStringList &displayExtraHeaders,
+                                        bool isPrinting,
+                                        const MessageViewer::HeaderStyle *style,
+                                        KMime::Message *message,
+                                        bool showEmoticons) const
+#endif
 {
     QVariantHash headerObject;
     const auto nodeHelper = style->nodeHelper();
@@ -355,18 +454,26 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     // direction.
     const QString absoluteThemePath = QUrl::fromLocalFile(absolutePath + QLatin1Char('/')).url();
     headerObject.insert(QStringLiteral("absoluteThemePath"), absoluteThemePath);
-    headerObject.insert(QStringLiteral("applicationDir"),
-                        QApplication::isRightToLeft() ? QStringLiteral("rtl") : QStringLiteral(
-                            "ltr"));
+    headerObject.insert(QStringLiteral("applicationDir"), QApplication::isRightToLeft() ? QStringLiteral("rtl") : QStringLiteral("ltr"));
 
     // TODO: use correct subject from nodeHelper->mailHeader
-    headerObject.insert(QStringLiteral("subjectDir"),
-                        d->headerStyleUtil.subjectDirectionString(message));
+    headerObject.insert(QStringLiteral("subjectDir"), d->headerStyleUtil.subjectDirectionString(message));
 
     QVector<QByteArray> defaultHeaders;
-    defaultHeaders << "to" << "reply-To" << "reply-From" << "cc" << "bcc" << "from" << "sender" << "resent-From" << "resent-To" << "subject" << "organization" << "list-id" << "date";
+    defaultHeaders << "to"
+                   << "reply-To"
+                   << "cc"
+                   << "bcc"
+                   << "from"
+                   << "sender"
+                   << "resent-From"
+                   << "resent-To"
+                   << "subject"
+                   << "organization"
+                   << "list-id"
+                   << "date";
 
-    for (const auto &header: defaultHeaders) {
+    for (const auto &header : std::as_const(defaultHeaders)) {
         QSharedPointer<HeaderFormatter> formatter;
         if (d->headerFormatter.contains(header)) {
             formatter = d->headerFormatter.value(header);
@@ -376,11 +483,11 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
         const auto i18nName = formatter->i18nName();
         const auto objectName = QString::fromUtf8(header).remove(QLatin1Char('-'));
         if (nodeHelper->hasMailHeader(header.constData(), message)) {
-            const auto value = formatter->format(message, nodeHelper);
+            const auto value = formatter->format(message, nodeHelper, showEmoticons);
             headerObject.insert(objectName, value);
         }
         if (!i18nName.isEmpty()) {
-            headerObject.insert(objectName+QStringLiteral("i18n"), i18nName);
+            headerObject.insert(objectName + QStringLiteral("i18n"), i18nName);
         }
     }
 
@@ -397,14 +504,11 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     if (!style->vCardName().isEmpty()) {
         headerObject.insert(QStringLiteral("vcardname"), style->vCardName());
     }
-    if (!style->collectionName().isEmpty()) {
-        headerObject.insert(QStringLiteral("collectionname"), style->collectionName());
-    }
 
     if (isPrinting) {
-        //provide a bit more left padding when printing
-        //kolab/issue3254 (printed mail cut at the left side)
-        //Use it just for testing if we are in printing mode
+        // provide a bit more left padding when printing
+        // kolab/issue3254 (printed mail cut at the left side)
+        // Use it just for testing if we are in printing mode
         headerObject.insert(QStringLiteral("isprinting"), i18n("Printing mode"));
         headerObject.insert(QStringLiteral("printmode"), QStringLiteral("printmode"));
     } else {
@@ -414,12 +518,14 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     // colors depend on if it is encapsulated or not
     QColor fontColor(Qt::white);
     QString linkColor = QStringLiteral("white");
-    const QColor activeColor
-        = KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
-    QColor activeColorDark = activeColor.darker(130);
+
+    if (!d->activeColor.isValid()) {
+        d->activeColor = KColorScheme(QPalette::Active, KColorScheme::Selection).background().color();
+    }
+    QColor activeColorDark = d->activeColor.darker(130);
     // reverse colors for encapsulated
     if (!style->isTopLevel()) {
-        activeColorDark = activeColor.darker(50);
+        activeColorDark = d->activeColor.darker(50);
         fontColor = QColor(Qt::black);
         linkColor = QStringLiteral("black");
     }
@@ -436,10 +542,10 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
         headerObject.insert(QStringLiteral("photourl"), xface.photoURL);
     }
 
-    for (QString header : qAsConst(displayExtraHeaders)) {
+    for (QString header : std::as_const(displayExtraHeaders)) {
         const QByteArray baHeader = header.toLocal8Bit();
         if (auto hrd = message->headerByType(baHeader.constData())) {
-            //Grantlee doesn't support '-' in variable name => remove it.
+            // Grantlee doesn't support '-' in variable name => remove it.
             header.remove(QLatin1Char('-'));
             headerObject.insert(header, hrd->asUnicodeString());
         }
@@ -455,33 +561,27 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
     headerObject.insert(QStringLiteral("attachmentI18n"), i18n("Attachments:"));
 
     if (messageHasAttachment) {
-        const QString iconPath
-            = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral(
-                                                                     "mail-attachment"),
-                                                                 KIconLoader::Toolbar);
-        const QString html = QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
+        const QString iconPath = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral("mail-attachment"), KIconLoader::Toolbar);
+        const QString html =
+            QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
         headerObject.insert(QStringLiteral("attachmentIcon"), html);
     }
 
     const bool messageIsSigned = KMime::isSigned(message);
     headerObject.insert(QStringLiteral("messageIsSigned"), messageIsSigned);
     if (messageIsSigned) {
-        const QString iconPath
-            = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral(
-                                                                     "mail-signed"),
-                                                                 KIconLoader::Toolbar);
-        const QString html = QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
+        const QString iconPath = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral("mail-signed"), KIconLoader::Toolbar);
+        const QString html =
+            QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
         headerObject.insert(QStringLiteral("signedIcon"), html);
     }
 
     const bool messageIsEncrypted = KMime::isEncrypted(message);
     headerObject.insert(QStringLiteral("messageIsEncrypted"), messageIsEncrypted);
     if (messageIsEncrypted) {
-        const QString iconPath
-            = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral(
-                                                                     "mail-encrypted"),
-                                                                 KIconLoader::Toolbar);
-        const QString html = QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
+        const QString iconPath = MessageViewer::IconNameCache::instance()->iconPath(QStringLiteral("mail-encrypted"), KIconLoader::Toolbar);
+        const QString html =
+            QStringLiteral("<img height=\"%2\" width=\"%2\" src=\"%1\"></a>").arg(QUrl::fromLocalFile(iconPath).url(), QString::number(d->iconSize));
         headerObject.insert(QStringLiteral("encryptedIcon"), html);
     }
 
@@ -491,7 +591,11 @@ QString GrantleeHeaderFormatter::format(const QString &absolutePath, const Grant
 
     QVariantHash mapping;
     mapping.insert(QStringLiteral("header"), headerObject);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Context context(mapping);
+#else
+    KTextTemplate::Context context(mapping);
+#endif
 
     return headerTemplate->render(&context);
 }
