@@ -1,12 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "grantleeheaderstyle.h"
 #include "header/grantleeheaderformatter.h"
-#include "header/headerstrategy.h"
 #include <GrantleeTheme/GrantleeTheme>
 
 #include <KMime/KMimeMessage>
@@ -16,8 +15,8 @@ class MessageViewer::GrantleeHeaderStylePrivate
 {
 public:
     GrantleeHeaderStylePrivate()
+        : mGrantleeFormatter(new GrantleeHeaderFormatter)
     {
-        mGrantleeFormatter = new GrantleeHeaderFormatter;
     }
 
     ~GrantleeHeaderStylePrivate()
@@ -25,7 +24,7 @@ public:
         delete mGrantleeFormatter;
     }
 
-    GrantleeHeaderFormatter *mGrantleeFormatter = nullptr;
+    GrantleeHeaderFormatter *const mGrantleeFormatter;
 };
 
 GrantleeHeaderStyle::GrantleeHeaderStyle()
@@ -44,7 +43,7 @@ const char *GrantleeHeaderStyle::name() const
 QString GrantleeHeaderStyle::format(KMime::Message *message) const
 {
     if (!message) {
-        return QString();
+        return {};
     }
 
     GrantleeHeaderFormatter::GrantleeHeaderFormatterSettings settings;
