@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -34,7 +34,6 @@ public:
     void setExtraDisplayHeaders(const QStringList &);
 
 private:
-    GrantleeHeaderTestStylePrivate *const d;
+    std::unique_ptr<GrantleeHeaderTestStylePrivate> const d;
 };
 }
-
