@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "headerstyleinterface.h"
-#include "headerstyle.h"
 #include "headerstyleplugin.h"
 #include "utils/messageviewerutil_p.h"
 #include <KActionMenu>
 #include <KToggleAction>
 #include <QAction>
+#include <QActionGroup>
 using namespace MessageViewer;
 
 HeaderStyleInterface::HeaderStyleInterface(MessageViewer::HeaderStylePlugin *headerStylePlugin, QObject *parent)
@@ -19,9 +19,7 @@ HeaderStyleInterface::HeaderStyleInterface(MessageViewer::HeaderStylePlugin *hea
 {
 }
 
-HeaderStyleInterface::~HeaderStyleInterface()
-{
-}
+HeaderStyleInterface::~HeaderStyleInterface() = default;
 
 QList<KToggleAction *> HeaderStyleInterface::action() const
 {
