@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,13 +59,16 @@ void WebEnginePartHtmlWriter::end()
         mStyleBody.clear();
     }
     if (data().size() > 2000000) {
-        qDebug() << " load big message ";
+        // qDebug() << " load big message ";
         mTempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/messageviewer_XXXXXX") + QLatin1String(".html"));
         mTempFile->open();
         QTextStream stream(mTempFile);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QByteArray codecValue = Util::htmlCodec(data(), codec());
         stream.setCodec(codecValue.constData());
+#else
+        stream.setEncoding(Util::htmlEncoding(data(), codec()));
+#endif
         stream << data();
         // Bug 387061
         mHtmlView->load(QUrl::fromLocalFile(mTempFile->fileName()));
