@@ -1,22 +1,23 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef WEBENGINEPARTHTMLWRITER_H
-#define WEBENGINEPARTHTMLWRITER_H
+#pragma once
 
 #include "bufferedhtmlwriter.h"
 #include <QObject>
 
-#include <QString>
 #include <QByteArray>
+#include <QString>
 class QTemporaryFile;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MailWebEngineView;
 }
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class WebEnginePartHtmlWriter : public QObject, public BufferedHtmlWriter
 {
     Q_OBJECT
@@ -40,15 +41,10 @@ private:
     void insertBodyStyle();
 
 private:
-    MailWebEngineView *mHtmlView = nullptr;
+    MailWebEngineView *const mHtmlView;
     QString mExtraHead;
     QString mStyleBody;
-    enum State {
-        Begun,
-        Queued,
-        Ended
-    } mState = Ended;
+    enum State { Begun, Queued, Ended } mState = Ended;
     QTemporaryFile *mTempFile = nullptr;
 };
 }
-#endif // WEBENGINEPARTHTMLWRITER_H
