@@ -21,20 +21,14 @@
 
 using namespace MessageViewer;
 
-void RenderTest::initTestCase()
+void RenderTest::initMain()
 {
     Test::setupEnv();
-}
-
 #ifndef Q_OS_WIN
-void initLocale()
-{
-    setenv("LC_ALL", "en_US.utf-8", 1);
-    setenv("TZ", "UTC", 1);
+    qputenv("LC_ALL", "en_US.UTF-8");
+#endif
 }
 
-Q_CONSTRUCTOR_FUNCTION(initLocale)
-#endif
 void RenderTest::testRenderSmart_data()
 {
     QTest::addColumn<QString>("mailFileName");
