@@ -4,13 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSSAGEVIEWER_TESTCSSHELPER_H
-#define MESSSAGEVIEWER_TESTCSSHELPER_H
+#pragma once
 
 #include <MessageViewer/CSSHelper>
 
-namespace MessageViewer {
-namespace Test {
+namespace MessageViewer
+{
+namespace Test
+{
 class TestCSSHelper : public MessageViewer::CSSHelper
 {
 public:
@@ -20,5 +21,3 @@ public:
 };
 }
 }
-
-#endif // MESSSAGEVIEWER_TESTCSSHELPER_H
