@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
-#define MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
+#pragma once
 
 #include <QString>
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class ConvertHtmlToPlainText
 {
 public:
@@ -26,5 +26,3 @@ private:
     QString mHtmlString;
 };
 }
-
-#endif // MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
