@@ -35,20 +35,27 @@
 #include <KLocalizedString>
 
 #include <QUrl>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/context.h>
 #include <grantlee/engine.h>
 #include <grantlee/metatype.h>
 #include <grantlee/template.h>
 #include <grantlee/templateloader.h>
+#else
+#include <KTextTemplate/context.h>
+#include <KTextTemplate/engine.h>
+#include <KTextTemplate/metatype.h>
+#include <KTextTemplate/template.h>
+#include <KTextTemplate/templateloader.h>
+#endif
 
 using namespace MimeTreeParser;
 using namespace MessageViewer;
-
+#ifndef COMPILE_WITH_UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(GpgME::DecryptionResult::Recipient)
 Q_DECLARE_METATYPE(GpgME::Key)
 Q_DECLARE_METATYPE(const QGpgME::Protocol *)
-
+#endif
 static const int SIG_FRAME_COL_UNDEF = 99;
 #define SIG_FRAME_COL_RED -1
 #define SIG_FRAME_COL_YELLOW 0
@@ -232,9 +239,7 @@ DefaultRendererPrivate::DefaultRendererPrivate(CSSHelperBase *cssHelper, const M
 {
 }
 
-DefaultRendererPrivate::~DefaultRendererPrivate()
-{
-}
+DefaultRendererPrivate::~DefaultRendererPrivate() = default;
 
 CSSHelperBase *DefaultRendererPrivate::cssHelper() const
 {
@@ -288,30 +293,50 @@ void DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp
     if (!mp->hasSubParts()) {
         return;
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template t = MessagePartRendererManager::self()->loadByName(QStringLiteral("encapsulatedrfc822messagepart.html"));
     Grantlee::Context c = MessagePartRendererManager::self()->createContext();
+#else
+    KTextTemplate::Template t = MessagePartRendererManager::self()->loadByName(QStringLiteral("encapsulatedrfc822messagepart.html"));
+    KTextTemplate::Context c = MessagePartRendererManager::self()->createContext();
+
+#endif
     QObject block;
 
     c.insert(QStringLiteral("block"), &block);
     block.setProperty("link", mp->nodeHelper()->asHREF(mp->message().data(), QStringLiteral("body")));
 
     c.insert(QStringLiteral("msgHeader"), mCreateMessageHeader(mp->message().data()));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
                  renderSubParts(mp, htmlWriter);
              }));
-
+#else
+    c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](KTextTemplate::OutputStream *) {
+                 renderSubParts(mp, htmlWriter);
+             }));
+#endif
     HTMLBlock::Ptr aBlock;
     if (mp->isAttachment()) {
         aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::OutputStream s(htmlWriter->stream());
+#else
+    KTextTemplate::OutputStream s(htmlWriter->stream());
+#endif
     t->render(&s, &c);
 }
 
 void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("htmlmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#else
+    KTextTemplate::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("htmlmessagepart.html"));
+    KTextTemplate::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#endif
     QObject block;
 
     c.insert(QStringLiteral("block"), &block);
@@ -349,7 +374,11 @@ void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *
     if (mp->isAttachment()) {
         aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::OutputStream s(htmlWriter->stream());
+#else
+    KTextTemplate::OutputStream s(htmlWriter->stream());
+#endif
     t->render(&s, &c);
 }
 
@@ -357,11 +386,15 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
 {
     KMime::Content *node = mp->content();
     const auto metaData = *mp->partMetaData();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("encryptedmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#else
+    KTextTemplate::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("encryptedmessagepart.html"));
+    KTextTemplate::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#endif
     QObject block;
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (node || mp->hasSubParts()) {
         c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
                      HTMLBlock::Ptr rBlock;
@@ -375,7 +408,22 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
                      renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
                  }));
     }
+#else
+    if (node || mp->hasSubParts()) {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](KTextTemplate::OutputStream *) {
+                     HTMLBlock::Ptr rBlock;
+                     if (mp->content() && mp->isRoot()) {
+                         rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
+                     }
+                     renderSubParts(mp, htmlWriter);
+                 }));
+    } else if (!metaData.inProgress) {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](KTextTemplate::OutputStream *) {
+                     renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
+                 }));
+    }
 
+#endif
     c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(mp->cryptoProto()));
     if (!mp->decryptRecipients().empty()) {
         c.insert(QStringLiteral("decryptedRecipients"), QVariant::fromValue(mp->decryptRecipients()));
@@ -390,8 +438,11 @@ void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp
     block.setProperty("decryptIcon", QUrl::fromLocalFile(IconNameCache::instance()->iconPath(QStringLiteral("document-decrypt"), KIconLoader::Small)).url());
     block.setProperty("errorText", metaData.errorText);
     block.setProperty("noSecKey", mp->isNoSecKey());
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::OutputStream s(htmlWriter->stream());
+#else
+    KTextTemplate::OutputStream s(htmlWriter->stream());
+#endif
     t->render(&s, &c);
 }
 
@@ -402,11 +453,16 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
     auto cryptoProto = mp->cryptoProto();
 
     const bool isSMIME = cryptoProto && (cryptoProto == QGpgME::smime());
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("signedmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#else
+    KTextTemplate::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("signedmessagepart.html"));
+    KTextTemplate::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#endif
     QObject block;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (node) {
         c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
                      HTMLBlock::Ptr rBlock;
@@ -420,7 +476,21 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
                      renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
                  }));
     }
-
+#else
+    if (node) {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](KTextTemplate::OutputStream *) {
+                     HTMLBlock::Ptr rBlock;
+                     if (mp->isRoot()) {
+                         rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
+                     }
+                     renderSubParts(mp, htmlWriter);
+                 }));
+    } else if (!metaData.inProgress) {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](KTextTemplate::OutputStream *) {
+                     renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
+                 }));
+    }
+#endif
     c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(cryptoProto));
     c.insert(QStringLiteral("block"), &block);
 
@@ -598,8 +668,11 @@ void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, Html
     block.setProperty("statusStr", statusStr);
     block.setProperty("signClass", mClass);
     block.setProperty("greenCaseWarning", greenCaseWarning);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::OutputStream s(htmlWriter->stream());
+#else
+    KTextTemplate::OutputStream s(htmlWriter->stream());
+#endif
     t->render(&s, &c);
 }
 
@@ -679,8 +752,13 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
 void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
     const GpgME::ImportResult &importResult(mp->importResult());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("certmessagepart.html"));
     Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#else
+    KTextTemplate::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("certmessagepart.html"));
+    KTextTemplate::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+#endif
     QObject block;
 
     c.insert(QStringLiteral("block"), &block);
@@ -706,7 +784,11 @@ void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *
     if (mp->isAttachment()) {
         aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::OutputStream s(htmlWriter->stream());
+#else
+    KTextTemplate::OutputStream s(htmlWriter->stream());
+#endif
     t->render(&s, &c);
 }
 
@@ -731,8 +813,8 @@ void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, Html
         const QByteArray cid = msgPart->content()->contentID()->identifier();
         auto mp = msgPart.dynamicCast<MimeTreeParser::TextMessagePart>();
         if (!cid.isEmpty() && mp) {
-            QString fileName = mp->temporaryFilePath();
-            QString href = QUrl::fromLocalFile(fileName).url();
+            const QString fileName = mp->temporaryFilePath();
+            const QString href = QUrl::fromLocalFile(fileName).url();
             htmlWriter->embedPart(cid, href);
         }
     }
