@@ -1,54 +1,39 @@
 /*
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2017 Sandro Knauß <sknauss@kde.org>
+    SPDX-FileCopyrightText: 2017 Sandro Knauß <sknauss@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagepartrendererfactory.h"
+#include "messagepartrendererbase.h"
 #include "messagepartrendererfactory_p.h"
 #include "messagepartrenderplugin.h"
-#include "viewer/urlhandlermanager.h"
-
-#include "messagepartrendererbase.h"
 #include "messageviewer_debug.h"
+#include "viewer/urlhandlermanager.h"
 
 #include "plugins/attachmentmessagepartrenderer.h"
 #include "plugins/messagepartrenderer.h"
 #include "plugins/textmessagepartrenderer.h"
 
-#include <KPluginLoader>
-
-#include <QMimeDatabase>
+#include <KPluginMetaData>
 #include <QJsonArray>
-#include <QJsonObject>
+#include <QMimeDatabase>
+#include <QPluginLoader>
 #include <algorithm>
 
 using namespace MessageViewer;
 
+MessagePartRendererFactoryPrivate::~MessagePartRendererFactoryPrivate()
+{
+    QHashIterator<QByteArray, std::vector<RendererInfo>> i(m_renderers);
+    while (i.hasNext()) {
+        i.next();
+        auto renderInfo = i.value();
+        renderInfo.erase(renderInfo.begin(), renderInfo.end());
+    }
+}
+
 void MessagePartRendererFactoryPrivate::setup()
 {
     if (m_renderers.isEmpty()) {
@@ -63,19 +48,18 @@ void MessagePartRendererFactoryPrivate::loadPlugins()
     if (m_pluginSubdir.isEmpty()) {
         return;
     }
-
-    KPluginLoader::forEachPlugin(m_pluginSubdir, [this](const QString &path) {
-        QPluginLoader loader(path);
-        const auto pluginData = loader.metaData().value(QLatin1String("MetaData")).toObject().value(QLatin1String("renderer")).toArray();
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(m_pluginSubdir);
+    for (const auto &md : plugins) {
+        const auto pluginData = md.rawData().value(QLatin1String("renderer")).toArray();
         if (pluginData.isEmpty()) {
-            qCWarning(MESSAGEVIEWER_LOG) << "Plugin" << path << "has no meta data.";
-            return;
+            qCWarning(MESSAGEVIEWER_LOG) << "Plugin" << md.fileName() << "has no meta data.";
+            continue;
         }
-
+        QPluginLoader loader(md.fileName());
         auto plugin = qobject_cast<MessagePartRenderPlugin *>(loader.instance());
         if (!plugin) {
-            qCWarning(MESSAGEVIEWER_LOG) << path << "is not a MessagePartRendererPlugin";
-            return;
+            qCWarning(MESSAGEVIEWER_LOG) << md.fileName() << "is not a MessagePartRendererPlugin";
+            continue;
         }
 
         MessagePartRendererBase *renderer = nullptr;
@@ -83,7 +67,7 @@ void MessagePartRendererFactoryPrivate::loadPlugins()
             const auto metaData = pluginData.at(i).toObject();
             const auto type = metaData.value(QLatin1String("type")).toString().toUtf8();
             if (type.isEmpty()) {
-                qCWarning(MESSAGEVIEWER_LOG) << path << "returned empty type specification for index" << i;
+                qCWarning(MESSAGEVIEWER_LOG) << md.fileName() << "returned empty type specification for index" << i;
                 break;
             }
             const auto mimetype = metaData.value(QLatin1String("mimetype")).toString().toLower();
@@ -99,7 +83,7 @@ void MessagePartRendererFactoryPrivate::loadPlugins()
             const auto mimeType = metaData.value(QLatin1String("mimetype")).toString().toLower();
             URLHandlerManager::instance()->registerHandler(handler, mimeType);
         }
-    });
+    }
 }
 
 void MessagePartRendererFactoryPrivate::initialize_builtin_renderers()
@@ -160,12 +144,15 @@ QVector<MessagePartRendererBase *> MessagePartRendererFactory::renderersForPart(
     auto candidates = d->m_renderers.value(mo->className());
 
     // remove candidates with a mimetype set that don't match the mimetype of the part
-    candidates.erase(std::remove_if(candidates.begin(), candidates.end(), [ancestors](const RendererInfo &info) {
-        if (info.mimeType.isEmpty()) {
-            return false;
-        }
-        return !ancestors.contains(info.mimeType);
-    }), candidates.end());
+    candidates.erase(std::remove_if(candidates.begin(),
+                                    candidates.end(),
+                                    [ancestors](const RendererInfo &info) {
+                                        if (info.mimeType.isEmpty()) {
+                                            return false;
+                                        }
+                                        return !ancestors.contains(info.mimeType);
+                                    }),
+                     candidates.end());
 
     // sort most specific mimetpypes first
     std::stable_sort(candidates.begin(), candidates.end(), [ancestors](const RendererInfo &lhs, const RendererInfo &rhs) {
@@ -182,6 +169,7 @@ QVector<MessagePartRendererBase *> MessagePartRendererFactory::renderersForPart(
     });
 
     QVector<MessagePartRendererBase *> r;
+    r.reserve(candidates.size());
     for (const auto &candidate : candidates) {
         r.push_back(candidate.renderer.data());
     }
