@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_MESSAGEPARTRENDERERFACTORY_P_H
-#define MESSAGEVIEWER_MESSAGEPARTRENDERERFACTORY_P_H
+#pragma once
 
 #include <QByteArray>
 #include <QHash>
@@ -13,11 +12,11 @@
 
 #include <vector>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MessagePartRendererBase;
 
-struct RendererInfo
-{
+struct RendererInfo {
     QSharedPointer<MessagePartRendererBase> renderer;
     QString mimeType;
     int priority;
@@ -32,9 +31,7 @@ public:
     void initialize_builtin_renderers();
     void insert(const QByteArray &type, MessagePartRendererBase *formatter, const QString &mimeType = QString(), int priority = 0);
 
-    QHash<QByteArray, std::vector<RendererInfo> > m_renderers;
-    QString m_pluginSubdir = QStringLiteral("messageviewer/bodypartformatter");
+    QHash<QByteArray, std::vector<RendererInfo>> m_renderers;
+    QString m_pluginSubdir = QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/messageviewer/bodypartformatter");
 };
 }
-
-#endif
