@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,9 +10,7 @@ using namespace MessageViewer;
 class MessageViewer::MessageViewerConfigureSettingsPluginPrivate
 {
 public:
-    MessageViewerConfigureSettingsPluginPrivate()
-    {
-    }
+    MessageViewerConfigureSettingsPluginPrivate() = default;
 };
 
 MessageViewerConfigureSettingsPlugin::MessageViewerConfigureSettingsPlugin(QObject *parent)
