@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DEFAULTGRANTLEEHEADERSTRATEGY_H
-#define DEFAULTGRANTLEEHEADERSTRATEGY_H
+#pragma once
 
 #include <messageviewer/headerstrategy.h>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class DefaultGrantleeHeaderStrategy : public HeaderStrategy
 {
 public:
@@ -28,4 +28,3 @@ public:
     }
 };
 }
-#endif // DEFAULTGRANTLEEHEADERSTRATEGY_H
