@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ DefaultGrantleeHeaderStyleInterface::DefaultGrantleeHeaderStyleInterface(Message
 {
 }
 
-DefaultGrantleeHeaderStyleInterface::~DefaultGrantleeHeaderStyleInterface()
-{
-}
+DefaultGrantleeHeaderStyleInterface::~DefaultGrantleeHeaderStyleInterface() = default;
 
 void DefaultGrantleeHeaderStyleInterface::createAction(KActionMenu *menu, QActionGroup *actionGroup, KActionCollection *ac)
 {
