@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ void RemoteContentWidgetTest::shouldHaveDefaultValues()
     MessageViewer::RemoteContentWidget w;
     auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), {});
+    QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
     auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("mLineEdit"));
     QVERIFY(mLineEdit);
