@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ RemoteContentStatusTypeComboBox::RemoteContentStatusTypeComboBox(QWidget *parent
     addItem(i18n("Blocked"), QVariant::fromValue(RemoteContentInfo::RemoteContentInfoStatus::Blocked));
 }
 
-RemoteContentStatusTypeComboBox::~RemoteContentStatusTypeComboBox()
-{
-}
+RemoteContentStatusTypeComboBox::~RemoteContentStatusTypeComboBox() = default;
 
 void RemoteContentStatusTypeComboBox::setStatus(MessageViewer::RemoteContentInfo::RemoteContentInfoStatus type)
 {
