@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,13 +7,9 @@
 
 #include "scamdetectioninfo.h"
 using namespace MessageViewer;
-ScamDetectionInfo::ScamDetectionInfo()
-{
-}
+ScamDetectionInfo::ScamDetectionInfo() = default;
 
-ScamDetectionInfo::~ScamDetectionInfo()
-{
-}
+ScamDetectionInfo::~ScamDetectionInfo() = default;
 
 const QString &ScamDetectionInfo::domainOrEmail() const
 {
