@@ -1,25 +1,25 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMDETECTIONWARNINGWIDGET_H
-#define SCAMDETECTIONWARNINGWIDGET_H
+#pragma once
 
 #include "messageviewer_private_export.h"
 
 #include <KMessageWidget>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ScamDetectionWarningWidgetPrivate;
 class MESSAGEVIEWER_TESTS_EXPORT ScamDetectionWarningWidget : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit ScamDetectionWarningWidget(QWidget *parent = nullptr);
-    ~ScamDetectionWarningWidget();
+    ~ScamDetectionWarningWidget() override;
 
     void setUseInTestApps(bool b);
 
@@ -39,8 +39,6 @@ private:
     void slotMessageIsNotAScam();
 
 private:
-    ScamDetectionWarningWidgetPrivate *const d;
+    std::unique_ptr<ScamDetectionWarningWidgetPrivate> const d;
 };
 }
-
-#endif // SCAMDETECTIONWARNINGWIDGET_H
