@@ -2,8 +2,7 @@
 **
 ** Filename   : util
 ** Created on : 03 April, 2005
-** Copyright  : (c) 2005 Till Adam
-** Email      : <adam@kde.org>
+** SPDX-FileCopyrightText : 2005 Till Adam <adam@kde.org>
 **
 *******************************************************************************/
 
@@ -37,39 +36,39 @@
 *******************************************************************************/
 
 #include "messageviewer/messageviewerutil.h"
-#include "messageviewerutil_p.h"
-#include "kpimtextedit/texttospeech.h"
-#include <MimeTreeParser/NodeHelper>
-#include "messageviewer_debug.h"
 #include "MessageCore/MessageCoreSettings"
 #include "MessageCore/NodeHelper"
 #include "MessageCore/StringUtil"
+#include "messageviewer_debug.h"
+#include "messageviewerutil_p.h"
+#include <MimeTreeParser/NodeHelper>
 
-#include "PimCommon/RenameFileDialog"
+#include <PimCommon/RenameFileDialog>
 
-#include <AkonadiCore/item.h>
+#include <Gravatar/GravatarCache>
+#include <gravatar/gravatarsettings.h>
 
-#include <kmbox/mbox.h>
+#include <KMbox/MBox>
 
-#include <KMime/Message>
+#include <KCharsets>
 #include <KFileWidget>
-#include <kcharsets.h>
-#include <KLocalizedString>
-#include <kmessagebox.h>
-#include <QFileDialog>
-#include <ktoolinvocation.h>
-#include <KJobWidgets>
-#include <KIO/StatJob>
 #include <KIO/FileCopyJob>
+#include <KIO/StatJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KMime/Message>
 #include <KRecentDirs>
 #include <QAction>
+#include <QActionGroup>
+#include <QDBusConnectionInterface>
+#include <QDesktopServices>
+#include <QFileDialog>
 #include <QIcon>
+#include <QRegularExpression>
 #include <QTemporaryFile>
 #include <QWidget>
-#include <QDBusConnectionInterface>
-#include <QActionGroup>
-#include <QDesktopServices>
-#include <QRegularExpression>
+#include <kwidgetsaddons_version.h>
 
 using namespace MessageViewer;
 /** Checks whether @p str contains external references. To be precise,
@@ -79,19 +78,15 @@ using namespace MessageViewer;
 
 bool Util::containsExternalReferences(const QString &str, const QString &extraHead)
 {
-    const bool hasBaseInHeader = extraHead.contains(QLatin1String(
-                                                        "<base href=\""), Qt::CaseInsensitive);
-    if (hasBaseInHeader && (str.contains(QLatin1String("href=\"/"), Qt::CaseInsensitive)
-                            || str.contains(QLatin1String("<img src=\"/"), Qt::CaseInsensitive))) {
+    const bool hasBaseInHeader = extraHead.contains(QLatin1String("<base href=\""), Qt::CaseInsensitive);
+    if (hasBaseInHeader && (str.contains(QLatin1String("href=\"/"), Qt::CaseInsensitive) || str.contains(QLatin1String("<img src=\"/"), Qt::CaseInsensitive))) {
         return true;
     }
     int httpPos = str.indexOf(QLatin1String("\"http:"), Qt::CaseInsensitive);
     int httpsPos = str.indexOf(QLatin1String("\"https:"), Qt::CaseInsensitive);
     while (httpPos >= 0 || httpsPos >= 0) {
         // pos = index of next occurrence of "http: or "https: whichever comes first
-        int pos = (httpPos < httpsPos)
-                ? ((httpPos >= 0) ? httpPos : httpsPos)
-                : ((httpsPos >= 0) ? httpsPos : httpPos);
+        const int pos = (httpPos < httpsPos) ? ((httpPos >= 0) ? httpPos : httpsPos) : ((httpsPos >= 0) ? httpsPos : httpPos);
         // look backwards for "href"
         if (pos > 5) {
             int hrefPos = str.lastIndexOf(QLatin1String("href"), pos - 5, Qt::CaseInsensitive);
@@ -102,8 +97,7 @@ bool Util::containsExternalReferences(const QString &str, const QString &extraHe
                 // HTML messages created by KMail itself for now contain the following:
                 // <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
                 // Make sure not to show an external references warning for this string
-                int dtdPos = str.indexOf(QLatin1String(
-                                             "http://www.w3.org/TR/html4/loose.dtd"), pos + 1);
+                int dtdPos = str.indexOf(QLatin1String("http://www.w3.org/TR/html4/loose.dtd"), pos + 1);
                 if (dtdPos != (pos + 1)) {
                     return true;
                 }
@@ -131,9 +125,13 @@ bool Util::containsExternalReferences(const QString &str, const QString &extraHe
             }
         }
         if (!newStringImg.isEmpty()) {
-            const bool containsReg2 = newStringImg.contains(QRegularExpression(QLatin1String("<img.*src=\"https?:/.*\".*>"), QRegularExpression::CaseInsensitiveOption), &rmatch);
+            static QRegularExpression image1RegularExpression =
+                QRegularExpression(QStringLiteral("<img.*src=\"https?:/.*\".*>"), QRegularExpression::CaseInsensitiveOption);
+            const bool containsReg2 = newStringImg.contains(image1RegularExpression, &rmatch);
             if (!containsReg2) {
-                const bool containsReg = newStringImg.contains(QRegularExpression(QLatin1String("<img.*src=https?:/.*>"), QRegularExpression::CaseInsensitiveOption), &rmatch);
+                static QRegularExpression image2RegularExpression =
+                    QRegularExpression(QStringLiteral("<img.*src=https?:/.*>"), QRegularExpression::CaseInsensitiveOption);
+                const bool containsReg = newStringImg.contains(image2RegularExpression, &rmatch);
                 return containsReg;
             } else {
                 return true;
@@ -149,17 +147,18 @@ bool Util::checkOverwrite(const QUrl &url, QWidget *w)
     if (url.isLocalFile()) {
         fileExists = QFile::exists(url.toLocalFile());
     } else {
-        auto job = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
+        auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatBasic);
         KJobWidgets::setWindow(job, w);
         fileExists = job->exec();
     }
     if (fileExists) {
-        if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(
-                w,
-                i18n("A file named \"%1\" already exists. "
-                     "Are you sure you want to overwrite it?", url.toDisplayString()),
-                i18n("Overwrite File?"),
-                KStandardGuiItem::overwrite())) {
+        if (KMessageBox::Cancel
+            == KMessageBox::warningContinueCancel(w,
+                                                  i18n("A file named \"%1\" already exists. "
+                                                       "Are you sure you want to overwrite it?",
+                                                       url.toDisplayString()),
+                                                  i18n("Overwrite File?"),
+                                                  KStandardGuiItem::overwrite())) {
             return false;
         }
     }
@@ -200,17 +199,16 @@ KMime::Content::List Util::allContents(const KMime::Content *message)
 
 bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, QList<QUrl> &urlList)
 {
-    QUrl url, dirUrl;
+    QUrl url;
+    QUrl dirUrl;
     QString recentDirClass;
     QUrl currentFolder;
     const bool multiple = (contents.count() > 1);
     if (multiple) {
         // get the dir
-        dirUrl = QFileDialog::getExistingDirectoryUrl(parent, i18n(
-                                                          "Save Attachments To"),
-                                                      KFileWidget::getStartUrl(QUrl(QStringLiteral(
-                                                                                        "kfiledialog:///attachmentDir")),
-                                                                               recentDirClass));
+        dirUrl = QFileDialog::getExistingDirectoryUrl(parent,
+                                                      i18n("Save Attachments To"),
+                                                      KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///attachmentDir")), recentDirClass));
         if (!dirUrl.isValid()) {
             return false;
         }
@@ -229,13 +227,10 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
             fileName = i18nc("filename for an unnamed attachment", "attachment.1");
         }
 
-        QUrl localUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral(
-                                                          "kfiledialog:///attachmentDir")),
-                                                 recentDirClass);
+        QUrl localUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///attachmentDir")), recentDirClass);
         localUrl.setPath(localUrl.path() + QLatin1Char('/') + fileName);
         QFileDialog::Options options = QFileDialog::DontConfirmOverwrite;
-        url = QFileDialog::getSaveFileUrl(parent, i18n("Save Attachment"), localUrl,
-                                          QString(), nullptr, options);
+        url = QFileDialog::getSaveFileUrl(parent, i18n("Save Attachment"), localUrl, QString(), nullptr, options);
         if (url.isEmpty()) {
             return false;
         }
@@ -246,13 +241,12 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
         KRecentDirs::add(recentDirClass, currentFolder.path());
     }
 
-    QMap< QString, int > renameNumbering;
+    QMap<QString, int> renameNumbering;
 
     bool globalResult = true;
     int unnamedAtmCount = 0;
-    PimCommon::RenameFileDialog::RenameFileDialogResult result
-        = PimCommon::RenameFileDialog::RENAMEFILE_IGNORE;
-    for (KMime::Content *content : qAsConst(contents)) {
+    PimCommon::RenameFileDialog::RenameFileDialogResult result = PimCommon::RenameFileDialog::RENAMEFILE_IGNORE;
+    for (KMime::Content *content : std::as_const(contents)) {
         QUrl curUrl;
         if (!dirUrl.isEmpty()) {
             curUrl = dirUrl;
@@ -260,8 +254,7 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
             fileName = MessageCore::StringUtil::cleanFileName(fileName);
             if (fileName.isEmpty()) {
                 ++unnamedAtmCount;
-                fileName = i18nc("filename for the %1-th unnamed attachment",
-                                 "attachment.%1", unnamedAtmCount);
+                fileName = i18nc("filename for the %1-th unnamed attachment", "attachment.%1", unnamedAtmCount);
             }
             if (!curUrl.path().endsWith(QLatin1Char('/'))) {
                 curUrl.setPath(curUrl.path() + QLatin1Char('/'));
@@ -271,21 +264,20 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
             curUrl = url;
         }
         if (!curUrl.isEmpty()) {
-            //Bug #312954
+            // Bug #312954
             if (multiple && (curUrl.fileName() == QLatin1String("smime.p7s"))) {
                 continue;
             }
             // Rename the file if we have already saved one with the same name:
             // try appending a number before extension (e.g. "pic.jpg" => "pic_2.jpg")
-            QString origFile = curUrl.fileName();
+            const QString origFile = curUrl.fileName();
             QString file = origFile;
 
             while (renameNumbering.contains(file)) {
                 file = origFile;
                 int num = renameNumbering[file] + 1;
                 int dotIdx = file.lastIndexOf(QLatin1Char('.'));
-                file.insert((dotIdx >= 0) ? dotIdx : file.length(), QLatin1Char(
-                                '_') + QString::number(num));
+                file.insert((dotIdx >= 0) ? dotIdx : file.length(), QLatin1Char('_') + QString::number(num));
             }
             curUrl = curUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
             curUrl.setPath(curUrl.path() + QLatin1Char('/') + file);
@@ -305,25 +297,19 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
                 }
             }
 
-            if (!(result == PimCommon::RenameFileDialog::RENAMEFILE_OVERWRITEALL
-                  || result == PimCommon::RenameFileDialog::RENAMEFILE_IGNOREALL)) {
+            if (!(result == PimCommon::RenameFileDialog::RENAMEFILE_OVERWRITEALL || result == PimCommon::RenameFileDialog::RENAMEFILE_IGNOREALL)) {
                 bool fileExists = false;
                 if (curUrl.isLocalFile()) {
                     fileExists = QFile::exists(curUrl.toLocalFile());
                 } else {
-                    auto job = KIO::stat(curUrl, KIO::StatJob::DestinationSide, 0);
+                    auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatDetail::StatBasic);
                     KJobWidgets::setWindow(job, parent);
                     fileExists = job->exec();
                 }
                 if (fileExists) {
-                    QPointer<PimCommon::RenameFileDialog> dlg = new PimCommon::RenameFileDialog(
-                        curUrl,
-                        multiple,
-                        parent);
-                    result
-                        = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dlg->exec());
-                    if (result == PimCommon::RenameFileDialog::RENAMEFILE_IGNORE
-                        || result == PimCommon::RenameFileDialog::RENAMEFILE_IGNOREALL) {
+                    QPointer<PimCommon::RenameFileDialog> dlg = new PimCommon::RenameFileDialog(curUrl, multiple, parent);
+                    result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dlg->exec());
+                    if (result == PimCommon::RenameFileDialog::RENAMEFILE_IGNORE || result == PimCommon::RenameFileDialog::RENAMEFILE_IGNOREALL) {
                         delete dlg;
                         continue;
                     } else if (result == PimCommon::RenameFileDialog::RENAMEFILE_RENAME) {
@@ -336,9 +322,9 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
             }
             // save
             if (result != PimCommon::RenameFileDialog::RENAMEFILE_IGNOREALL) {
-                const bool result = saveContent(parent, content, curUrl);
-                if (!result) {
-                    globalResult = result;
+                const bool resultSave = saveContent(parent, content, curUrl);
+                if (!resultSave) {
+                    globalResult = resultSave;
                 } else {
                     urlList.append(curUrl);
                 }
@@ -364,20 +350,34 @@ bool Util::saveContent(QWidget *parent, KMime::Content *content, const QUrl &url
     bool bEncryptedParts = mNodeHelper->encryptionState(content)
                            != MimeTreeParser::KMMsgNotEncrypted;
     if (bEncryptedParts) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(parent,
+#else
         if (KMessageBox::questionYesNo(parent,
+
+#endif
                                        i18n(
                                            "The part %1 of the message is encrypted. Do you want to keep the encryption when saving?",
                                            url.fileName()),
                                        i18n("KMail Question"), KGuiItem(i18n("Keep Encryption")),
                                        KGuiItem(i18n("Do Not Keep")))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             == KMessageBox::Yes) {
+#endif
             bSaveEncrypted = true;
         }
     }
 
     bool bSaveWithSig = true;
     if (mNodeHelper->signatureState(content) != MessageViewer::MimeTreeParser::KMMsgNotSigned) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(parent,
+#else
         if (KMessageBox::questionYesNo(parent,
+
+#endif
                                        i18n(
                                            "The part %1 of the message is signed. Do you want to keep the signature when saving?",
                                            url.fileName()),
@@ -434,8 +434,7 @@ bool Util::saveContent(QWidget *parent, KMime::Content *content, const QUrl &url
     }
 #else
     const QByteArray data = content->decodedContent();
-    qCWarning(MESSAGEVIEWER_LOG)
-        << "Port the encryption/signature handling when saving a KMime::Content.";
+    qCWarning(MESSAGEVIEWER_LOG) << "Port the encryption/signature handling when saving a KMime::Content.";
 #endif
     QDataStream ds;
     QFile file;
@@ -461,7 +460,7 @@ bool Util::saveContent(QWidget *parent, KMime::Content *content, const QUrl &url
 
     const int bytesWritten = ds.writeRawData(data.data(), data.size());
     if (bytesWritten != data.size()) {
-        QFile *f = static_cast<QFile *>(ds.device());
+        auto f = static_cast<QFile *>(ds.device());
         KMessageBox::error(parent,
                            xi18nc("1 = file name, 2 = error string",
                                   "<qt>Could not write to the file<br /><filename>%1</filename><br /><br />%2</qt>",
@@ -505,27 +504,28 @@ bool Util::saveAttachments(const KMime::Content::List &contents, QWidget *parent
     return Util::saveContents(parent, contents, urlList);
 }
 
-QString Util::generateMboxFileName(const Akonadi::Item &msgBase)
+QString Util::generateFileNameForExtension(const Akonadi::Item &msgBase, const QString &extension)
 {
     QString fileName;
 
     if (msgBase.hasPayload<KMime::Message::Ptr>()) {
-        fileName
-            = MessageCore::StringUtil::cleanFileName(MessageCore::StringUtil::cleanSubject(
-                                                         msgBase.
-                                                         payload
-                                                         <KMime::Message::Ptr>().data()).trimmed());
+        fileName = MessageCore::StringUtil::cleanFileName(MessageCore::StringUtil::cleanSubject(msgBase.payload<KMime::Message::Ptr>().data()).trimmed());
         fileName.remove(QLatin1Char('\"'));
     } else {
         fileName = i18n("message");
     }
 
-    if (!fileName.endsWith(QLatin1String(".mbox"))) {
-        fileName += QLatin1String(".mbox");
+    if (!fileName.endsWith(extension)) {
+        fileName += extension;
     }
     return fileName;
 }
 
+QString Util::generateMboxFileName(const Akonadi::Item &msgBase)
+{
+    return Util::generateFileNameForExtension(msgBase, QStringLiteral(".mbox"));
+}
+
 bool Util::saveMessageInMboxAndGetUrl(QUrl &url, const Akonadi::Item::List &retrievedMsgs, QWidget *parent, bool appendMessages)
 {
     if (retrievedMsgs.isEmpty()) {
@@ -537,17 +537,18 @@ bool Util::saveMessageInMboxAndGetUrl(QUrl &url, const Akonadi::Item::List &retr
     const QString filter = i18n("email messages (*.mbox);;all files (*)");
 
     QString fileClass;
-    const QUrl startUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral(
-                                                            "kfiledialog:///savemessage")),
-                                                   fileClass);
+    const QUrl startUrl = KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///savemessage")), fileClass);
     QUrl localUrl;
     localUrl.setPath(startUrl.path() + QLatin1Char('/') + fileName);
     QFileDialog::Options opt;
     if (appendMessages) {
         opt |= QFileDialog::DontConfirmOverwrite;
     }
-    QUrl dirUrl = QFileDialog::getSaveFileUrl(parent, i18np("Save Message", "Save Messages",
-                                                            retrievedMsgs.count()), QUrl::fromLocalFile(localUrl.toString()), filter, nullptr,
+    QUrl dirUrl = QFileDialog::getSaveFileUrl(parent,
+                                              i18np("Save Message", "Save Messages", retrievedMsgs.count()),
+                                              QUrl::fromLocalFile(localUrl.toString()),
+                                              filter,
+                                              nullptr,
                                               opt);
     if (!dirUrl.isEmpty()) {
         QFile file;
@@ -569,29 +570,25 @@ bool Util::saveMessageInMboxAndGetUrl(QUrl &url, const Akonadi::Item::List &retr
         KMBox::MBox mbox;
         if (!mbox.load(localFileName)) {
             if (appendMessages) {
-                KMessageBox::error(parent, i18n("File %1 could not be loaded.",
-                                                localFileName), i18n("Error loading message"));
+                KMessageBox::error(parent, i18n("File %1 could not be loaded.", localFileName), i18n("Error loading message"));
             } else {
-                KMessageBox::error(parent, i18n("File %1 could not be created.",
-                                                localFileName), i18n("Error saving message"));
+                KMessageBox::error(parent, i18n("File %1 could not be created.", localFileName), i18n("Error saving message"));
             }
             return false;
         }
-        for (const Akonadi::Item &item : qAsConst(retrievedMsgs)) {
+        for (const Akonadi::Item &item : std::as_const(retrievedMsgs)) {
             if (item.hasPayload<KMime::Message::Ptr>()) {
                 mbox.appendMessage(item.payload<KMime::Message::Ptr>());
             }
         }
 
         if (!mbox.save()) {
-            KMessageBox::error(parent, i18n("We cannot save message."),
-                               i18n("Error saving message"));
+            KMessageBox::error(parent, i18n("We cannot save message."), i18n("Error saving message"));
             return false;
         }
-        QUrl localUrl = QUrl::fromLocalFile(localFileName);
+        localUrl = QUrl::fromLocalFile(localFileName);
         if (localUrl.isLocalFile()) {
-            KRecentDirs::add(fileClass, localUrl.adjusted(
-                                 QUrl::RemoveFilename | QUrl::StripTrailingSlash).path());
+            KRecentDirs::add(fileClass, localUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path());
         }
 
         if (!dirUrl.isLocalFile()) {
@@ -632,7 +629,7 @@ QAction *Util::createAppAction(const KService::Ptr &service, bool singleOffer, Q
         actionName = i18nc("@item:inmenu Open With, %1 is application name", "%1", actionName);
     }
 
-    QAction *act = new QAction(parent);
+    auto act = new QAction(parent);
     act->setIcon(QIcon::fromTheme(service->icon()));
     act->setText(actionName);
     actionGroup->addAction(act);
@@ -642,10 +639,167 @@ QAction *Util::createAppAction(const KService::Ptr &service, bool singleOffer, Q
 
 bool Util::excludeExtraHeader(const QString &s)
 {
-    QRegularExpression ref(QStringLiteral("http-equiv=\\s*(\'|\")(&#82;|R)EFRESH(\'|\")"), QRegularExpression::CaseInsensitiveOption);
-    if (s.contains(ref)) {
+    static QRegularExpression divRef(QStringLiteral("</div>"), QRegularExpression::CaseInsensitiveOption);
+    if (s.contains(divRef)) {
+        return true;
+    }
+    static QRegularExpression bodyRef(QStringLiteral("body.s*>.s*div"), QRegularExpression::CaseInsensitiveOption);
+    if (s.contains(bodyRef)) {
         return true;
     }
     return false;
 }
 
+void Util::addHelpTextAction(QAction *act, const QString &text)
+{
+    act->setStatusTip(text);
+    act->setToolTip(text);
+    if (act->whatsThis().isEmpty()) {
+        act->setWhatsThis(text);
+    }
+}
+
+const QTextCodec *Util::codecForName(const QByteArray &_str)
+{
+    if (_str.isEmpty()) {
+        return nullptr;
+    }
+    const QByteArray codec = _str.toLower();
+    return KCharsets::charsets()->codecForName(QLatin1String(codec));
+}
+
+void Util::readGravatarConfig()
+{
+    Gravatar::GravatarCache::self()->setMaximumSize(Gravatar::GravatarSettings::self()->gravatarCacheSize());
+    if (!Gravatar::GravatarSettings::self()->gravatarSupportEnabled()) {
+        Gravatar::GravatarCache::self()->clear();
+    }
+}
+
+QString Util::parseBodyStyle(const QString &style)
+{
+    const int indexStyle = style.indexOf(QLatin1String("style=\""));
+    if (indexStyle != -1) {
+        // qDebug() << " style " << style;
+        const int indexEnd = style.indexOf(QLatin1Char('"'), indexStyle + 7);
+        if (indexEnd != -1) {
+            const QStringView styleStr = QStringView(style).mid(indexStyle + 7, indexEnd - (indexStyle + 7));
+            const auto lstStyle = styleStr.split(QLatin1Char(';'), Qt::SkipEmptyParts);
+            QStringList lst;
+            for (const auto &style : lstStyle) {
+                if (!style.trimmed().contains(QLatin1String("white-space"))) {
+                    lst.append(style.toString().trimmed());
+                }
+            }
+            if (!lst.isEmpty()) {
+                return QStringLiteral(" style=\"%1").arg(lst.join(QLatin1Char(';'))) + QStringLiteral(";\"");
+            }
+        }
+    }
+    return {};
+}
+
+// FIXME this used to go through the full webkit parser to extract the body and head blocks
+// until we have that back, at least attempt to fix some of the damage
+// yes, "parsing" HTML with regexps is very very wrong, but it's still better than not filtering
+// this at all...
+Util::HtmlMessageInfo Util::processHtml(const QString &htmlSource)
+{
+    Util::HtmlMessageInfo messageInfo;
+    QString s = htmlSource.trimmed();
+    static QRegularExpression docTypeRegularExpression = QRegularExpression(QStringLiteral("<!DOCTYPE[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch matchDocType;
+    const int indexDoctype = s.indexOf(docTypeRegularExpression, 0, &matchDocType);
+    QString textBeforeDoctype;
+    if (indexDoctype > 0) {
+        textBeforeDoctype = s.left(indexDoctype);
+        s.remove(textBeforeDoctype);
+    }
+    const QString capturedString = matchDocType.captured();
+    if (!capturedString.isEmpty()) {
+        s = s.remove(capturedString).trimmed();
+    }
+    static QRegularExpression htmlRegularExpression = QRegularExpression(QStringLiteral("<html[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(htmlRegularExpression).trimmed();
+    // head
+    static QRegularExpression headEndRegularExpression = QRegularExpression(QStringLiteral("^<head/>"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(headEndRegularExpression).trimmed();
+    const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
+    if (startIndex >= 0) {
+        const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
+
+        if (endIndex < 0) {
+            messageInfo.htmlSource = htmlSource;
+            return messageInfo;
+        }
+        const int index = startIndex + 6;
+        messageInfo.extraHead = s.mid(index, endIndex - index);
+        if (MessageViewer::Util::excludeExtraHeader(messageInfo.extraHead)) {
+            messageInfo.extraHead.clear();
+        }
+        s = s.remove(startIndex, endIndex - startIndex + 7).trimmed();
+    }
+    // body
+    static QRegularExpression body = QRegularExpression(QStringLiteral("<body[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch matchBody;
+    const int bodyStartIndex = s.indexOf(body, 0, &matchBody);
+    if (bodyStartIndex >= 0) {
+        // qDebug() << "matchBody  " << matchBody.capturedTexts();
+        s = s.remove(bodyStartIndex, matchBody.capturedLength()).trimmed();
+        // Parse style
+        messageInfo.bodyStyle = matchBody.captured();
+    }
+    // Some mail has </div>$ at end
+    static QRegularExpression htmlDivRegularExpression =
+        QRegularExpression(QStringLiteral("(</html></div>|</html>)$"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(htmlDivRegularExpression).trimmed();
+    // s = s.remove(QRegularExpression(QStringLiteral("</html>$"), QRegularExpression::CaseInsensitiveOption)).trimmed();
+    static QRegularExpression bodyEndRegularExpression = QRegularExpression(QStringLiteral("</body>$"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(bodyEndRegularExpression).trimmed();
+    messageInfo.htmlSource = textBeforeDoctype + s;
+    return messageInfo;
+}
+
+QByteArray Util::htmlCodec(const QByteArray &data, const QByteArray &codec)
+{
+    QByteArray currentCodec = codec;
+    if (currentCodec.isEmpty()) {
+        currentCodec = QByteArray("UTF-8");
+    }
+    if (currentCodec == QByteArray("us-ascii")) {
+        currentCodec = QByteArray("iso-8859-1");
+    }
+    if (data.contains("charset=\"utf-8\"") || data.contains("charset=\"UTF-8\"") || data.contains("charset=UTF-8")) {
+        currentCodec = QByteArray("UTF-8");
+    }
+
+    // qDebug() << " codec ******************************************: " << codec << " currentCodec : " <<currentCodec;
+    return currentCodec;
+}
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+QStringConverter::Encoding Util::htmlEncoding(const QByteArray &data, const QByteArray &codec)
+{
+    QByteArray currentCodec = codec;
+    if (currentCodec.isEmpty()) {
+        return QStringConverter::Utf8;
+    }
+    if (currentCodec == QByteArray("us-ascii")) {
+        return QStringConverter::Latin1;
+    }
+    if (data.contains("charset=\"utf-8\"") || data.contains("charset=\"UTF-8\"") || data.contains("charset=UTF-8")) {
+        return QStringConverter::Utf8;
+    }
+
+    // qDebug() << " codec ******************************************: " << codec << " currentCodec : " <<currentCodec;
+    // TODO verify
+    return QStringConverter::System;
+}
+#endif
+
+QDebug operator<<(QDebug d, const Util::HtmlMessageInfo &t)
+{
+    d << " htmlSource " << t.htmlSource;
+    d << " extraHead " << t.extraHead;
+    d << " bodyStyle " << t.bodyStyle;
+    return d;
+}
