@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,15 +8,14 @@
 #include "messagedisplayformatattribute.h"
 #include <QByteArray>
 #include <QDataStream>
+#include <QIODevice>
 
 using namespace MessageViewer;
 
 class MessageViewer::MessageDisplayFormatAttributePrivate
 {
 public:
-    MessageDisplayFormatAttributePrivate()
-    {
-    }
+    MessageDisplayFormatAttributePrivate() = default;
 
     Viewer::DisplayFormatMessage messageFormat = Viewer::UseGlobalSetting;
     bool remoteContent = false;
