@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -16,6 +16,4 @@ MessageWidgetArea::MessageWidgetArea(QWidget *parent)
     mainLayout->setContentsMargins({});
 }
 
-MessageWidgetArea::~MessageWidgetArea()
-{
-}
+MessageWidgetArea::~MessageWidgetArea() = default;
