@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMEPARTTREEVIEW_H
-#define MIMEPARTTREEVIEW_H
+#pragma once
 
-#include <QTreeView>
 #include <KMime/Message>
+#include <QTreeView>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class MimeTreeModel;
 class MimePartTreeView : public QTreeView
 {
     Q_OBJECT
 public:
     explicit MimePartTreeView(QWidget *parent = nullptr);
-    ~MimePartTreeView();
+    ~MimePartTreeView() override;
 
     MessageViewer::MimeTreeModel *mimePartModel() const;
 
@@ -30,8 +30,6 @@ private:
     void slotMimePartDestroyed();
     void saveMimePartTreeConfig();
     void restoreMimePartTreeConfig();
-    MimeTreeModel *mMimePartModel = nullptr;
+    MimeTreeModel *const mMimePartModel;
 };
 }
-
-#endif // MIMEPARTTREEVIEW_H
