@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
   SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
   SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,16 +15,14 @@
 #include "viewer.h"
 #include "csshelper.h"
 #include "dkim-verify/dkimwidgetinfo.h"
-#include "settings/messageviewersettings.h"
 #include "viewer/mimeparttree/mimeparttreeview.h"
 #include "viewer/mimeparttree/mimetreemodel.h"
 #include "viewer/webengine/mailwebengineview.h"
 #include "viewer_p.h"
-#include "widgets/configurewidget.h"
 #include "widgets/zoomactionmenu.h"
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/MessageParts>
+#include <Akonadi/MessageParts>
 #include <QUrl>
 #include <WebEngineViewer/WebEngineManageScript>
 #include <WebEngineViewer/WebHitTestResult>
@@ -35,6 +33,8 @@
 
 #include <QAction>
 
+#include <Akonadi/MDNStateAttribute>
+
 namespace MessageViewer
 {
 class AbstractMessageLoadedHandler::AbstractMessageLoadedHandlerPrivate
@@ -67,10 +67,8 @@ Viewer::Viewer(QWidget *aParent, QWidget *mainWindow, KActionCollection *actionC
     initialize();
 }
 
-Viewer::~Viewer()
-{
-    // the d_ptr is automatically deleted
-}
+// the d_ptr is automatically deleted
+Viewer::~Viewer() = default;
 
 void Viewer::initialize()
 {
@@ -94,6 +92,16 @@ void Viewer::initialize()
     connect(d_ptr, &ViewerPrivate::showPreviousMessage, this, &Viewer::showPreviousMessage);
 
     setMessage(KMime::Message::Ptr(), MimeTreeParser::Delayed);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &Viewer::slotGeneralPaletteChanged);
+#endif
+}
+
+void Viewer::slotGeneralPaletteChanged()
+{
+    Q_D(Viewer);
+    d->updatePalette();
 }
 
 void Viewer::changeEvent(QEvent *event)
@@ -345,6 +353,12 @@ bool Viewer::event(QEvent *e)
         e->accept();
         return true;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    else if (e->type() == QEvent::ApplicationPaletteChange) {
+        slotGeneralPaletteChanged();
+    }
+#endif
+
     return QWidget::event(e);
 }
 
@@ -523,6 +537,7 @@ Akonadi::ItemFetchJob *Viewer::createFetchJob(const Akonadi::Item &item)
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().setFetchRelations(true); // needed to know if we have notes or not
     job->fetchScope().fetchAttribute<MailTransport::ErrorAttribute>();
+    job->fetchScope().fetchAttribute<Akonadi::MDNStateAttribute>();
     return job;
 }
 
@@ -662,6 +677,12 @@ RemoteContentMenu *Viewer::remoteContentMenu() const
     return d->remoteContentMenu();
 }
 
+MessageViewer::MDNWarningWidget *Viewer::mdnWarning() const
+{
+    Q_D(const Viewer);
+    return d->mdnWarning();
+}
+
 void Viewer::setPluginName(const QString &pluginName)
 {
     Q_D(Viewer);
