@@ -13,22 +13,22 @@
 #include "messageviewer_private_export.h"
 #include "viewer.h" //not so nice, it is actually for the enums from MailViewer
 #include "widgets/opensavedfilefolderwidget.h"
-#include <PimCommon/ShareServiceUrlManager>
-#include <WebEngineViewer/CheckPhishingUrlUtil>
-
 #include <Akonadi/Item>
 #include <Akonadi/Monitor>
 #include <Akonadi/Session>
 #include <KIO/Job>
 #include <KMime/Message>
 #include <KService>
+#include <PimCommon/ShareServiceUrlManager>
 #include <QPointer>
 #include <QUrl>
 #include <QVector>
+#include <WebEngineViewer/CheckPhishingUrlUtil>
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
 
 #include <QObject>
 #include <QTimer>
-
+class QTextCodec;
 namespace KIO
 {
 class Job;
@@ -94,6 +94,7 @@ class ViewerPluginToolManager;
 class MailSourceWebEngineViewer;
 class ShowNextMessageWidget;
 class RemoteContentMenu;
+class MDNWarningWidget;
 /**
 \brief Private class for the Viewer, the main widget in the messageviewer library.
 
@@ -286,6 +287,8 @@ private:
     void createOpenWithMenu(QMenu *topMenu, const QString &contentTypeStr, bool fromCurrentContent);
 
 public:
+    void updatePalette();
+
     void itemFetchResult(KJob *job);
 
     /** Read settings from app's config file. */
@@ -441,7 +444,8 @@ public:
     void setIdentityManager(KIdentityManagement::IdentityManager *ident);
     void setFolderIdentity(uint folderIdentity);
 
-    RemoteContentMenu *remoteContentMenu() const;
+    Q_REQUIRED_RESULT RemoteContentMenu *remoteContentMenu() const;
+    Q_REQUIRED_RESULT MessageViewer::MDNWarningWidget *mdnWarning() const;
 
 private Q_SLOTS:
     void slotActivatePlugin(MessageViewer::ViewerPluginInterface *interface);
@@ -613,6 +617,7 @@ private:
     bool mHtmlLoadExternalDefaultSetting = false;
     bool mHtmlLoadExtOverride = false;
     void slotUrlBlocked(const QUrl &url);
+    void updateColorFromScheme();
 
 public:
     KMime::Message::Ptr mMessage; // the current message, if it was set manually
@@ -695,7 +700,9 @@ public:
     MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
     WebEngineViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
     WebEngineViewer::TrackingWarningWidget *mMailTrackingWarning = nullptr;
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+#endif
     Viewer::DisplayFormatMessage mDisplayFormatMessageOverwrite;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
     PimCommon::ShareServiceUrlManager *mShareServiceManager = nullptr;
@@ -713,6 +720,6 @@ public:
     MessageViewer::MessageViewerRenderer *mMessageViewerRenderer = nullptr;
     KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
     RemoteContentMenu *mRemoteContentMenu = nullptr;
+    MessageViewer::MDNWarningWidget *mMdnWarning = nullptr;
 };
 }
-
