@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,35 +8,35 @@
 #include "htmlwriter/webengineembedpart.h"
 
 #include <QBuffer>
-#include <QUrl>
-#include <QImage>
 #include <QDebug>
+#include <QImage>
+#include <QUrl>
 #include <QWebEngineUrlRequestInfo>
 
 using namespace MessageViewer;
-#define LOAD_FROM_FILE 1
+// #define LOAD_FROM_FILE 1
 CidReferencesUrlInterceptor::CidReferencesUrlInterceptor(QObject *parent)
     : WebEngineViewer::NetworkPluginUrlInterceptorInterface(parent)
 {
 }
 
-CidReferencesUrlInterceptor::~CidReferencesUrlInterceptor()
-{
-}
+CidReferencesUrlInterceptor::~CidReferencesUrlInterceptor() = default;
 
 bool CidReferencesUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
     const QUrl urlRequestUrl(info.requestUrl());
     if (urlRequestUrl.scheme() == QLatin1String("cid")) {
         if (info.resourceType() == QWebEngineUrlRequestInfo::ResourceTypeImage) {
-            const QUrl newUrl = QUrl(MessageViewer::WebEngineEmbedPart::self()->contentUrl(
-                        urlRequestUrl.path()));
+            const QUrl newUrl = QUrl(MessageViewer::WebEngineEmbedPart::self()->contentUrl(urlRequestUrl.path()));
             if (!newUrl.isEmpty()) {
 #ifdef LOAD_FROM_FILE
                 QImage image(newUrl.path());
                 QByteArray ba;
                 QBuffer buf(&ba);
+                // Reduce image.
+                image = image.scaled(800, 600);
                 image.save(&buf, "png");
+
                 const QByteArray hexed = ba.toBase64();
                 buf.close();
                 const QUrl r = QUrl(QString::fromUtf8(QByteArray("data:image/png;base64,") + hexed));
