@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ LoadExternalReferencesUrlInterceptor::LoadExternalReferencesUrlInterceptor(QObje
 {
 }
 
-LoadExternalReferencesUrlInterceptor::~LoadExternalReferencesUrlInterceptor()
-{
-}
+LoadExternalReferencesUrlInterceptor::~LoadExternalReferencesUrlInterceptor() = default;
 bool LoadExternalReferencesUrlInterceptor::urlIsBlocked(const QUrl &requestedUrl)
 {
     const QUrl url = requestedUrl.adjusted(QUrl::RemovePath | QUrl::RemovePort | QUrl::RemoveQuery);
