@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,19 +16,20 @@
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineManageScript>
 
-#include "scamdetection/scamcheckshorturl.h"
 #include "scamdetection/scamdetectionwebengine.h"
 #include <QContextMenuEvent>
 #include <QWebEngineProfile>
 #include <WebEngineViewer/WebHitTest>
 
+#include <QPainter>
 #include <QPrinter>
 #include <QWebEngineUrlScheme>
 
 #include <WebEngineViewer/WebHitTestResult>
 
 using namespace MessageViewer;
-template<typename Arg, typename R, typename C> struct InvokeWrapper {
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
     R *receiver;
     void (C::*memberFunction)(Arg);
     void operator()(Arg result)
@@ -48,9 +49,7 @@ InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFunction)(Arg))
 class MessageViewer::MailWebEngineViewPrivate
 {
 public:
-    MailWebEngineViewPrivate()
-    {
-    }
+    MailWebEngineViewPrivate() = default;
 
     QUrl mHoveredUrl;
     QPoint mLastClickPosition;
@@ -358,7 +357,8 @@ bool MailWebEngineView::execPrintPreviewPage(QPrinter *printer, int timeout)
 void MailWebEngineView::initializeCustomScheme()
 {
     QWebEngineUrlScheme cidScheme("cid");
-    cidScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored);
+    cidScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored | QWebEngineUrlScheme::LocalScheme
+                       | QWebEngineUrlScheme::LocalAccessAllowed);
     cidScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
     QWebEngineUrlScheme::registerScheme(cidScheme);
 }
