@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,9 +26,7 @@ TestMailMBoxWebEngine::TestMailMBoxWebEngine(QWidget *parent)
     viewer->setPluginName(QStringLiteral("longheaderstyleplugin"));
 }
 
-TestMailMBoxWebEngine::~TestMailMBoxWebEngine()
-{
-}
+TestMailMBoxWebEngine::~TestMailMBoxWebEngine() = default;
 
 KMime::Message::Ptr TestMailMBoxWebEngine::readAndParseMail(const QString &mailFile)
 {
@@ -47,7 +45,9 @@ KMime::Message::Ptr TestMailMBoxWebEngine::readAndParseMail(const QString &mailF
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto testWebEngine = new TestMailMBoxWebEngine;
     testWebEngine->show();
     const int ret = app.exec();
