@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ using namespace MessageViewer;
 class MessageViewer::ViewerPluginInterfacePrivate
 {
 public:
-    ViewerPluginInterfacePrivate()
-    {
-    }
+    ViewerPluginInterfacePrivate() = default;
 };
 
 ViewerPluginInterface::ViewerPluginInterface(QObject *parent)
