@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILSOURCEWEBENGINEVIEWER_H
-#define MAILSOURCEWEBENGINEVIEWER_H
+#pragma once
 
 #include <QDialog>
 class QTabWidget;
 class QWebEnginePage;
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class FindBarSourceView;
 class MailSourceViewTextBrowserWidget;
 class MailSourceWebEngineViewer : public QDialog
@@ -19,19 +19,19 @@ class MailSourceWebEngineViewer : public QDialog
     Q_OBJECT
 public:
     explicit MailSourceWebEngineViewer(QWidget *parent = nullptr);
-    ~MailSourceWebEngineViewer();
+    ~MailSourceWebEngineViewer() override;
 
     void setRawSource(const QString &source);
     void setDisplayedSource(QWebEnginePage *page);
     void setFixedFont();
+
 private:
     void readConfig();
     void writeConfig();
-    MailSourceViewTextBrowserWidget *mRawBrowser = nullptr;
+    MailSourceViewTextBrowserWidget *const mRawBrowser;
     FindBarSourceView *mFindBar = nullptr;
     QTabWidget *mTabWidget = nullptr;
     MailSourceViewTextBrowserWidget *mHtmlBrowser = nullptr;
     bool mShowHtmlSource = false;
 };
 }
-#endif // MAILSOURCEWEBENGINEVIEWER_H
