@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -32,9 +32,7 @@ ShowNextMessageWidget::ShowNextMessageWidget(QWidget *parent)
     setMaximumHeight(mNextMessage->height() + 4);
 }
 
-ShowNextMessageWidget::~ShowNextMessageWidget()
-{
-}
+ShowNextMessageWidget::~ShowNextMessageWidget() = default;
 
 void ShowNextMessageWidget::updateButton(bool hasPreviousMessage, bool hasNextMessage)
 {
