@@ -8,22 +8,22 @@
     SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef MIMETREEPARSER_CRYPTOHELPER_H
-#define MIMETREEPARSER_CRYPTOHELPER_H
+#pragma once
 
 #include <QByteArray>
 #include <QVector>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 enum PGPBlockType {
-    UnknownBlock = -1,        // BEGIN PGP ???
+    UnknownBlock = -1, // BEGIN PGP ???
     NoPgpBlock = 0,
-    PgpMessageBlock = 1,      // BEGIN PGP MESSAGE
+    PgpMessageBlock = 1, // BEGIN PGP MESSAGE
     MultiPgpMessageBlock = 2, // BEGIN PGP MESSAGE, PART X[/Y]
-    SignatureBlock = 3,       // BEGIN PGP SIGNATURE
-    ClearsignedBlock = 4,     // BEGIN PGP SIGNED MESSAGE
-    PublicKeyBlock = 5,       // BEGIN PGP PUBLIC KEY BLOCK
-    PrivateKeyBlock = 6       // BEGIN PGP PRIVATE KEY BLOCK (PGP 2.x: ...SECRET...)
+    SignatureBlock = 3, // BEGIN PGP SIGNATURE
+    ClearsignedBlock = 4, // BEGIN PGP SIGNED MESSAGE
+    PublicKeyBlock = 5, // BEGIN PGP PUBLIC KEY BLOCK
+    PrivateKeyBlock = 6, // BEGIN PGP PRIVATE KEY BLOCK (PGP 2.x: ...SECRET...)
 };
 
 class Block
@@ -49,5 +49,3 @@ QVector<Block> prepareMessageForDecryption(const QByteArray &msg);
 } // namespace MimeTreeParser
 
 Q_DECLARE_TYPEINFO(MimeTreeParser::Block, Q_MOVABLE_TYPE);
-
-#endif
