@@ -17,10 +17,10 @@
 #include "bodyformatter/utils.h"
 
 #include <KMime/Content>
+#include <Libkleo/KeyCache>
 
 #include <QGpgME/DN>
 #include <QGpgME/ImportJob>
-#include <QGpgME/KeyListJob>
 #include <QGpgME/Protocol>
 #include <QGpgME/VerifyDetachedJob>
 #include <QGpgME/VerifyOpaqueJob>
@@ -269,7 +269,7 @@ const KMime::Headers::Base *MimeTreeParser::MessagePart::header(const char *head
 QVector<KMime::Headers::Base *> MessagePart::headers(const char *headerType) const
 {
     Q_UNUSED(headerType)
-    return QVector<KMime::Headers::Base *>();
+    return {};
 }
 
 //-----MessagePartList----------------------
@@ -278,9 +278,7 @@ MessagePartList::MessagePartList(ObjectTreeParser *otp)
 {
 }
 
-MessagePartList::~MessagePartList()
-{
-}
+MessagePartList::~MessagePartList() = default;
 
 QString MessagePartList::text() const
 {
@@ -289,12 +287,12 @@ QString MessagePartList::text() const
 
 QString MessagePartList::plaintextContent() const
 {
-    return QString();
+    return {};
 }
 
 QString MessagePartList::htmlContent() const
 {
-    return QString();
+    return {};
 }
 
 //-----TextMessageBlock----------------------
@@ -313,9 +311,7 @@ TextMessagePart::TextMessagePart(ObjectTreeParser *otp, KMime::Content *node, bo
     parseContent();
 }
 
-TextMessagePart::~TextMessagePart()
-{
-}
+TextMessagePart::~TextMessagePart() = default;
 
 bool TextMessagePart::decryptMessage() const
 {
@@ -459,9 +455,7 @@ AttachmentMessagePart::AttachmentMessagePart(ObjectTreeParser *otp, KMime::Conte
 {
 }
 
-AttachmentMessagePart::~AttachmentMessagePart()
-{
-}
+AttachmentMessagePart::~AttachmentMessagePart() = default;
 
 //-----HtmlMessageBlock----------------------
 
@@ -480,9 +474,7 @@ HtmlMessagePart::HtmlMessagePart(ObjectTreeParser *otp, KMime::Content *node, In
     mCharset = NodeHelper::charset(node);
 }
 
-HtmlMessagePart::~HtmlMessagePart()
-{
-}
+HtmlMessagePart::~HtmlMessagePart() = default;
 
 void HtmlMessagePart::fix() const
 {
@@ -497,7 +489,7 @@ QString HtmlMessagePart::text() const
 
 QString MimeTreeParser::HtmlMessagePart::plaintextContent() const
 {
-    return QString();
+    return {};
 }
 
 bool HtmlMessagePart::isHtml() const
@@ -525,9 +517,7 @@ MimeMessagePart::MimeMessagePart(ObjectTreeParser *otp, KMime::Content *node, bo
     parseInternal(node, mOnlyOneMimePart);
 }
 
-MimeMessagePart::~MimeMessagePart()
-{
-}
+MimeMessagePart::~MimeMessagePart() = default;
 
 QString MimeMessagePart::text() const
 {
@@ -536,12 +526,12 @@ QString MimeMessagePart::text() const
 
 QString MimeMessagePart::plaintextContent() const
 {
-    return QString();
+    return {};
 }
 
 QString MimeMessagePart::htmlContent() const
 {
-    return QString();
+    return {};
 }
 
 //-----AlternativeMessagePart----------------------
@@ -596,9 +586,7 @@ AlternativeMessagePart::AlternativeMessagePart(ObjectTreeParser *otp, KMime::Con
     }
 }
 
-AlternativeMessagePart::~AlternativeMessagePart()
-{
-}
+AlternativeMessagePart::~AlternativeMessagePart() = default;
 
 Util::HtmlMode AlternativeMessagePart::preferredMode() const
 {
@@ -620,7 +608,7 @@ QString AlternativeMessagePart::text() const
     if (mChildParts.contains(Util::MultipartPlain)) {
         return mChildParts[Util::MultipartPlain]->text();
     }
-    return QString();
+    return {};
 }
 
 void AlternativeMessagePart::fix() const
@@ -683,13 +671,11 @@ CertMessagePart::CertMessagePart(ObjectTreeParser *otp, KMime::Content *node, co
     mImportResult = executor.exec(import, certData);
 }
 
-CertMessagePart::~CertMessagePart()
-{
-}
+CertMessagePart::~CertMessagePart() = default;
 
 QString CertMessagePart::text() const
 {
-    return QString();
+    return {};
 }
 
 const GpgME::ImportResult &CertMessagePart::importResult() const
@@ -717,9 +703,7 @@ SignedMessagePart::SignedMessagePart(ObjectTreeParser *otp,
     partMetaData()->status_code = GPGME_SIG_STAT_NONE;
 }
 
-SignedMessagePart::~SignedMessagePart()
-{
-}
+SignedMessagePart::~SignedMessagePart() = default;
 
 void SignedMessagePart::setIsSigned(bool isSigned)
 {
@@ -862,27 +846,9 @@ void SignedMessagePart::sigStatusToMetaData()
         if (partMetaData()->isGoodSignature && !key.keyID()) {
             // Search for the key by its fingerprint so that we can check for
             // trust etc.
-            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false); // local, no sigs
-            if (!job) {
-                qCDebug(MIMETREEPARSER_LOG) << "The Crypto backend does not support listing keys. ";
-            } else {
-                std::vector<GpgME::Key> found_keys;
-                // As we are local it is ok to make this synchronous
-                GpgME::KeyListResult res = job->exec(QStringList(QLatin1String(signature.fingerprint())), false, found_keys);
-                if (res.error()) {
-                    qCDebug(MIMETREEPARSER_LOG) << "Error while searching key for Fingerprint: " << signature.fingerprint();
-                }
-                if (found_keys.size() > 1) {
-                    // Should not Happen
-                    qCDebug(MIMETREEPARSER_LOG) << "Oops: Found more then one Key for Fingerprint: " << signature.fingerprint();
-                }
-                if (found_keys.size() != 1) {
-                    // Should not Happen at this point
-                    qCDebug(MIMETREEPARSER_LOG) << "Oops: Found no Key for Fingerprint: " << signature.fingerprint();
-                } else {
-                    key = found_keys[0];
-                }
-                delete job;
+            key = Kleo::KeyCache::instance()->findByFingerprint(signature.fingerprint());
+            if (key.isNull()) {
+                qCDebug(MIMETREEPARSER_LOG) << "Found no Key for Fingerprint" << signature.fingerprint();
             }
         }
 
@@ -896,16 +862,11 @@ void SignedMessagePart::sigStatusToMetaData()
         if (key.numUserIDs() > 0 && key.userID(0).id()) {
             partMetaData()->signer = prettifyDN(key.userID(0).id());
         }
-        for (uint iMail = 0; iMail < key.numUserIDs(); ++iMail) {
+        for (const auto &uid : key.userIDs()) {
             // The following if /should/ always result in TRUE but we
             // won't trust implicitly the plugin that gave us these data.
-            if (key.userID(iMail).email()) {
-                QString email = QString::fromUtf8(key.userID(iMail).email());
-                // ### work around gpgme 0.3.QString text() const override;x / cryptplug bug where the
-                // ### email addresses are specified as angle-addr, not addr-spec:
-                if (email.startsWith(QLatin1Char('<')) && email.endsWith(QLatin1Char('>'))) {
-                    email = email.mid(1, email.length() - 2);
-                }
+            if (uid.email()) {
+                QString email = QString::fromUtf8(uid.email());
                 if (!email.isEmpty()) {
                     partMetaData()->signerMailAddresses.append(email);
                 }
@@ -1010,7 +971,7 @@ QString SignedMessagePart::plaintextContent() const
     if (!content()) {
         return MessagePart::text();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -1019,7 +980,7 @@ QString SignedMessagePart::htmlContent() const
     if (!content()) {
         return MessagePart::text();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -1054,7 +1015,7 @@ QVector<KMime::Headers::Base *> SignedMessagePart::headers(const char *headerTyp
     if (content()) {
         return content()->headersByType(headerType);
     }
-    return QVector<KMime::Headers::Base *>();
+    return {};
 }
 
 //-----CryptMessageBlock---------------------
@@ -1082,9 +1043,7 @@ EncryptedMessagePart::EncryptedMessagePart(ObjectTreeParser *otp,
     partMetaData()->status_code = GPGME_SIG_STAT_NONE;
 }
 
-EncryptedMessagePart::~EncryptedMessagePart()
-{
-}
+EncryptedMessagePart::~EncryptedMessagePart() = default;
 
 void EncryptedMessagePart::setDecryptMessage(bool decrypt)
 {
@@ -1224,28 +1183,17 @@ bool EncryptedMessagePart::okDecryptMIME(KMime::Content &data)
                 bDecryptionOk = true;
             }
             GpgME::Key key;
-            QGpgME::KeyListJob *job = mCryptoProto->keyListJob(false, false, false); // local, no sigs
-            if (!job) {
-                qCDebug(MIMETREEPARSER_LOG) << "The Crypto backend does not support listing keys. ";
-            } else {
-                std::vector<GpgME::Key> found_keys;
-                // As we are local it is ok to make this synchronous
-                GpgME::KeyListResult res = job->exec(QStringList(QLatin1String(recipient.keyID())), false, found_keys);
-                if (res.error()) {
-                    qCDebug(MIMETREEPARSER_LOG) << "Error while searching key for Fingerprint: " << recipient.keyID();
+            key = Kleo::KeyCache::instance()->findByKeyIDOrFingerprint(recipient.keyID());
+            if (key.isNull()) {
+                auto ret = Kleo::KeyCache::instance()->findSubkeysByKeyID({recipient.keyID()});
+                if (ret.size() == 1) {
+                    key = ret.front().parent();
                 }
-                if (found_keys.size() > 1) {
-                    // Should not Happen
-                    qCDebug(MIMETREEPARSER_LOG) << "Oops: Found more then one Key for Fingerprint: " << recipient.keyID();
-                }
-                if (found_keys.size() != 1) {
-                    // Should not Happen at this point
-                    qCDebug(MIMETREEPARSER_LOG) << "Oops: Found no Key for Fingerprint: " << recipient.keyID();
-                } else {
-                    key = found_keys[0];
+                if (key.isNull()) {
+                    qCDebug(MIMETREEPARSER_LOG) << "Found no Key for KeyID " << recipient.keyID();
                 }
             }
-            mDecryptRecipients.push_back(std::make_pair(recipient, key));
+            mDecryptRecipients.emplace_back(recipient, key);
         }
 
         if (!bDecryptionOk && partMetaData()->isSigned) {
@@ -1349,7 +1297,7 @@ QString EncryptedMessagePart::plaintextContent() const
     if (!content()) {
         return MessagePart::text();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -1358,7 +1306,7 @@ QString EncryptedMessagePart::htmlContent() const
     if (!content()) {
         return MessagePart::text();
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -1415,7 +1363,7 @@ QVector<KMime::Headers::Base *> EncryptedMessagePart::headers(const char *header
     if (extraContent) {
         return nodeHelper()->headers(headerType, extraContent);
     }
-    return QVector<KMime::Headers::Base *>();
+    return {};
 }
 
 EncapsulatedRfc822MessagePart::EncapsulatedRfc822MessagePart(ObjectTreeParser *otp, KMime::Content *node, const KMime::Message::Ptr &message)
@@ -1442,9 +1390,7 @@ EncapsulatedRfc822MessagePart::EncapsulatedRfc822MessagePart(ObjectTreeParser *o
     parseInternal(message.data(), false);
 }
 
-EncapsulatedRfc822MessagePart::~EncapsulatedRfc822MessagePart()
-{
-}
+EncapsulatedRfc822MessagePart::~EncapsulatedRfc822MessagePart() = default;
 
 QString EncapsulatedRfc822MessagePart::text() const
 {
