@@ -19,8 +19,6 @@
 #include "nodehelper.h"
 #include "partnodebodypart.h"
 
-#include "mimetreeparser_debug.h"
-
 #include "bodyformatter/utils.h"
 #include "interfaces/bodypartformatter.h"
 #include "utils/util.h"
@@ -146,7 +144,7 @@ MessagePartPtr ObjectTreeParser::processType(KMime::Content *node, ProcessResult
         mNodeHelper->setNodeDisplayedEmbedded(node, true);
 
         const MessagePart::Ptr result = formatter->process(part);
-        if (!result) {
+        if (result.isNull()) {
             continue;
         }
 
@@ -161,7 +159,7 @@ MessagePartPtr ObjectTreeParser::processType(KMime::Content *node, ProcessResult
 MessagePart::Ptr ObjectTreeParser::parseObjectTreeInternal(KMime::Content *node, bool onlyOneMimePart)
 {
     if (!node) {
-        return MessagePart::Ptr();
+        return {};
     }
 
     // reset pending async jobs state (we'll rediscover pending jobs as we go)
