@@ -2,30 +2,24 @@
     partmetadata.h
 
     KMail, the KDE mail client.
-    Copyright (c) 2002-2003 Karl-Heinz Zimmer <khz@kde.org>
-    Copyright (c) 2003      Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Karl -Heinz Zimmer <khz@kde.org>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_PARTMETADATA_H
-#define MIMETREEPARSER_PARTMETADATA_H
+#pragma once
 
 #include "mimetreeparser_export.h"
 
-#include <gpgme++/verificationresult.h>
 #include <gpgme++/context.h>
+#include <gpgme++/verificationresult.h>
 
-#include <QStringList>
 #include <QDateTime>
+#include <QStringList>
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class PartMetaData
 {
 public:
@@ -47,7 +41,7 @@ public:
     QStringList signerMailAddresses;
     QByteArray keyId;
     GpgME::Signature::Validity keyTrust;
-    QString status;  // to be used for unknown plug-ins
+    QString status; // to be used for unknown plug-ins
     int status_code; // to be used for i18n of OpenPGP and S/MIME CryptPlugs
     QString errorText;
     QDateTime creationTime;
@@ -63,5 +57,3 @@ public:
     bool isEncapsulatedRfc822Message : 1;
 };
 }
-
-#endif // MIMETREEPARSER_PARTMETADATA_H
