@@ -1,19 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateparserjobtest.h"
 
-#ifndef _WIN32
-#define private public
-#endif
 #include "templateparserjob.h"
 #include "templateparserjob_p.h"
-#ifndef _WIN32
-#undef protected
-#endif
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityManager>
 #include <MimeTreeParser/ObjectTreeParser>
