@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -454,9 +454,7 @@ CustomTemplateItemDelegate::CustomTemplateItemDelegate(QObject *parent)
 {
 }
 
-CustomTemplateItemDelegate::~CustomTemplateItemDelegate()
-{
-}
+CustomTemplateItemDelegate::~CustomTemplateItemDelegate() = default;
 
 void CustomTemplateItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
@@ -493,9 +491,7 @@ CustomTemplateItem::CustomTemplateItem(QTreeWidget *parent,
     setFlags(flags() | Qt::ItemIsEditable);
 }
 
-CustomTemplateItem::~CustomTemplateItem()
-{
-}
+CustomTemplateItem::~CustomTemplateItem() = default;
 
 void CustomTemplateItem::setCustomType(CustomTemplates::Type type)
 {
