@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ TemplateConvertCommandJob::TemplateConvertCommandJob(QObject *parent)
 {
 }
 
-TemplateConvertCommandJob::~TemplateConvertCommandJob()
-{
-}
+TemplateConvertCommandJob::~TemplateConvertCommandJob() = default;
 
 QString TemplateConvertCommandJob::convertText()
 {
