@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -144,7 +144,7 @@ int TemplateParserJob::parseQuotes(const QString &prefix, const QString &str, QS
 
     // Also allow the german lower double-quote sign as quote separator, not only
     // the standard ASCII quote ("). This fixes bug 166728.
-    const QList<QChar> quoteChars = {QLatin1Char('"'), 0x201C};
+    const QList<QChar> quoteChars = {QLatin1Char('"'), QChar(0x201C)};
 
     QChar prev(QChar::Null);
 
@@ -235,7 +235,7 @@ MimeTreeParser::MessagePart::Ptr toplevelTextNode(MimeTreeParser::MessagePart::P
             }
         }
     }
-    return MimeTreeParser::MessagePart::Ptr();
+    return {};
 }
 
 void TemplateParserJob::processWithTemplate(const QString &tmpl)
@@ -1066,6 +1066,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
         || !TemplateParserSettings::self()->replyUsingVisualFormat() || (!content || !content->hasContent())) {
         htmlBody.clear();
     } else {
+        // qDebug() << "htmlBody********************* " << htmlBody;
         makeValidHtml(htmlBody);
     }
     if (d->mMode == NewMessage && plainBody.isEmpty() && !d->mExtractHtmlInfoResult.mPlainText.isEmpty()) {
@@ -1082,7 +1083,7 @@ QString TemplateParserJob::getPlainSignature() const
     const KIdentityManagement::Identity &identity = d->m_identityManager->identityForUoid(d->mIdentity);
 
     if (identity.isNull()) {
-        return QString();
+        return {};
     }
 
     KIdentityManagement::Signature signature = const_cast<KIdentityManagement::Identity &>(identity).signature();
@@ -1101,7 +1102,7 @@ QString TemplateParserJob::getHtmlSignature() const
 {
     const KIdentityManagement::Identity &identity = d->m_identityManager->identityForUoid(d->mIdentity);
     if (identity.isNull()) {
-        return QString();
+        return {};
     }
 
     KIdentityManagement::Signature signature = const_cast<KIdentityManagement::Identity &>(identity).signature();
@@ -1278,7 +1279,7 @@ QString TemplateParserJob::findTemplate()
                 break;
             default:
                 qCDebug(TEMPLATEPARSER_LOG) << "Unknown message mode:" << d->mMode;
-                return QString();
+                return {};
             }
             d->mQuoteString = fconf.quoteString();
             if (!tmpl.isEmpty()) {
@@ -1323,7 +1324,7 @@ QString TemplateParserJob::findTemplate()
             break;
         default:
             qCDebug(TEMPLATEPARSER_LOG) << "Unknown message mode:" << d->mMode;
-            return QString();
+            return {};
         }
         d->mQuoteString = iconf.quoteString();
         if (!tmpl.isEmpty()) {
@@ -1346,7 +1347,7 @@ QString TemplateParserJob::findTemplate()
         break;
     default:
         qCDebug(TEMPLATEPARSER_LOG) << "Unknown message mode:" << d->mMode;
-        return QString();
+        return {};
     }
 
     d->mQuoteString = TemplateParserSettings::self()->quoteString();
@@ -1397,7 +1398,7 @@ QString TemplateParserJob::pipe(const QString &cmd, const QString &buf)
     if (success) {
         return QTextCodec::codecForLocale()->toUnicode(process.readAllStandardOutput());
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -1414,7 +1415,7 @@ QString TemplateParserJob::plainMessageText(bool aStripSignature, AllowSelection
     }
 
     if (!d->mOrigMsg) {
-        return QString();
+        return {};
     }
     const auto mp = toplevelTextNode(d->mOtp->parsedPart());
     QString result = mp->plaintextContent();
