@@ -1,21 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEMPLATESTEXTEDITOR_H
-#define TEMPLATESTEXTEDITOR_H
+#pragma once
 
 #include <KPIMTextEdit/PlainTextEditor>
 
 #include <KSyntaxHighlighting/Repository>
 
 class QKeyEvent;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextEditorCompleter;
 }
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TemplatesTextEditor : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -31,9 +32,9 @@ protected:
 
     void clearDecorator() override;
     void createHighlighter() override;
+
 private:
     KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
     KSyntaxHighlighting::Repository mSyntaxRepo;
 };
 }
-#endif // TEMPLATESTEXTEDITOR_H
