@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -101,7 +101,7 @@ QString TemplateParser::Util::getFirstNameFromEmail(const QString &str)
     }
     return res;
 }
-
+#include <QDebug>
 QString TemplateParser::Util::getLastNameFromEmail(const QString &str)
 {
     // simple logic:
@@ -134,6 +134,7 @@ QString TemplateParser::Util::getLastNameFromEmail(const QString &str)
             }
         }
     }
+    qDebug() << " res " << res;
     return res;
 }
 
