@@ -1,21 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEMPLATEWEBENGINEPAGE_H
-#define TEMPLATEWEBENGINEPAGE_H
+#pragma once
 
 #include <QWebEnginePage>
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TemplateWebEnginePage : public QWebEnginePage
 {
     Q_OBJECT
 public:
     explicit TemplateWebEnginePage(QObject *parent = nullptr);
-    ~TemplateWebEnginePage();
+    ~TemplateWebEnginePage() override;
 };
 }
-
-#endif // TEMPLATEWEBENGINEPAGE_H
