@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef TEST_TEMPLATECONFIGUREWIDGET_GUI_H
-#define TEST_TEMPLATECONFIGUREWIDGET_GUI_H
+#pragma once
 
 #include <QWidget>
 
@@ -14,7 +13,5 @@ class TemplateConfigureTestWidget : public QWidget
     Q_OBJECT
 public:
     explicit TemplateConfigureTestWidget(QWidget *parent = nullptr);
-    ~TemplateConfigureTestWidget();
+    ~TemplateConfigureTestWidget() override;
 };
-
-#endif
