@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,21 +7,19 @@
 #include "templateeditor_gui.h"
 #include "templateparser/templatestextedit.h"
 
-#include <QHBoxLayout>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QHBoxLayout>
 #include <QStandardPaths>
 
 TemplateEditorTestWidget::TemplateEditorTestWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->addWidget(new TemplateParser::TemplatesTextEdit(this));
 }
 
-TemplateEditorTestWidget::~TemplateEditorTestWidget()
-{
-}
+TemplateEditorTestWidget::~TemplateEditorTestWidget() = default;
 
 int main(int argc, char **argv)
 {
@@ -33,7 +31,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    TemplateEditorTestWidget *w = new TemplateEditorTestWidget();
+    auto w = new TemplateEditorTestWidget();
     w->resize(800, 600);
 
     w->show();
