@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,22 +8,20 @@
 #include "templateparser/templatestextedit.h"
 #include "templateparseremailaddressrequesterinterfacewidget.h"
 
-#include <QHBoxLayout>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QHBoxLayout>
 #include <QStandardPaths>
 
 TemplateParserEmailRequesterTestWidget::TemplateParserEmailRequesterTestWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget *w = new TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget(this);
+    auto lay = new QHBoxLayout(this);
+    auto w = new TemplateParser::TemplateParserEmailAddressRequesterInterfaceWidget(this);
     lay->addWidget(w);
 }
 
-TemplateParserEmailRequesterTestWidget::~TemplateParserEmailRequesterTestWidget()
-{
-}
+TemplateParserEmailRequesterTestWidget::~TemplateParserEmailRequesterTestWidget() = default;
 
 int main(int argc, char **argv)
 {
@@ -35,7 +33,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    TemplateParserEmailRequesterTestWidget *w = new TemplateParserEmailRequesterTestWidget();
+    auto w = new TemplateParserEmailRequesterTestWidget();
     w->resize(800, 600);
 
     w->show();
