@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ZOOMACTIONMENUTEST_H
-#define ZOOMACTIONMENUTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,8 @@ class ZoomActionMenuTest : public QObject
     Q_OBJECT
 public:
     explicit ZoomActionMenuTest(QObject *parent = nullptr);
-    ~ZoomActionMenuTest();
+    ~ZoomActionMenuTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAssignZoomFactor();
 };
-
-#endif // ZOOMACTIONMENUTEST_H
