@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ CheckPhishingUrlCacheTest::CheckPhishingUrlCacheTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-CheckPhishingUrlCacheTest::~CheckPhishingUrlCacheTest()
-{
-}
+CheckPhishingUrlCacheTest::~CheckPhishingUrlCacheTest() = default;
 
 void CheckPhishingUrlCacheTest::shouldNotBeAMalware()
 {
