@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -52,8 +52,6 @@ LocalDataBaseManagerTest::LocalDataBaseManagerTest(QObject *parent)
 {
 }
 
-LocalDataBaseManagerTest::~LocalDataBaseManagerTest()
-{
-}
+LocalDataBaseManagerTest::~LocalDataBaseManagerTest() = default;
 
 QTEST_GUILESS_MAIN(LocalDataBaseManagerTest)
