@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ VerifyDataBaseUpdateTest::VerifyDataBaseUpdateTest(QObject *parent)
 {
 }
 
-VerifyDataBaseUpdateTest::~VerifyDataBaseUpdateTest()
-{
-}
+VerifyDataBaseUpdateTest::~VerifyDataBaseUpdateTest() = default;
 
 void VerifyDataBaseUpdateTest::shouldVerifyCheckSums_data()
 {
