@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,7 +11,6 @@
 #include <PimCommon/NetworkManager>
 
 #include <QJsonDocument>
-#include <QNetworkConfigurationManager>
 #include <QUrlQuery>
 
 using namespace WebEngineViewer;
@@ -54,7 +53,7 @@ void CreatePhishingUrlDataBaseJob::slotSslErrors(QNetworkReply *reply, const QLi
 
 void CreatePhishingUrlDataBaseJob::start()
 {
-    if (!PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (!PimCommon::NetworkManager::self()->isOnline()) {
         Q_EMIT finished(UpdateDataBaseInfo(), BrokenNetwork);
         deleteLater();
     } else {
