@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef LOCALDATABASEMANAGER_H
-#define LOCALDATABASEMANAGER_H
+#pragma once
 
-#include <QObject>
-#include "webengineviewer_export.h"
 #include "createphishingurldatabasejob.h"
 #include "searchfullhashjob.h"
+#include "webengineviewer_export.h"
+#include <QObject>
 #include <QUrl>
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineView;
 class LocalDataBaseManagerPrivate;
 /**
@@ -24,7 +24,7 @@ class WEBENGINEVIEWER_EXPORT LocalDataBaseManager : public QObject
     Q_OBJECT
 public:
     explicit LocalDataBaseManager(QObject *parent = nullptr);
-    ~LocalDataBaseManager();
+    ~LocalDataBaseManager() override;
 
     void checkUrl(const QUrl &url);
 
@@ -39,5 +39,3 @@ protected:
     LocalDataBaseManagerPrivate *const d;
 };
 }
-
-#endif // LOCALDATABASEMANAGER_H
