@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,6 @@
 #include <PimCommon/NetworkManager>
 #include <QJsonDocument>
 #include <QNetworkAccessManager>
-#include <QNetworkConfigurationManager>
 #include <QUrlQuery>
 #include <webengineviewer_debug.h>
 
@@ -20,9 +19,7 @@ WEBENGINEVIEWER_EXPORT bool webengineview_useCompactJson_SearchFullHashJob = tru
 class WebEngineViewer::SearchFullHashJobPrivate
 {
 public:
-    SearchFullHashJobPrivate()
-    {
-    }
+    SearchFullHashJobPrivate() = default;
 
     Q_REQUIRED_RESULT bool foundExactHash(const QList<QByteArray> &listLongHash);
     QHash<QByteArray, QByteArray> mHashs;
@@ -101,7 +98,8 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
             // const QString minimumWaitDuration = answer.value(QStringLiteral("minimumWaitDuration")).toString();
             // const QString negativeCacheDuration = answer.value(QStringLiteral("negativeCacheDuration")).toString();
             // Implement multi match ?
-            if (info.count() == 1) {
+            const auto numberOfInfo{info.count()};
+            if (numberOfInfo == 1) {
                 const QVariantMap map = info.at(0).toMap();
                 const QString threatTypeStr = map[QStringLiteral("threatType")].toString();
 
@@ -130,6 +128,8 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
                 } else {
                     qCWarning(WEBENGINEVIEWER_LOG) << " SearchFullHashJob::parse threatTypeStr : " << threatTypeStr;
                 }
+            } else if (numberOfInfo == 0) {
+                Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::Ok, d->mUrl);
             } else {
                 qCWarning(WEBENGINEVIEWER_LOG) << " SearchFullHashJob::parse matches multi element : " << info.count();
                 Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::Unknown, d->mUrl);
@@ -232,7 +232,7 @@ QByteArray SearchFullHashJob::jsonRequest() const
 
 void SearchFullHashJob::start()
 {
-    if (!PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (!PimCommon::NetworkManager::self()->isOnline()) {
         Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::BrokenNetwork, d->mUrl);
         deleteLater();
     } else if (canStart()) {
