@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -51,9 +51,7 @@ CreatePhisingUrlDataBaseGui::CreatePhisingUrlDataBaseGui(QWidget *parent)
     buttonLayout->addWidget(save);
 }
 
-CreatePhisingUrlDataBaseGui::~CreatePhisingUrlDataBaseGui()
-{
-}
+CreatePhisingUrlDataBaseGui::~CreatePhisingUrlDataBaseGui() = default;
 
 void CreatePhisingUrlDataBaseGui::clear()
 {
