@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,11 @@
 #include "searchfullhashgui.h"
 
 #include <QApplication>
-#include <QStandardPaths>
-#include <QLineEdit>
-#include <QPushButton>
-#include <QPlainTextEdit>
 #include <QLabel>
+#include <QLineEdit>
+#include <QPlainTextEdit>
+#include <QPushButton>
+#include <QStandardPaths>
 #include <QVBoxLayout>
 
 extern WEBENGINEVIEWER_EXPORT bool webengineview_useCompactJson_SearchFullHashJob;
@@ -20,23 +20,23 @@ SearchFullHashGui::SearchFullHashGui(QWidget *parent)
     : QWidget(parent)
 {
     webengineview_useCompactJson_SearchFullHashJob = false;
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
-    QHBoxLayout *checkHashLayout = new QHBoxLayout;
+    auto checkHashLayout = new QHBoxLayout;
     layout->addLayout(checkHashLayout);
-    QLabel *lab = new QLabel(QStringLiteral("Hash from Url to Check:"), this);
+    auto lab = new QLabel(QStringLiteral("Hash from Url to Check:"), this);
     checkHashLayout->addWidget(lab);
     mCheckHashLineEdit = new QLineEdit(this);
     checkHashLayout->addWidget(mCheckHashLineEdit);
 
-    QHBoxLayout *databaseHashLayout = new QHBoxLayout;
+    auto databaseHashLayout = new QHBoxLayout;
     layout->addLayout(databaseHashLayout);
     lab = new QLabel(QStringLiteral("Database hash:"), this);
     checkHashLayout->addWidget(lab);
     mDataBaseHashLineEdit = new QLineEdit(this);
     checkHashLayout->addWidget(mDataBaseHashLineEdit);
 
-    QPushButton *button = new QPushButton(QStringLiteral("Check"), this);
+    auto button = new QPushButton(QStringLiteral("Check"), this);
     checkHashLayout->addWidget(button);
     connect(button, &QPushButton::clicked, this, &SearchFullHashGui::slotCheckUrl);
     connect(mCheckHashLineEdit, &QLineEdit::returnPressed, this, &SearchFullHashGui::slotCheckUrl);
@@ -50,9 +50,7 @@ SearchFullHashGui::SearchFullHashGui(QWidget *parent)
     layout->addWidget(mJson);
 }
 
-SearchFullHashGui::~SearchFullHashGui()
-{
-}
+SearchFullHashGui::~SearchFullHashGui() = default;
 
 void SearchFullHashGui::slotCheckUrl()
 {
@@ -66,7 +64,7 @@ void SearchFullHashGui::slotCheckUrl()
     }
 
     mResult->clear();
-    WebEngineViewer::SearchFullHashJob *job = new WebEngineViewer::SearchFullHashJob(this);
+    auto job = new WebEngineViewer::SearchFullHashJob(this);
     connect(job, &WebEngineViewer::SearchFullHashJob::result, this, &SearchFullHashGui::slotGetResult);
     connect(job, &WebEngineViewer::SearchFullHashJob::debugJson, this, &SearchFullHashGui::slotJSonDebug);
     job->setDatabaseState(QStringList() << databaseHashStr);
@@ -112,7 +110,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    SearchFullHashGui *w = new SearchFullHashGui;
+    auto w = new SearchFullHashGui;
 
     w->show();
     app.exec();
