@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,7 +7,9 @@
 #include <PimCommon/LineEditWithCompleterNg>
 #include <QAction>
 #include <QWebEngineView>
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QWebEngineFindTextResult>
+#endif
 using namespace WebEngineViewer;
 
 class WebEngineViewer::FindBarWebEngineViewPrivate
@@ -45,9 +47,15 @@ void FindBarWebEngineView::searchText(bool backward, bool isAutoSearch)
     }
     d->mView->findText(QString()); // Clear an existing highlight
     mLastSearchStr = searchWord;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    d->mView->findText(mLastSearchStr, searchOptions, [this](const QWebEngineFindTextResult &result) {
+        setFoundMatch(result.numberOfMatches() > 0);
+    });
+#else
     d->mView->findText(mLastSearchStr, searchOptions, [this](bool found) {
         setFoundMatch(found);
     });
+#endif
 }
 
 void FindBarWebEngineView::updateSensitivity(bool sensitivity)
@@ -57,9 +65,15 @@ void FindBarWebEngineView::updateSensitivity(bool sensitivity)
         searchOptions |= QWebEnginePage::FindCaseSensitively;
         d->mView->findText(QString()); // Clear an existing highlight
     }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    d->mView->findText(QString(), searchOptions, [this](const QWebEngineFindTextResult &result) {
+        setFoundMatch(result.numberOfMatches() > 0);
+    });
+#else
     d->mView->findText(QString(), searchOptions, [this](bool found) {
         setFoundMatch(found);
     });
+#endif
 }
 
 void FindBarWebEngineView::clearSelections()
