@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ using namespace WebEngineViewer;
 class WebEngineViewer::NetworkAccessManagerWebEnginePrivate
 {
 public:
-    NetworkAccessManagerWebEnginePrivate()
-    {
-    }
+    NetworkAccessManagerWebEnginePrivate() = default;
 
     WebEngineViewer::NetworkUrlInterceptorManager *mManager = nullptr;
     WebEngineViewer::NetworkUrlInterceptor *mNetworkUrlInterceptor = nullptr;
