@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TestDndWebEngine_H
-#define TestDndWebEngine_H
+#pragma once
 
 #include <QWebEngineView>
 #include <QWidget>
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class WebEngineView;
 }
 
@@ -19,6 +19,7 @@ class WebEngineViewBase : public QWebEngineView
     Q_OBJECT
 public:
     explicit WebEngineViewBase(QWidget *parent = nullptr);
+
 protected:
     void dragEnterEvent(QDragEnterEvent *e) override;
     void dragLeaveEvent(QDragLeaveEvent *e) override;
@@ -31,10 +32,9 @@ class TestDndWebEngine : public QWidget
     Q_OBJECT
 public:
     explicit TestDndWebEngine(QWidget *parent = nullptr);
-    ~TestDndWebEngine();
+    ~TestDndWebEngine() override;
+
 private:
     WebEngineViewer::WebEngineView *pageView = nullptr;
     WebEngineViewBase *webEngineView = nullptr;
 };
-
-#endif // TestDndWebEngine_H
