@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -80,9 +80,7 @@ void CidUrlRequestInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
     }
 }
 
-CidUrlRequestInterceptor::~CidUrlRequestInterceptor()
-{
-}
+CidUrlRequestInterceptor::~CidUrlRequestInterceptor() = default;
 
 TestWebEngineViewInterceptor::TestWebEngineViewInterceptor(QWidget *parent)
     : QWidget(parent)
@@ -116,7 +114,9 @@ int main(int argc, char *argv[])
     QWebEngineUrlScheme::registerScheme(scheme);
 
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto handler = new CidSchemeHandler(nullptr);
     QWebEngineProfile::defaultProfile()->installUrlSchemeHandler("cid", handler);
     auto testWebEngine = new TestWebEngineViewInterceptor;
