@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ WebEngineAccessKeyAnchorTest::WebEngineAccessKeyAnchorTest(QObject *parent)
 {
 }
 
-WebEngineAccessKeyAnchorTest::~WebEngineAccessKeyAnchorTest()
-{
-}
+WebEngineAccessKeyAnchorTest::~WebEngineAccessKeyAnchorTest() = default;
 
 void WebEngineAccessKeyAnchorTest::shouldReturnEmptyAccessKeyAnchor()
 {
