@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ WebEngineExportPdfPageJob::WebEngineExportPdfPageJob(QObject *parent)
 {
 }
 
-WebEngineExportPdfPageJob::~WebEngineExportPdfPageJob()
-{
-}
+WebEngineExportPdfPageJob::~WebEngineExportPdfPageJob() = default;
 
 void WebEngineExportPdfPageJob::start()
 {
