@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ WebEngineNavigationRequestInterceptor::WebEngineNavigationRequestInterceptor(QWe
 {
 }
 
-WebEngineNavigationRequestInterceptor::~WebEngineNavigationRequestInterceptor()
-{
-}
+WebEngineNavigationRequestInterceptor::~WebEngineNavigationRequestInterceptor() = default;
 
 bool WebEngineNavigationRequestInterceptor::acceptNavigationRequest(const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame)
 {
