@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,11 @@
 #include "webengineviewer_export.h"
 #include <QWebEnginePage>
 class QWebEngineProfile;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 class QWebEngineDownloadItem;
+#else
+class QWebEngineDownloadRequest;
+#endif
 class QPrinter;
 namespace WebEngineViewer
 {
@@ -59,7 +63,11 @@ public:
 
     WebEngineViewer::WebHitTest *hitTestContent(const QPoint &pos);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void saveHtml(QWebEngineDownloadItem *download);
+#else
+    void saveHtml(QWebEngineDownloadRequest *download);
+#endif
     Q_REQUIRED_RESULT bool execPrintPreviewPage(QPrinter *printer, int timeout);
 
     Q_REQUIRED_RESULT QPoint mapToViewport(const QPoint &pos) const;
@@ -75,4 +83,3 @@ private:
     void init();
 };
 }
-
