@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -96,11 +96,6 @@ WebEngineManageScript *WebEngineView::webEngineManagerScript() const
     return d->mManagerScript;
 }
 
-void WebEngineView::addScript(const QString &source, const QString &scriptName, QWebEngineScript::InjectionPoint injectionPoint)
-{
-    d->mManagerScript->addScript(page()->profile(), source, scriptName, injectionPoint);
-}
-
 void WebEngineView::forwardWheelEvent(QWheelEvent *event)
 {
     Q_UNUSED(event)
